﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO;
using Microsoft.VisualBasic.FileIO;

namespace ThiesGeneral.FileFunctions
{
    static public class Folder
    {
        static public long GetFolderSize(string folderPathPar)
        {
            long loFolderSize = 0;
            DirectoryInfo diDir = new DirectoryInfo(folderPathPar);
            foreach (FileInfo fiFile in diDir.GetFiles("*", System.IO.SearchOption.AllDirectories))
            {
                loFolderSize += fiFile.Length;
            }
            return (loFolderSize);
        }

        static public string GetFolderName(string path)
        {
            var dInfo = new DirectoryInfo(path);
            return dInfo.Name;
        }

        static public DateTime GetFolderCreationTime(string path)
        {
            var dirInfo = new DirectoryInfo(path);
            return dirInfo.CreationTime;
        }

        static public long GetFreeSpaceFromFolder(string folderPar)
        {
            DriveInfo diDriveInfo = new DriveInfo(folderPar.Substring(0, 1));
            return diDriveInfo.AvailableFreeSpace;
        }

        static public string GetFilmTypeByFolder(string folderPathPar)
        {
            string[] fileTypes = {      
            "*.mpls",                                                 
            "*.mkv", 
            "*.avi",
            "*.divx",
            "*.mpg",
            "*.ogm",
            "*.mpeg",
            "*.ts",
            "*.m2ts",
            "video_ts.ifo",
            "*.nrg",
            "*.iso",
            "*.img",
            "*.wmv",
            "*.mp4"
            };


            string[] files =
                Directory.GetFiles(folderPathPar, fileTypes[0], System.IO.SearchOption.AllDirectories);
            int a = 0;

            do
            {
                files =
                    Directory.GetFiles(folderPathPar, fileTypes[a], System.IO.SearchOption.AllDirectories);
                a++;
            }
            while ((files.Count() == 0) & (a < fileTypes.Count()-1));
            a--;

            if (files.Count() > 0)
            {
                return (fileTypes[a].Substring(fileTypes[a].LastIndexOf(Convert.ToChar(".")) + 1));
            }

            return "unknown";
        }

        static public void CopyOrMoveFilesFromFolderToNewFolder(string oldFolderPar, string newFolderPar)
        {
            string strCurrenPath = oldFolderPar;
            //Verzeichnis anlegen wenn noch nicht da
            if (!Directory.Exists(newFolderPar))
            {
                Directory.CreateDirectory(newFolderPar);
            }
            var source = new DirectoryInfo(oldFolderPar);
            var target = new DirectoryInfo(newFolderPar);
            if (source.Root.ToString() == target.Root.ToString())
            {
                FileSystem.MoveDirectory(oldFolderPar, newFolderPar);
            }
            else
            {
                FileSystem.CopyDirectory(strCurrenPath, newFolderPar,
                    UIOption.AllDialogs);
            }
        }

        static public void DeleteAllRarFilesInFolder(string folder)
        {
            string[] strRarFiles = Directory.GetFiles(folder, "*.rar", System.IO.SearchOption.AllDirectories);
            foreach (string strFile in strRarFiles)
            {
                File.Delete(strFile);
            }
        }
    }
}
