﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Id3Tag;
using System.Windows.Forms;
using Id3Tag.HighLevel.Id3Frame;
using Microsoft.DirectX.AudioVideoPlayback;

namespace ThiesGeneral.Media.Musik
{
    static public class Mp3
    {
        static public string Title { get; set; }
        static public string Album { get; set; }
        static public string Artist { get; set; }
        static public string Comment { get; set; }
        static public string Genre { get; set; }
        static public string TrackNumber { get; set; }
        static public string Year { get; set; }
        static public string Length { get; set; }
        static public string FilePath { get; set; }

        static private void Init()
        {
            Title = "";
            Album = "";
            Artist = "";
            Comment = "";
            Genre = "";
            TrackNumber = "";
            Year = "";
            Length = "";
            FilePath = "";
        }

        static public void ReadMp3Tag(string filePath)
        {
            Init();
            FilePath = filePath;
            var manager = new Id3TagManager();
            var v1Tag = new Id3Tag.HighLevel.Id3V1Tag();
            Id3Tag.HighLevel.TagContainer tagContainer;
            FileState fs = null;
            try
            {
                fs = manager.GetTagsStatus(filePath);
            }
            catch (Exception)
            {
                return;
            }
            
            try
            {
                if (fs.Id3V1TagFound)
                {
                    v1Tag = manager.ReadV1Tag(filePath);
                    Album = v1Tag.Album;
                    Artist = v1Tag.Artist;
                    Comment = v1Tag.Comment;
                    Genre = v1Tag.Genre;
                    Title = v1Tag.Title;
                    TrackNumber = v1Tag.TrackNumber;
                    Year = v1Tag.Year;
                }
            }
            catch (Exception)
            {
                
                
            }
            

            try
            {
                if (fs.Id3V2TagFound)
                {


                    tagContainer = manager.ReadV2Tag(filePath);
                    string test = "";
                    foreach (var item in tagContainer)
                    {
                        if ((item.Type == Id3Tag.HighLevel.FrameType.Text) || (item.Type == Id3Tag.HighLevel.FrameType.Comment))
                        {
                            var tf = new TextFrame();
                            var cf = new CommentFrame();
                            if (item.Type == Id3Tag.HighLevel.FrameType.Text)
                            {
                                tf = (TextFrame)item;
                                switch (tf.Descriptor.Id)
                                {
                                    case "TIT2":
                                        Title = tf.Content;
                                        break;
                                    case "TALB":
                                        Album = tf.Content;
                                        break;
                                    case "TYER":
                                        Year = tf.Content;
                                        break;
                                    case "TRCK":
                                        TrackNumber = tf.Content;
                                        break;
                                    case "TPE1":
                                        Artist = tf.Content;
                                        break;
                                    case "TCON":
                                        if (tf.Content.Contains("("))
                                        {
                                            string genereNum = tf.Content.Substring(1,
                                                tf.Content.IndexOf(")")-1);
                                            int genereNumInt = 0;
                                            if (int.TryParse(genereNum,out genereNumInt))
                                            {
                                                if (Id3Tag.HighLevel.Genre.Instance.ContainsGenre(genereNumInt))
                                                {
                                                    Genre = Id3Tag.HighLevel.Genre.Instance.AllGenres[genereNumInt];
                                                }        
                                            }

                                        }
                                        else
                                        {
                                            Genre = tf.Content;
                                        }                                                                                
                                        break;
                                    case "TLEN":
                                        Length = tf.Content;
                                        break;
                                    default:
                                        break;
                                }
                                test = test + "\n" + tf.Descriptor.Id + ":" + tf.Content;
                            }
                            else
                            {
                                cf = (CommentFrame)item;
                                Comment = cf.Text;
                                test = test + "\n" + cf.Descriptor.Id + ":" + cf.Text;
                            }
                        }
                    }
                }

            }
            catch (Exception)
            {
                
                
            }
        }

        static public void WriteMp3Tag()
        {
            if (FilePath != "")
            {
                var manager = new Id3TagManager();
                var tagContainer = new Id3Tag.HighLevel.TagContainerV4();
                Id3Tag.HighLevel.Id3V1Tag v1Tag = new Id3Tag.HighLevel.Id3V1Tag();

                // V1Tag
                v1Tag.Album = Album;
                v1Tag.Artist = Artist;
                v1Tag.Title = Title;
                v1Tag.TrackNumber = TrackNumber;
                v1Tag.Year = Year;

                // V2Tag
                tagContainer.Add(new TextFrame("TIT2",Title,Encoding.Default));
                tagContainer.Add(new TextFrame("TALB",Album,Encoding.Default));
                tagContainer.Add(new TextFrame("TYER",Year,Encoding.Default));
                tagContainer.Add(new TextFrame("TRCK",TrackNumber,Encoding.Default));
                tagContainer.Add(new TextFrame("TPE1",Artist,Encoding.Default));
                tagContainer.Add(new TextFrame("TCON",Genre,Encoding.Default));
                tagContainer.Add(new TextFrame("TLEN",Length,Encoding.Default));
                try
                {
                    manager.WriteV1Tag(FilePath, v1Tag);
                    manager.WriteV2Tag(FilePath, tagContainer);
                }
                catch (Exception)
                {
                    
                }
                

            }
        }


        static public double GetLength(string filePath)
        {
            double length = 0;
            try
            {
                var myAudio = new Audio(filePath);
                //myAudio.Play();
                length = myAudio.Duration;
                //myAudio.Stop();
                Length = new DateTime(Convert.ToInt64(10000000 * length)).TimeOfDay.ToString("hh':'mm':'ss");
                myAudio.Dispose();
            }
            catch (Exception)
            {
                
            }
            return length;
            
        }
    }
}
