﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Excel = Microsoft.Office.Interop.Excel;
using System.Windows.Forms; 

namespace ThiesGeneral.MsOffice
{
    
    public class MyExcel
    {
        private Excel.Application myExcelApplication;
        private Excel.Workbook myExcelWorkbook;
        private Excel.Worksheet myExcelWorkSheet;
        private int currentLineNo = 0;
        private int currentCoulmnNo = 0;


        /// <summary>
        /// Create Empty Excelsheet
        /// </summary>
        /// <param name="showExcel">Show Worksheet</param>
        public MyExcel(bool showExcel) 
        {
            try
            {
                // Excel Prozess initialisieren
                myExcelApplication = new Excel.Application();
                myExcelApplication.Visible = showExcel;
                myExcelApplication.ScreenUpdating = showExcel;

                // Excel Datei anlegen: Workbook
                var myCount = myExcelApplication.Workbooks.Count;
                myExcelWorkbook = (Excel.Workbook)(myExcelApplication.Workbooks.Add(System.Reflection.Missing.Value));
                myExcelWorkSheet = (Excel.Worksheet)myExcelWorkbook.ActiveSheet;
            }

            catch (Exception ex)
            {
                String myErrorString = ex.Message;
                MessageBox.Show(myErrorString);
            }
            finally
            {
                // Excel beenden
                if ((myExcelApplication != null) && (!showExcel))
                {
                    myExcelApplication.Quit();
                }
            }

            
        }


        /// <summary>
        /// Creates a Excelfile
        /// </summary>
        /// <param name="sheetNamePar">Name of the Excelsheet</param>
        /// <param name="headerPar">The Headercolumns</param>
        /// <param name="dataPar">The two dimensional DataArray</param>
        /// <param name="letItOpenPar">Show the ExcelApplication</param>
        /// <param name="fileName">filename to save</param>
        public MyExcel(string sheetNamePar,string [] headerPar,string[,] dataPar, string fileName, bool letItOpenPar)
        {
            try
            {
                // Excel Prozess initialisieren
                myExcelApplication = new Excel.Application();
                myExcelApplication.Visible = false;
                myExcelApplication.ScreenUpdating = false;

                // Excel Datei anlegen: Workbook
                var myCount = myExcelApplication.Workbooks.Count;
                myExcelWorkbook = (Excel.Workbook)(myExcelApplication.Workbooks.Add(System.Reflection.Missing.Value));
                myExcelWorkSheet = (Excel.Worksheet)myExcelWorkbook.ActiveSheet;

                myExcelWorkSheet.Name = sheetNamePar;

                AddLine(headerPar);
                MakeLineBold(1, headerPar.Count());

                for (int i = 0; i < dataPar.GetLength(1); i++)
                {
                    NewLine();
                    for (int a = 0; a < dataPar.GetLength(0); a++)
                    {
                        AddCell(dataPar[a, i]);       
                    }
                }
                myExcelApplication.Visible = letItOpenPar;
                myExcelApplication.ScreenUpdating = letItOpenPar;

                if (!letItOpenPar)
                {
                    myExcelWorkbook.SaveAs(fileName, Excel.XlFileFormat.xlWorkbookNormal,
                        System.Reflection.Missing.Value,
                        System.Reflection.Missing.Value,
                        System.Reflection.Missing.Value,
                        System.Reflection.Missing.Value,
                        Excel.XlSaveAsAccessMode.xlExclusive,
                        System.Reflection.Missing.Value,
                        System.Reflection.Missing.Value,
                        System.Reflection.Missing.Value,
                        System.Reflection.Missing.Value,
                        System.Reflection.Missing.Value);
                    myExcelWorkbook.Close(false, fileName, System.Reflection.Missing.Value);
                }
                
            }

            catch (Exception ex)
            {
                String myErrorString = ex.Message;
                MessageBox.Show(myErrorString);
            }
            finally
            {
                // Excel beenden
                if ((myExcelApplication != null) && (!letItOpenPar))
                {
                    myExcelApplication.Workbooks.Close();
                    myExcelApplication.Quit();
                    myExcelWorkSheet = null;
                    myExcelWorkbook = null;
                    myExcelApplication = null;
                    System.GC.Collect();
                }
            }

        }


        /// <summary>
        /// Exampleconstructor
        /// for Example only
        /// </summary>
        /// <param name="beispielPar"></param>
        /// <param name="BeispielToday"></param>
        public MyExcel(string beispielPar, DateTime BeispielToday)
        {
            throw new NotImplementedException();
            try
            {
                // First Contact: Excel Prozess initialisieren
                myExcelApplication = new Excel.Application();
                myExcelApplication.Visible = true;
                myExcelApplication.ScreenUpdating = true;

                // Excel Datei anlegen: Workbook
                var myCount = myExcelApplication.Workbooks.Count;
                myExcelWorkbook = (Excel.Workbook)(myExcelApplication.Workbooks.Add(System.Reflection.Missing.Value));
                myExcelWorkSheet = (Excel.Worksheet)myExcelWorkbook.ActiveSheet;

                // Überschriften eingeben
                myExcelWorkSheet.Cells[2, 2] = "Hamburg";    // Zelle B2
                myExcelWorkSheet.Cells[2, 3] = "Nürnberg";   // Zelle C2
                myExcelWorkSheet.Cells[2, 4] = "Hamburg";    // Zelle D2

                // Formatieren der Überschrift
                Excel.Range myRangeHeadline;
                myRangeHeadline = myExcelWorkSheet.get_Range("B2", "D2");
                myRangeHeadline.Font.Bold = true;
                myRangeHeadline.HorizontalAlignment = Excel.XlHAlign.xlHAlignCenter;
                myRangeHeadline.Borders.Weight = Excel.XlBorderWeight.xlThick;

                // Daten eingeben
                myExcelWorkSheet.Cells[3, 2] = "18";
                myExcelWorkSheet.Cells[3, 3] = "21";
                myExcelWorkSheet.Cells[3, 4] = "11";
                myExcelWorkSheet.Cells[4, 2] = "21";
                myExcelWorkSheet.Cells[4, 3] = "32";
                myExcelWorkSheet.Cells[4, 4] = "22";
                myExcelWorkSheet.Cells[5, 2] = "12";
                myExcelWorkSheet.Cells[5, 3] = "56";
                myExcelWorkSheet.Cells[5, 4] = "14";
                myExcelWorkSheet.Name = "Kunden";


                // Chart erzeugen
                Excel.Range myRangeValues;
                myRangeValues = myExcelWorkSheet.get_Range("B3", "D5");

                Excel.Chart myChart = (Excel.Chart)myExcelWorkbook.Charts.Add(
                  System.Reflection.Missing.Value,
                  System.Reflection.Missing.Value,
                  System.Reflection.Missing.Value,
                  System.Reflection.Missing.Value);

                myChart.ChartWizard(
                  myRangeValues,
                  Excel.XlChartType.xl3DColumn,
                  System.Reflection.Missing.Value,
                  Excel.XlRowCol.xlRows,
                  System.Reflection.Missing.Value,
                  System.Reflection.Missing.Value,
                  System.Reflection.Missing.Value,
                  "Titel",
                  "Kunden",
                  "Anzahl",
                  System.Reflection.Missing.Value);

                myChart.CopyPicture(Excel.XlPictureAppearance.xlScreen,
                 Excel.XlCopyPictureFormat.xlBitmap,
                 Excel.XlPictureAppearance.xlScreen);

                myChart.Location(Excel.XlChartLocation.xlLocationAsObject, myExcelWorkSheet.Name);

                // Excel Datei abspeichern
                // wenn die Datei vorher vorhanden ist, kommt in Excel eine Fehlermeldung.
                myExcelWorkbook.Close(true, "C:\\kunden.xls", System.Reflection.Missing.Value);
            }

            catch (Exception ex)
            {
                String myErrorString = ex.Message;
                MessageBox.Show(myErrorString);
            }
            finally
            {
                // Excel beenden
                if (myExcelApplication != null)
                {
                    myExcelApplication.Quit();
                }

            }  

        }


        /// <summary>
        /// Adds a line to the Excelsheet
        /// </summary>
        /// <param name="cellsPar">Cells array which where added from left to right</param>
        public void AddLine(string[] cellsPar)
        {
            int column = 0;
            currentLineNo++;

            try
            {
                foreach (string cell in cellsPar)
                {
                    column++;                    
                    myExcelWorkSheet.Cells[currentLineNo, column] = cell;
                }
            }
            catch (Exception ex)
            {
                String myErrorString = ex.Message;
                MessageBox.Show(myErrorString);
            }
        }

        public void AddCell(string cellPar)
        {

            try
            {
                currentCoulmnNo++;
                myExcelWorkSheet.Cells[currentLineNo, currentCoulmnNo] = cellPar;
            }
            catch (Exception ex)
            {
                String myErrorString = ex.Message;
                MessageBox.Show(myErrorString);
            }
        }

        public void NewLine()
        {
            currentLineNo++;
            currentCoulmnNo = 0;
        }


        public void MakeLineBold(int lineNoPar, int lastCellNoPar)
        {
            try
            {
                for (int a = 1; a <= lastCellNoPar; a++)
                {
                    myExcelWorkSheet.Cells[lineNoPar, a].Font.Bold = true;
                }
            }
            catch (Exception ex)
            {
                String myErrorString = ex.Message;
                MessageBox.Show(myErrorString);
            }
            
        }
    }
}
