﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO;

namespace ThiesGeneral.Web.HtmlBuilder
{
    public class HtmlDocument
    {
        string _InnerText = string.Empty;
        public String FileName { get; set; }
        public string InnerText
        {            
            set
            {
                _InnerText = value;
                Children.Clear();
            }
        }
        public List<HtmlElement> Children = new List<HtmlElement>();

        /// <summary>
        /// Constructor with filename
        /// </summary>
        /// <param name="fileName">for example "index.html"</param>
        public HtmlDocument(string fileName)
        {
            FileName = fileName;
        }

        public HtmlDocument()
        {

        }  

        public HtmlElement CreateElement(string p)
        {
            var htmlElement = new HtmlElement();
            htmlElement.Tag = p;
            return htmlElement;
        }

        public HtmlElement CreateElement(string p, bool singleTag)
        {
            var htmlElement = new HtmlElement();
            htmlElement.Tag = p;
            htmlElement.SingleTag = singleTag;
            return htmlElement;
        }

        public void AppendChild(HtmlElement elem)
        {
            Children.Add(elem);
        }

        public string GetInnerText()
        {
            if (_InnerText == string.Empty)
            {
                string ChildrenText = "<HTML>\r\n";
                foreach (var child in Children)
                {
                    ChildrenText = ChildrenText + child.TagAndText + "\r\n";
                }
                ChildrenText = ChildrenText + "</HTML>";
                return ChildrenText;
            }
            return _InnerText;
        }

        public void WriteInFolder(string folder)
        {
            if ((FileName != "") && (folder != ""))
            {
                FileStream fsStream;
                string filePath = folder + "\\" + FileName;

                if (!Directory.Exists(folder))
	            {
                    Directory.CreateDirectory(folder);
	            }         

                string fileContent;
                StreamWriter streWriter;

                // Datei erzeugen/öffnen
                if (!File.Exists(filePath))
                {
                    fsStream = File.Create(filePath);
                    fsStream.Close();
                }

                //schreiben
                fileContent = this.GetInnerText();

                // in Datei schreiben
                streWriter = new StreamWriter(filePath, false,Encoding.Unicode);
                streWriter.Write(fileContent);
                streWriter.Close();
            }
        }

    }
}
