﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.deusing System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace ThiesGeneral.Web.HtmlBuilder
{
    public class HtmlElement
    {
        string _InnerText;
        public string Tag { get; set; }
        public bool SingleTag { get; set; }
        public List<HtmlAribute> HAttributes { get; set; }
        public string InnerText 
        {
            get
            {
                if (Children.Count > 0)
                {
                    string ChildrenText = string.Empty;
                    foreach (var child in Children)
                    {
                        ChildrenText = ChildrenText + "\r\n" + child.TagAndText;
                    }
                    return ChildrenText;
                }
                return _InnerText;
            }
            set
            {
                if (Children.Count > 0)
                {
                    Children.Clear();
                }
                _InnerText = value;
            }
        }
        public string TagAndText 
        {
            get
            {
                string atText = string.Empty;
                if (Tag != null)
                {


                    if (HAttributes != null)
                    {
                        foreach (HtmlAribute item in HAttributes)
                        {
                            atText = atText + " " + item.AtName + "=" +
                                "\"" + item.AtValue + "\"";
                        }
                    }
                    if (SingleTag)
                    {
                        return "<" + Tag + atText + ">" +
                            InnerText;
                    }
                    return "<" + Tag + atText + ">" +
                            InnerText +
                            "</" + Tag + ">";
                }
                else
                {
                    return InnerText;
                }
            }
        }
        public List<HtmlElement> Children = new List<HtmlElement>();
        public HtmlElement()
        {

        }

        public void AppendChild(HtmlElement element)
        {
            Children.Add(element);
        }
        public void AddAtribute(string atName, string atValue)
        {
            if (HAttributes == null)
            {
                HAttributes = new List<HtmlAribute>();
            }
            HAttributes.Add(new HtmlAribute(atName, atValue));
        }

        public void AddText(string textToAdd)
        {
            var newChild = new HtmlElement();
            newChild.InnerText = textToAdd;
            Children.Add(newChild);
        }

        
    }
    public class HtmlAribute
    {
        public string AtName { get; set; }
        public string AtValue { get; set; }
        public HtmlAribute(string atName, string atValue)
        {
            AtName = atName;
            AtValue = atValue;
        }
    }
}
