/// Copyright  2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.Text;
using System.Net;
using System.Net.Sockets;
using System.Threading;
using System.Windows.Forms;
using System.IO;

namespace ThiesGeneral.Web.WebServer
{
    public delegate void applicationOrder_event(string s);
    public delegate void fileGet_event(string s, ref string filePath);
    public delegate void streamGet_event(string s, ref Stream stream);

    public class Server
    {
        public event applicationOrder_event ApplicationOrder;
        public event fileGet_event GetFile;
        public event streamGet_event GetStream;

        int _Port;
        int _Backlog;
        string ServerRootPath = String.Empty;
        Thread MyClientThread;
        bool ServerRunning = true;
        bool nextConnection = false;

        public Server(int Port, int Backlog)
        {
            _Port = Port;
            _Backlog = Backlog;
            MyClientThread = new Thread(new ThreadStart(StartServer));
        }

        public Server(int Port, int Backlog, string serverRootPath)
        {
            _Port = Port;
            _Backlog = Backlog;
            ServerRootPath = serverRootPath;
            MyClientThread = new Thread(new ThreadStart(StartServer));
        }

        public void Start()
        {
            MyClientThread.Start();
        }

        public void Stop()
        {
            ServerRunning = false;
            MyClientThread.Abort();
        }

        private void StartServer()
        {
            int Port, Backlog;
            Port = _Port;
            Backlog = _Backlog;

            Socket server = new Socket(AddressFamily.InterNetwork, SocketType.Stream, ProtocolType.Tcp);
            try
            {
                server.Bind(new IPEndPoint(IPAddress.Any, Port));
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            
            server.Listen(Backlog);
            //SocketAsyncEventArgs e = new SocketAsyncEventArgs();
            //e.Completed += new EventHandler<SocketAsyncEventArgs>(e_Completed);
            //server.AcceptAsync(e);
            server.BeginAccept(e_Completed,server);
            while (ServerRunning)
            {
                Thread.Sleep(10);
                if (nextConnection)
                {
                    //e = new SocketAsyncEventArgs();
                    //e.Completed += new EventHandler<SocketAsyncEventArgs>(e_Completed);
                    //server.AcceptAsync(e);
                    server.BeginAccept(e_Completed, server);
                    nextConnection = false;
                }
            }
            server.Close();

        }

        void e_Completed(IAsyncResult ar)
        {
            Socket listener = (Socket)ar.AsyncState;
            Socket sock = listener.EndAccept(ar);
            //Socket sock = ar.AcceptSocket;
            Serverhandling handling = new Serverhandling(sock, ServerRootPath);
            handling.orderToAplication += new orderToAplication_event(GetApplicationOrderByUser);
            handling.getFile += new getFile_event(handling_getFile);
            handling.getStream += new getStream_event(handling_getStream);
            handling.Run();
            nextConnection = true;
        }

        void handling_getStream(string s, ref Stream Stream)
        {
            if (GetStream != null)
            {
                GetStream(s, ref Stream);
            }
        }

        void handling_getFile(string s, ref string filePath)
        {
            if (GetFile != null)
            {
                GetFile(s, ref filePath);
            }
        }


        private void GetApplicationOrderByUser(string order)
        {
            if (ApplicationOrder != null)
            {
                ApplicationOrder(order);
            }
        }

    }
}
