/// Copyright  2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using System.Net;
using System.Net.Sockets;
using System.Threading;
using System.IO;

namespace ThiesGeneral.Web.WebServer
{
    public delegate void orderToAplication_event(string s);
    public delegate void getFile_event(string s,ref string filePath);
    public delegate void getStream_event(string s, ref Stream Stream);

    class Serverhandling
    {
        public event orderToAplication_event orderToAplication;
        public event getFile_event getFile;
        public event getStream_event getStream;

        private Socket Sock;
        private string WebRootFolder;
        int BufferSize = 131072;

        public Serverhandling(Socket sock, string webRootFolder)
        {
            Sock = sock;
            WebRootFolder = webRootFolder;
        }


        public void Run()
        {
            String request = getContent();
            try
            {
                String[] lines = request.Split(Environment.NewLine.ToCharArray());
                String[] words = lines[0].Split(" ".ToCharArray());
                if (words[0] == "GET")
                {
                    int pos = words[1].LastIndexOf("/");
                    if (pos > -1)
                    {
                        SendContent(words, pos);
                    }
                    else
                    {
                        sendResponse("400 BAD REQUEST", "Url-Error");
                    }
                }
                else
                {
                    sendResponse("400 BAD REQUEST", "Only GET supported");
                }
            }
            catch (FileNotFoundException e1)
            {
                sendResponse("400 BAD REQUEST", e1.Message + ": " + e1.FileName);
            }
            catch (Exception e)
            {
                sendResponse("400 BAD REQUEST", "Protokollfehler: " + e.Message);
            }
            Sock.Close();
        }

        private void SendContent(String[] words, int pos)
        {
            if (WebRootFolder != "")
            {
                if (
                    (!words[1].Contains("?")) && 
                    (!words[1].Contains("getfile")) && 
                    (!words[1].Contains("getThisfile"))
                    )
                {
                    if (words[1] != "/" && words[1].Length > pos)
                    {
                        String filename = words[1].Substring(pos + 1);
                        if (File.Exists(WebRootFolder + "\\" + filename))
                        {
                            sendFile(filename);
                        }
                        else
                        {
                            sendResponse("404 NOT FOUND", "File not found: " + filename);
                        }
                    }
                    else
                    {
                        if (File.Exists(WebRootFolder + "\\" + "index.html"))
                            sendFile("index.html");
                        else
                            sendResponse("200 OK", "Index");
                    }
                }
                else
                {
                    if (words[1].Contains("?"))
                    {
                        if (orderToAplication != null)
                        {
                            string[] myWords = words[1].Split("?".ToCharArray());
                            orderToAplication(myWords[1]);
                            words[1] = myWords[0];
                            SendContent(words, pos);
                        }
                    }
                    GetFile(words);
                }
            }
            else
            {
                if (!GetFile(words))
                {
                    if (getStream != null)
                    {
                        Stream stream = null;
                        getStream(words[1], ref stream);
                        if (stream != null)
                        {
                            SendStream(stream, words[1]);
                        }
                        else
                        {
                            sendResponse("404 NOT FOUND", "File not found: " + words[1]);
                        }
                    }
                    else
                    {
                        sendResponse("500 SERVER ERROR", "Error in Handler-class");
                    }
                }
            }
                
            
        }

        private bool GetFile(string [] words) 
        {
            if (words[1].Contains("getThisfile"))
            {
                if (getFile != null)
                {
                    string[] myWords = words[1].Split("/".ToCharArray());
                    string[] myWords2 = myWords[1].Split("=".ToCharArray());
                    string filePath = string.Empty;
                    getFile(myWords2[1], ref filePath);
                    sendFile(filePath);
                }
                return true;
            }
            else
            {
                if (words[1].Contains("getfile"))
                {
                    if (getFile != null)
                    {
                        string[] myWords = words[1].Split("=".ToCharArray());
                        string filePath = string.Empty;
                        getFile(myWords[1], ref filePath);
                        sendRedirectGetFile(new FileInfo(filePath).Name, myWords[1]);
                    }
                    return true;
                }
            }
            return false;
        }

        private void sendRedirectGetFile(String fileName, String fileId)
        {
            sendText("HTTP/1.0 302 Moved Temporarily");
            sendText("Server: ThiesWebserver 1.00");
            sendText("Location: /getfile=" + fileId + "/getThisfile/" + fileName);
            sendText("");
        }

        private void sendResponse(String status, String tosend)
        {
            LogConsole(status);
            sendText("HTTP/1.1 " + status);
            sendText("Server: ThiesWebserver 1.00");
            sendText("Connection: close");
            sendText("Content-Type: text/html; charset=UTF-8");
            sendText("Content-Length: " + (tosend.Length + Environment.NewLine.Length));
            sendText("");
            sendText(tosend);
        }

        private void sendText(String text)
        {
            try
            {
                Sock.Send(Encoding.UTF8.GetBytes(text + Environment.NewLine));
            }
            catch (Exception)
            {

            }            
        }

        private void sendFile(String filename)
        {
            FileStream stream;
            if (filename.Contains(":"))
            {
                stream = new FileStream(filename, FileMode.Open, FileAccess.Read, FileShare.Read, BufferSize, false);
            }
            else
            {
                stream = new FileStream(WebRootFolder + "\\" + filename, FileMode.Open, FileAccess.Read, FileShare.Read, BufferSize, false);
            }
            Stream sStream = stream;
            SendStream(sStream, filename);
        }


        private void SendStream(Stream stream, string fileName)
        {
            try
            {
                LogConsole("200 OK [ " + fileName + " ]");
                sendText("HTTP/1.1 200 OK");
                sendText("Server: ThiesWebserver 1.00");
                sendText("Connection: close");
                if ((fileName.Contains(".htm")) || (fileName == "/"))
                {
                    sendText("Content-Type: text/html; charset=UTF-8");
                }
                else
                {
                    sendText("Content-Type: application/octet-stream");
                }
                
                sendText("Content-Length: " + stream.Length);
                sendText("");
                long read = 0;
                while (read < stream.Length)
                {
                    int buffersize;
                    if (stream.Length - read > BufferSize)
                    {
                        buffersize = BufferSize;
                        read += BufferSize;
                    }
                    else
                    {
                        buffersize = (int)(stream.Length - read);
                        read = stream.Length;
                    }
                    byte[] tosend = new byte[buffersize];
                    stream.Read(tosend, 0, buffersize);
                    Sock.Send(tosend);
                    //Thread.Sleep(1);
                }
                stream.Close();
            }
            catch (SocketException e)
            {
                // cancel fileload
                if (e.ErrorCode == 10053)
                {
                    if (stream != null)
                    {
                        stream.Close();
                    }
                }
                else
                {
                    throw e;
                }
            }
        }

        private String getContent()
        {
            String content = "";
            Thread.Sleep(10);
            while (Sock.Available > 0)
            {
                int bytes = Sock.Available;
                byte[] buffer = new byte[bytes];
                Sock.Receive(buffer, bytes, SocketFlags.None);
                content += Encoding.UTF8.GetString(buffer);
                Thread.Sleep(10);
            }
            return content;
        }
        private void LogConsole(String Message)
        {
            Console.WriteLine(((IPEndPoint)Sock.RemoteEndPoint).Address.ToString() + " - " + Message);
        }
    }
}
