﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ThiesMediaProject.General;
using ThiesMediaProject.SettingForms;
using ThiesMediaProject.Properties;
using ThiesMediaProject.ToolForms;
using System.IO;
using System.Threading;
using ThiesGeneral.FileFunctions;
using ThiesGeneral.Media.Video;
using ThiesGeneral.Media.VLC_Streaming;
using ThiesMediaProject.ToolForms.IMDBLoader;
using System.Diagnostics;

namespace ThiesMediaProject
{
    public partial class FilmForm : Form
    {
        object formDataSource;
        Films MyFilms = new Films();
        private int indexOfItemUnderMouseToDrag;
        private Rectangle dragBoxFromMouseDown;
        private Point screenOffset;

        public object DataSource
        {
            get
            {
                return formDataSource;
            }
            set
            {
                MyFilms = (Films)value;
                formDataSource = MyFilms;

                filmBindingSource.DataSource = formDataSource;
                filmDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);
            }
        }

        public FilmForm()
        {            
            InitializeComponent();
            this.Size = Settings.Default.FilmFormSize;
            Translate.TranslateForm(this);
            this.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            filmBindingNavigator.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            mainFormMenuStrip.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            bindingNavigatorPositionItem.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            this.Icon = Properties.Resources.tmp_icon;            
        }

        private void MainForm_Load(object sender, EventArgs e)
        {
            MyFilms = Data.DataFilms;
            if (MyFilms != null)
            {
                MyFilms.Sort(TypeDescriptor.GetProperties(new Film())["Filmname"],
                    ListSortDirection.Ascending);
                filmBindingSource.DataSource = MyFilms;
                changeBackColor();
            }
            filmDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);            

            if (Settings.Default.FilmsColumnsNotToShow != null)
            {
                foreach (string item in Settings.Default.FilmsColumnsNotToShow)
                {
                    filmDataGridView.Columns.Remove(item);
                }
            }
        }

        private void pathSettingsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            var pF = new PathsForm();
            pF.ShowDialog();
            ReloadFilms();
        }

        private void filmDataGridView_ColumnHeaderMouseClick(object sender, DataGridViewCellMouseEventArgs e)
        {
            if (filmDataGridView.Columns[e.ColumnIndex].ValueType != new Bitmap(1,1).GetType())
            {
                if (filmDataGridView.SortedColumn == filmDataGridView.Columns[e.ColumnIndex])
                {
                    if (filmDataGridView.SortOrder == SortOrder.Ascending)
                    {
                        filmDataGridView.Sort(filmDataGridView.Columns[e.ColumnIndex], ListSortDirection.Ascending);
                    }
                    else
                    {
                        filmDataGridView.Sort(filmDataGridView.Columns[e.ColumnIndex], ListSortDirection.Descending);
                    }
                }
                else
                    filmDataGridView.Sort(filmDataGridView.Columns[e.ColumnIndex], ListSortDirection.Ascending);

                foreach (Control item in tableLayoutPanel4.Controls)
                {
                    if (item.GetType() == new Label().GetType())
                    {
                        if (item.Text.ToLower().Replace(" ", "").Contains(filmDataGridView.Columns[e.ColumnIndex].HeaderText.ToLower().Replace(" ", "")))
                        {
                            if (filmDataGridView.SortOrder == SortOrder.Ascending)
                            {
                                item.Text = "↑" + item.Text;
                                item.Text = item.Text.Replace("↓", "");
                            }
                            else
                            {
                                item.Text = "↓" + item.Text;
                                item.Text = item.Text.Replace("↑", "");
                            }                            
                        }
                        else
                        {
                            item.Text = item.Text.Replace("↑", "");
                            item.Text = item.Text.Replace("↓", "");
                        }
                    }
                }

                filmDataGridView.Refresh();
                changeBackColor();
                RefreshDataFields();
            }
        }

        private void filmDataGridView_CellContentClick(object sender, DataGridViewCellEventArgs e)
        {

        }

        private void filmDataGridView_CellEndEdit(object sender, DataGridViewCellEventArgs e)
        {
            MyFilms[filmDataGridView.CurrentRow.Index].SaveXML();
            Data.Save();
        }

        private void generalSettingsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            var gS = new GeneralSettingsForm();
            gS.ShowDialog();
            this.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            filmBindingNavigator.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            mainFormMenuStrip.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            bindingNavigatorPositionItem.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
        }

        private void filmBindingNavigator_RefreshItems(object sender, EventArgs e)
        {

        }

        private void openDirectoryButtton_Click(object sender, EventArgs e)
        {
            if (filmDataGridView.CurrentRow != null)
            {
                MyFilms[
                    filmDataGridView.CurrentRow.Index].OpenVideoFolder();
            }
        }

        private void playButton_Click(object sender, EventArgs e)
        {
            string[] fileTypes = {
            "*.mpcpl",
            "*.asx",
            "*.mpls",
            "*.mkv", 
            "*.avi",
            "*.divx",
            "*.mpg",
            "*.ogm",
            "*.mpeg",
            "*.ts",
            "*.m2ts",
            "video_ts.ifo",
            "*.nrg",
            "*.iso",
            "*.img",
            "*.wmv",
            "*.mp4"
        };
            selectRowsFromCells();

            if (filmDataGridView.SelectedRows.Count > 1)
            {
                if (MessageBox.Show("Make and play Playlist?",
                    "Playlist",
                    MessageBoxButtons.YesNo,
                    MessageBoxIcon.Question) == System.Windows.Forms.DialogResult.Yes)
                {
                    List<string> myFiles = new List<string>();
                    Films filmList = new Films();
                    foreach (DataGridViewRow item in filmDataGridView.SelectedRows)
                    {
                        filmList.Add(MyFilms[item.Index]);
                        MyFilms[item.Index].LastTimePlayed = DateTime.Now;
                        MyFilms[item.Index].SaveXML();
                        string[] files =
                            Directory.GetFiles(MyFilms[item.Index].Path, fileTypes[0], System.IO.SearchOption.AllDirectories);
                                               
                        int a = 1;

                        while ((files.Count() == 0) & (a < fileTypes.Count()))
                        {
                            files =
                                Directory.GetFiles(MyFilms[item.Index].Path, fileTypes[a], System.IO.SearchOption.AllDirectories);
                            a++;
                            //if (files.Count() > 0 && fileTypes[a] == "*.mpls")
                            //{
                            //    List<string> filesList = new List<string>();
                            //    List<string> folder = new List<string>();
                            //    folder.Add(MyFilms[item.Index].Path);
                            //    filesList.Add(VideoPlaylist.GenerateMPCPL(folder, MyFilms[item.Index].Path));
                            //    files = filesList.ToArray();
                            //}
                        }
                        myFiles.AddRange(files);

                    }
                    var FMP = new MultiPlayForm();
                    FMP.addFilms(myFiles.ToArray(),filmList, Application.CommonAppDataPath);
                    FMP.ShowDialog();
                }
            }
            else
            {
                if (filmDataGridView.CurrentRow != null)
                {
                    MyFilms[
                        filmDataGridView.CurrentRow.Index].OpenVideoInFolder();
                }
            }
            Data.Save();
        }

        private void filmcopyToolStripMenuItem_Click(object sender, EventArgs e)
        {
            var cTF = new CopyToolForm(MyFilms);
            cTF.ShowDialog();
            DataSource = MyFilms;
            filmDataGridView.Refresh();
            changeBackColor();
            RefreshDataFields();
        }

        private void reloadFilmsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            ReloadFilms();
        }

        private void ReloadFilms()
        {
            //filmDataGridView.Rows.Clear();
            Data.ReloadFilms(true);
            MyFilms = Data.DataFilms;
            if (MyFilms != null)
            {
                MyFilms.Sort(TypeDescriptor.GetProperties(new Film())["Filmname"],
                    ListSortDirection.Ascending);
                filmBindingSource.DataSource = MyFilms;
            }
            DataSource = MyFilms;
            filmDataGridView.Refresh();
            changeBackColor();
            RefreshDataFields();
        }        

        private void iMDBLoaderToolStripMenuItem_Click(object sender, EventArgs e)
        {
            selectRowsFromCells();
            IMDBForm frmIMDB = new IMDBForm();
            if (filmDataGridView.SelectedRows.Count > 0)
            {
                var myFilms = new Films();
                foreach (DataGridViewRow item in filmDataGridView.SelectedRows)
                {
                    myFilms.Add(MyFilms[item.Index]);
                }
                frmIMDB.setItemsToChange(myFilms);
            }
            else
            {
                if (filmDataGridView.CurrentRow != null)
                {
                    filmDataGridView.CurrentRow.Selected = true;
                    var myFilms = new Films();
                    foreach (DataGridViewRow item in filmDataGridView.SelectedRows)
                    {
                        myFilms.Add(MyFilms[item.Index]);
                    }
                    frmIMDB.setItemsToChange(myFilms);    
                }
            }

            frmIMDB.ShowDialog();
            filmBindingSource.DataSource = MyFilms;
            filmDataGridView.Refresh();
            filmDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);
            changeBackColor();
            RefreshDataFields();
            frmIMDB.Dispose();
            System.GC.Collect();
        }

        private void RefreshDataFields()
        {
            foreach (Control item in this.Controls)
            {
                if (item.DataBindings.Count == 1)
                {
                    try
                    {
                        item.DataBindings[0].ReadValue();
                    }
                    catch (Exception)
                    {

                    }
                }
            }
        }

        private void filePropertiesToolStripMenuItem_Click(object sender, EventArgs e)
        {
            selectRowsFromCells();
            if ((filmDataGridView.SelectedRows != null) && (filmDataGridView.SelectedRows.Count > 0))
            {
                StatusForm sF = new StatusForm("Getting properties");
                sF.MaxValue = filmDataGridView.SelectedRows.Count;
                sF.AllowCancel = true;
                sF.Show();
                foreach (DataGridViewRow item in filmDataGridView.SelectedRows)
                {
                    sF.Value++;
                    MyFilms[item.Index].GetFileProperties();
                    if (sF.Canceled)
                    {
                        break;
                    }
                }
                sF.Close();
            }
            Data.Save();
            Filter();
            //selectRowsFromCells();
            //var f1 = new FilmFilePropertyForm();
            //string[] strFilmOrdner = new string[1];
            //if (filmDataGridView.SelectedRows.Count > 0)
            //{
            //    strFilmOrdner = new string[filmDataGridView.SelectedRows.Count];
            //    int i = 0;
            //    foreach (DataGridViewRow lviItem in filmDataGridView.SelectedRows)
            //    {
            //        strFilmOrdner[i] = Data.DataFilms[lviItem.Index].Path;
            //        i++;
            //    }

            //}
            //else
            //{
            //    if (filmDataGridView.CurrentRow != null)
            //    {
            //        strFilmOrdner[0] = Data.DataFilms[filmDataGridView.CurrentRow.Index].Path;
            //    }
            //}

            //f1.setFilms(strFilmOrdner);
            //f1.ShowDialog();
            //Filter();
        }

        private void playToolStripMenuItem_Click(object sender, EventArgs e)
        {
            playButton_Click(sender, e);
        }

        private void openDirectoryToolStripMenuItem_Click(object sender, EventArgs e)
        {
            openDirectoryButtton_Click(sender, e);
        }

        private void bindingNavigatorPositionItem_Click(object sender, EventArgs e)
        {

        }

        private void wishlistToolStripMenuItem_Click(object sender, EventArgs e)
        {
            var wLF = new WishListForm();
            wLF.ShowDialog();
        }

        private void iMDBStoryloaderToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (filmDataGridView.CurrentRow != null)
            {
                var iSF = new IMDBStoryLoadForm();
                iSF.FilmIdString = MyFilms[filmDataGridView.CurrentRow.Index].IMDBID;
                iSF.ShowDialog();
            }
        }

        private void excelExportToolStripMenuItem_Click(object sender, EventArgs e)
        {
            var eEF = new ExcelExportForm();
            eEF.ShowDialog();
        }

        private void searchTextBox_TextChanged(object sender, EventArgs e)
        {
            foreach (Film film in MyFilms)
            {
                foreach (var property in film.GetType().GetProperties())
                {
                    if (property.GetValue(film, null) != null)
                    {
                        if (property.GetValue(film, null).ToString().ToUpper().Contains(searchTextBox.Text.ToUpper()))
                        {
                            filmDataGridView.CurrentCell =
                                filmDataGridView.Rows[MyFilms.IndexOf(film)].Cells[0];
                            //filmDataGridView.Refresh();
                            return;
                        }
                    }
                }
            }
        }

        private void filterTextbox_TextChanged(object sender, EventArgs e)
        {
        
        }

        private void filterButton_Click(object sender, EventArgs e)
        {
            Filter();
        }

        private void Filter()
        {
            var result = new Films();
            foreach (Film film in Data.DataFilms)
            {
                foreach (var property in film.GetType().GetProperties())
                {
                    if (property.GetValue(film, null) != null)
                    {
                        if (property.GetValue(film, null).ToString().ToUpper().Contains(filterTextbox.Text.ToUpper()))
                        {
                            result.Add(film);
                            break;
                        }    
                    }
                }
            }
            MyFilms = result;
            filmBindingSource.DataSource = MyFilms;
            filmDataGridView.Refresh();
            changeBackColor();
            RefreshDataFields();
            filmDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);

        }
        

        private void searchTextBox_KeyUp(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Enter)
            {
                Next();
            }
        }

        private void Next()
        {
            if (filmDataGridView.CurrentRow != null)
            {
                for (int i = filmDataGridView.CurrentRow.Index + 1; i < MyFilms.Count; i++)
                {
                    foreach (var property in MyFilms[i].GetType().GetProperties())
                    {
                        if (property.GetValue(MyFilms[i], null) != null)
                        {
                            if (property.GetValue(MyFilms[i], null).ToString().ToUpper().Contains(searchTextBox.Text.ToUpper()))
                            {
                                filmDataGridView.CurrentCell =
                                    filmDataGridView.Rows[i].Cells[0];
                                return;
                            }
                        }
                    }
                }
            }
        }

        private void filterTextbox_KeyUp(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Enter)
            {
                Filter();
            }
        }

        private void nextButton_Click(object sender, EventArgs e)
        {
            Next();
        }

        private void FilmForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            this.WindowState = FormWindowState.Normal;
            Settings.Default.FilmFormSize = this.Size;
            Settings.Default.Save();
        }

        

        private void selectRowsFromCells()
        {
            foreach (DataGridViewCell item in filmDataGridView.SelectedCells)
            {
                item.OwningRow.Selected = true;
            }
        }

        private void columnDontShowToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (filmDataGridView.CurrentCell != null)
            {
                if (Settings.Default.FilmsColumnsNotToShow == null)
                {
                    Settings.Default.FilmsColumnsNotToShow = new System.Collections.Specialized.StringCollection();
                }
                Settings.Default.FilmsColumnsNotToShow.Add(
                    filmDataGridView.CurrentCell.OwningColumn.Name);
                filmDataGridView.Columns.Remove(
                filmDataGridView.CurrentCell.OwningColumn);
                Settings.Default.Save();
            }
        }

        private void columnsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            FilmColumnsForm fCF = new FilmColumnsForm();
            fCF.ShowDialog();
            this.Close();
        }
        
        private void endToolStripMenuItem_Click(object sender, EventArgs e)
        {
            this.Close();
        }
        /// <summary>
        /// if any of the textboxes were changed this will run
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void filmnameTextBox_Validated(object sender, EventArgs e)
        {
            if (filmDataGridView.CurrentRow != null)
            {
                if (MyFilms[filmDataGridView.CurrentRow.Index] != null)
                {
                    MyFilms[filmDataGridView.CurrentRow.Index].SaveXML();
                    Data.Save();
                }
            }
           
            
        }

        static public string[] FilesToStream;


        private void clearStreaminglistToolStripMenuItem_Click(object sender, EventArgs e)
        {
            FilesToStream = null;
        }

        private void streaminglistToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (FilesToStream != null)
            {
                StreamPlayForm sPF = new StreamPlayForm();
                sPF.AddFilms(FilesToStream);
                sPF.ShowDialog();
                FilesToStream = sPF.ReturnFilms();
            }
        }

        private void addToStreaminglistToolStripMenuItem_Click(object sender, EventArgs e)
        {
            List<string> filesToStream = new List<string>();
            if (FilesToStream != null)
            {
                filesToStream.AddRange(FilesToStream);
            }
            selectRowsFromCells();
            if (filmDataGridView.SelectedRows != null)
            {
                foreach (DataGridViewRow item in filmDataGridView.SelectedRows)
                {
                    var myFilm4 = MyFilms[item.Index];
                    filesToStream.AddRange(myFilm4.GetVideoFilePaths());    
                }                
            }
            FilesToStream = filesToStream.ToArray();

        }

        private void streamStreaminglistToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (FilesToStream != null)
            {
                VlcStreaming.PathToVLC = Settings.Default.VlcPath;
                VlcStreaming.Filenames = FilesToStream;
                VlcStreaming.OpenPlaylist_Stream(Settings.Default.VlcStreamingParameter);
            }
        }

        private void streamToolStripMenuItem_Click_1(object sender, EventArgs e)
        {
            if (filmDataGridView.CurrentRow != null)
            {
                var myFilm3 = MyFilms[filmDataGridView.CurrentRow.Index];
                myFilm3.StreamVideoInFolder();
            }

        }

        private void filmDataGridView_MouseDown(object sender, MouseEventArgs e)
        {
            if ((filmDataGridView.CurrentRow != null) && dragActivatedCheckBox.Checked)
            {
                // Get the index of the item the mouse is below.
                indexOfItemUnderMouseToDrag = filmDataGridView.CurrentRow.Index;

                if (indexOfItemUnderMouseToDrag != ListBox.NoMatches)
                {

                    // Remember the point where the mouse down occurred. The DragSize indicates
                    // the size that the mouse can move before a drag event should be started.                
                    Size dragSize = SystemInformation.DragSize;

                    // Create a rectangle using the DragSize, with the mouse position being
                    // at the center of the rectangle.
                    dragBoxFromMouseDown = new Rectangle(new Point(e.X - (dragSize.Width / 2),
                                                                   e.Y - (dragSize.Height / 2)), dragSize);
                }
                else
                    // Reset the rectangle if the mouse is not over an item in the ListBox.
                    dragBoxFromMouseDown = Rectangle.Empty;
            }
        }

        private void filmDataGridView_MouseUp(object sender, MouseEventArgs e)
        {
            // Reset the drag rectangle when the mouse button is raised.
            dragBoxFromMouseDown = Rectangle.Empty;
        }

        private void filmDataGridView_MouseMove(object sender, MouseEventArgs e)
        {
            if ((e.Button & MouseButtons.Left) == MouseButtons.Left)
            {

                // If the mouse moves outside the rectangle, start the drag.
                if (dragBoxFromMouseDown != Rectangle.Empty &&
                    !dragBoxFromMouseDown.Contains(e.X, e.Y))
                {
                    // The screenOffset is used to account for any desktop bands 
                    // that may be at the top or left side of the screen when 
                    // determining when to cancel the drag drop operation.
                    screenOffset = SystemInformation.WorkingArea.Location;

                    // Proceed with the drag-and-drop, passing in the list item.                    
                    selectRowsFromCells();
                    List<string> mF = new List<string>();
                    foreach (DataGridViewRow item in filmDataGridView.SelectedRows)
                    {
                        mF.Add(
                            MyFilms[
                                item.Index].Path);
                    }
                    string[] mf = mF.ToArray();
                    DragDropEffects dropEffect = filmDataGridView.DoDragDrop(
                        new DataObject(DataFormats.FileDrop, mf),
                        DragDropEffects.All | DragDropEffects.Link);

                }
            }
        }

        private void propertyChangerToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (filmDataGridView.CurrentCell != null)
            {
                if (filmDataGridView.SelectedCells.Count == 0)
                {
                    filmDataGridView.CurrentCell.Selected = true;
                }
                new PropertyChangerForm(filmDataGridView.SelectedCells).ShowDialog();
                foreach (DataGridViewCell cell in filmDataGridView.SelectedCells)
                {
                        MyFilms[cell.RowIndex].SaveXML();
                }
                Data.Save();
            }
        }

        private void specialPropertyChangerToolStripMenuItem_Click(object sender, EventArgs e)
        {
            BindingList<SpecialPropertyChanger> myCells = new BindingList<SpecialPropertyChanger>();
            foreach (DataGridViewCell item in filmDataGridView.SelectedCells)
            {
                var myCell = new SpecialPropertyChanger();
                myCell.ValueBeforeChange = item.Value.ToString();
                myCells.Add(myCell);
            }
            var mySPCF = new SpecialPropertyChangerForm();
            mySPCF.MProperties = myCells;
            mySPCF.ShowDialog();

            int i = 0;
            foreach (SpecialPropertyChanger item in myCells)
            {
                filmDataGridView.SelectedCells[i].Value = item.ValueAfterChange;
                MyFilms[filmDataGridView.SelectedCells[i].RowIndex].SaveXML();
                i++;
            }
            Data.Save();
        }

        private void numerateCellsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            int i = filmDataGridView.SelectedCells.Count;
            foreach (DataGridViewCell item in filmDataGridView.SelectedCells)
            {
                item.Value = i;
                i--;
                MyFilms[item.RowIndex].SaveXML();
            }
            Data.Save();
        }

        private void randomFilmToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if ((filmDataGridView.Rows != null) && (filmDataGridView.Rows.Count > 0))
            {
                Random r = new Random();
                filmDataGridView.CurrentCell = filmDataGridView.Rows[r.Next(0, filmDataGridView.Rows.Count)].Cells[0];
            }
        }

        private void toolStripButton2_Click(object sender, EventArgs e)
        {
            new MusikForm().Show();
            this.Close();
        }

        private void toolStripButton3_Click(object sender, EventArgs e)
        {
            new SeriesForm().Show();
            this.Close();
        }

        private void iMDBLoader2ToolStripMenuItem_Click(object sender, EventArgs e)
        {
            selectRowsFromCells();
            if (filmDataGridView.SelectedRows != null)
            {
                IMDBLoaderForm loaderForm = new IMDBLoaderForm();
                foreach (DataGridViewRow item in filmDataGridView.SelectedRows)
                {
                    loaderForm.AddFilm(MyFilms[item.Index]);
                }
                loaderForm.ShowDialog();
                Filter();                
            }
        }


        private void streamingButton_Click(object sender, EventArgs e)
        {
            streamingContextMenuStrip.Show(streamingButton, new Point(streamingButton.Width, 0));
        }

        private void streamingContextMenuStrip_Opening(object sender, CancelEventArgs e)
        {

        }

        private void openInIMDBToolStripMenuItem_Click(object sender, EventArgs e)
        {
            selectRowsFromCells();
            if (filmDataGridView.SelectedRows != null)
            {
                foreach (DataGridViewRow item in filmDataGridView.SelectedRows)
                {
                    Process.Start("http://www.imdb.com/title/" + MyFilms[item.Index].IMDBID + "/");
                }
            }
        }

        private void statisticToolStripMenuItem_Click(object sender, EventArgs e)
        {
            new StatisticForm().Show();
        }

        private void filmDataGridView_CellDoubleClick(object sender, DataGridViewCellEventArgs e)
        {
            playButton_Click(sender, new EventArgs());
        }

        private void GenreTextBox_TextChanged(object sender, EventArgs e)
        {

        }

        private void fileTypeTextBox_TextChanged(object sender, EventArgs e)
        {

        }

        private void sizeMBTextBox_TextChanged(object sender, EventArgs e)
        {

        }

        private void iMDBIDTextBox_TextChanged(object sender, EventArgs e)
        {

        }

        private void iMDBRatingTextBox_TextChanged(object sender, EventArgs e)
        {

        }

        private void widthTextBox_TextChanged(object sender, EventArgs e)
        {

        }

        private void heightTextBox_TextChanged(object sender, EventArgs e)
        {

        }

        private void lengthTextBox_TextChanged(object sender, EventArgs e)
        {

        }

        private void filmDataGridView_CurrentCellChanged(object sender, EventArgs e)
        {            
            
        }

        private void newPropertiesToolStripMenuItem_Click(object sender, EventArgs e)
        {
           
        }

        private void filmDataGridView_DataError(object sender, DataGridViewDataErrorEventArgs e)
        {

        }

        private void tableLayoutPanel4_MouseClick(object sender, MouseEventArgs e)
        {
            
        }

        private void sortByLabel_Click(object sender, EventArgs e)
        {
            Label myLabel = (Label)sender;
            string myText = myLabel.Text.Replace(":", "").Replace("↑", "").Replace("↓", "").Replace(" ","").ToLower();
            int columnIndex = -1;

            foreach (DataGridViewColumn item in filmDataGridView.Columns)
            {
                if (item.HeaderText.Replace(" ", "").ToLower().Contains(myText))
                {
                    if (filmDataGridView.SortOrder == SortOrder.Ascending)
                    {
                        filmDataGridView.Sort(item, ListSortDirection.Descending);    
                    }
                    else
                    {
                        filmDataGridView.Sort(item, ListSortDirection.Ascending);
                    }
                    columnIndex = item.Index;
                }
            }

            if (columnIndex > -1)
            {
                foreach (Control item in tableLayoutPanel4.Controls)
                {
                    if (item.GetType() == new Label().GetType())
                    {
                        if (item.Text.ToLower().Replace(" ","").Contains(filmDataGridView.Columns[columnIndex].HeaderText.ToLower().Replace(" ","")))
                        {
                            if (filmDataGridView.SortOrder == SortOrder.Ascending)
                            {
                                item.Text = "↑" + item.Text;
                                item.Text = item.Text.Replace("↓", "");
                            }
                            else
                            {
                                item.Text = "↓" + item.Text;
                                item.Text = item.Text.Replace("↑", "");
                            }
                        }
                        else
                        {
                            item.Text = item.Text.Replace("↑", "");
                            item.Text = item.Text.Replace("↓", "");
                        }
                    }
                }
            }

        }

        private void resetOnlyPlayThisFileToolStripMenuItem_Click(object sender, EventArgs e)
        {
            selectRowsFromCells();
            foreach (DataGridViewRow item in filmDataGridView.SelectedRows)
            {
                MyFilms[item.Index].OnlyPlayFilePath = null;
            }

        }

        private void deleteMovieFromListToolStripMenuItem_Click(object sender, EventArgs e)
        {
            selectRowsFromCells();
            if (
                MessageBox.Show(String.Format("Are you sure, you want to delete {0} film(s)?",filmDataGridView.SelectedRows.Count),
                "Delete",
                MessageBoxButtons.YesNo,
                MessageBoxIcon.Question)
                == 
                System.Windows.Forms.DialogResult.Yes)
            {
                foreach (DataGridViewRow item in filmDataGridView.SelectedRows)
                {
                    if (Settings.Default.DeletedMovies == null)
                    {
                        Settings.Default.DeletedMovies = new System.Collections.Specialized.StringCollection();
                    }
                    Settings.Default.DeletedMovies.Add(MyFilms[item.Index].Path);
                    Data.DataFilms.Remove(MyFilms[item.Index]);
                }
                Data.Save();
                DataSource = MyFilms;
                filmDataGridView.Refresh();
                changeBackColor();
                RefreshDataFields();                
            }            
        }

        private void deleteMovieFromListDiskToolStripMenuItem_Click(object sender, EventArgs e)
        {
            selectRowsFromCells();
            if (
                MessageBox.Show(String.Format("Are you sure, you want to delete {0} film(s)? \nYou can't recover it!", filmDataGridView.SelectedRows.Count),
                "Delete",
                MessageBoxButtons.YesNo,
                MessageBoxIcon.Question)
                ==
                System.Windows.Forms.DialogResult.Yes)
            {
                foreach (DataGridViewRow item in filmDataGridView.SelectedRows)
                {
                    try
                    {
                        Directory.Delete(MyFilms[item.Index].Path,true);
                    }
                    catch (Exception ex)
                    {

                        MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    }
                    Data.DataFilms.Remove(MyFilms[item.Index]);        
                }
                Data.Save();
                DataSource = MyFilms;
                filmDataGridView.Refresh();
                changeBackColor();
                RefreshDataFields();
            }
        }

        private void deletedFilmsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            new DeletedFilmsForm().ShowDialog();
            ReloadFilms();
        }

        private void resetPlaylistToolStripMenuItem_Click(object sender, EventArgs e)
        {
            selectRowsFromCells();
            if (filmDataGridView.SelectedRows.Count > 0)
            {
                foreach (DataGridViewRow item in filmDataGridView.SelectedRows)
                {
                    MyFilms[item.Index].ResetPlayList();
                }
            }
        }

        private void testToolStripMenuItem_Click(object sender, EventArgs e)
        {

        }

        private void changeBackColor()
        {
            bool changeColor = false;
            foreach (DataGridViewRow item in filmDataGridView.Rows)
            {
                if (changeColor)
                {
                    item.DefaultCellStyle.BackColor = Color.AntiqueWhite;
                    changeColor = false;
                }
                else
                {
                    item.DefaultCellStyle.BackColor = Color.White;
                    changeColor = true;
                }

            }
        }

    }
}
