﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using ThiesMediaProject.Properties;
using ThiesMediaProject.SettingForms;
using System.Xml.Serialization;
using System.IO;
using System.Windows.Forms;
using ThiesGeneral.MsOffice;
using System.Diagnostics;
using System.Xml;

namespace ThiesMediaProject.General
{
    static public class Data
    {
        static public Films DataFilms { get; set; }
        static public SeriesList DataSeriesList { get; set; }
        static public MusikList DataMusikList { get; set; }

        public static void InitData()
        {
            if (File.Exists(Application.LocalUserAppDataPath + @"\appdata.xml"))
            {
                Load();
            }
            else
            {
                DataFilms = new Films(Settings.Default.Paths,true);
                DataSeriesList = new SeriesList(Settings.Default.SeriesPaths,true);
                DataMusikList = new MusikList(Settings.Default.MusikPaths,true);
                Save();
            }
            
        }

        public static void ReloadFolder()
        {
            ReloadFilms(false);
            ReloadSeries(false);
            ReloadMusik(false);
            Save();
        }

        public static void ReloadFilms(bool save)
        {
            DataFilms = new Films(Settings.Default.Paths,true);
            if (save)
            {
                Save();
            }
        }

        public static void ReloadSeries(bool save)
        {
            DataSeriesList = new SeriesList(Settings.Default.SeriesPaths,true);
            if (save)
            {
                Save();
            }
        }

        public static void ReloadMusik(bool save)
        {
            DataMusikList = new MusikList(Settings.Default.MusikPaths,true);
            if (save)
            {
                Save();
            }
        }


        public static void Save()
        {
            try
            {
                var sT = new StreamWriter(Application.LocalUserAppDataPath + @"\appdata.xml", false);
                var xS = new XmlSerializer(typeof(DataMemory));
                var dM = new DataMemory(DataFilms, DataSeriesList, DataMusikList);
                xS.Serialize(sT, dM);
                sT.Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        public static void Load()
        {
            try
            {
                
                var sT = new StreamReader(Application.LocalUserAppDataPath + @"\appdata.xml");
                var xmlsT = new XmlTextReader(sT);
                XmlSerializer xS = new XmlSerializer(typeof(DataMemory));

                var dM = new DataMemory(DataFilms, DataSeriesList, DataMusikList);

                dM = (DataMemory)xS.Deserialize(xmlsT);
                DataFilms = dM.DataFilms;
                DataSeriesList = dM.DataSeriesList;
                DataMusikList = dM.DataMusikList;
                sT.Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        public static void ExportFilmsToExcel(string fileNamePar,bool openFileAfterExport)
        {
            var film = new Film();
            string[] headers = new string[film.GetType().GetProperties().Count()];
            string[,] data = new string[
                                    film.GetType().GetProperties().Count(),
                                    DataFilms.Count()];
            int a = 0;
            int i = 0;

            foreach (var property in film.GetType().GetProperties())
            {
                if (
                    (property.Name != "FilmID") && 
                    (property.Name != "SortingProperty") &&
                    (property.Name != "PictureByteArray") &&
                    (property.Name != "FilmPicture") &&
                    (property.Name != "Genere")
                    )
                {
                    headers[i] = property.Name;
                    i++;
                }
            }



            a = 0;
            foreach (Film film2 in DataFilms)
            {
                i = 0;
                foreach (var property in film2.GetType().GetProperties())
                {
                    if (
                     (property.Name != "FilmID") &&
                     (property.Name != "SortingProperty") &&
                     (property.Name != "PictureByteArray") &&
                     (property.Name != "FilmPicture") &&
                     (property.Name != "Genere")
                    )
                    {
                        if ((property.GetValue(film2, null) != null))
                        {
                            if ((property.GetValue(film2, null).GetType() != typeof(System.Drawing.Bitmap)))
                            {
                                data[i, a] = property.GetValue(film2, null).ToString();
                            }
                        }
                        i++;
                    }
                }
                i = 0;
                a++;
            }


            var mE = new MyExcel("Films", headers, data, fileNamePar, false);
            if (openFileAfterExport)
            {
                if (MessageBox.Show("Open Excel now?", "Open Excel", MessageBoxButtons.YesNo) == DialogResult.Yes)
                {
                    mE = null;
                    Process.Start("Explorer.exe", fileNamePar);
                }
            }
            
        }

        public static void ExportSeriesToExcel(string fileNamePar, bool openFileAfterExport)
        {
            var series = new Series();
            string[] headers = new string[series.GetType().GetProperties().Count()];
            string[,] data = new string[
                                    series.GetType().GetProperties().Count(),
                                    DataFilms.Count()];
            int a = 0;
            int i = 0;

            foreach (var property in series.GetType().GetProperties())
            {
                headers[i] = property.Name;
                i++;
            }



            a = 0;
            foreach (Series series2 in DataSeriesList)
            {
                i = 0;
                foreach (var property in series2.GetType().GetProperties())
                {
                    if ((property.GetValue(series2, null) != null))
                    {
                        if ((property.GetValue(series2, null).GetType() != typeof(System.Drawing.Bitmap)))
                        {
                            data[i, a] = property.GetValue(series2, null).ToString();
                        }
                    }
                    i++;
                }
                i = 0;
                a++;
            }


            var mE = new MyExcel("Films", headers, data, fileNamePar, false);
            if (openFileAfterExport)
            {
                if (MessageBox.Show("Open Excel now?", "Open Excel", MessageBoxButtons.YesNo) == DialogResult.Yes)
                {
                    mE = null;
                    Process.Start("Explorer.exe", fileNamePar);
                }
            }

        }
    }
}
