﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.Drawing;
using System.Linq;
using System.Text;
using System.IO;
using ThiesGeneral.FileFunctions;
using System.ComponentModel;
using System.Xml.Serialization;
using System.Windows.Forms;
using System.Diagnostics;
using ThiesMediaProject.ToolForms;
using System.Threading;
using ThiesGeneral.Media.VLC_Streaming;
using ThiesMediaProject.Properties;
using ThiesGeneral.Media.Video;
using ThiesMediaProject.MedInfo;

namespace ThiesMediaProject.General
{
    public class Film
    {
        string filmName;
        string length;
        string[] fileTypes = {
            "*.mpcpl",
            "*.asx",
            "*.mpls",
            "*.mkv", 
            "*.avi",
            "*.divx",
            "*.mpg",
            "*.ogm",
            "*.mpeg",
            "*.ts",
            "*.m2ts",
            "video_ts.ifo",
            "*.nrg",
            "*.iso",
            "*.img",
            "*.wmv",
            "*.mp4"
        };

        public string Filmname
        {
            get
            {
                if (filmName != null)
                {
                    return filmName.Replace("\0", ""); ;
                }
                return "";
            }
            set
            {
                filmName = value;
            }
        }

        public string FilmID { get; set; }
        public string Path { get; set; }
        public long SizeMB { get; set; }
        public DateTime DateCreated { get; set; }
        public string FileType { get; set; }
        public string IMDBID { get; set; }
        public int YearOfPrime { get; set; }
        public string Genre { get; set; }
        public string Genere 
        {
            get
            {
                return Genre;
            }
            set
            {
                Genre = value;
            }
        }
        public string Regie { get; set; }
        public string Actors { get; set; }
        public int Width { get; set; }
        public int Height { get; set; }
        public string Length
        {
            get
            {
                return length;
            }
            set
            {
                length = value;
            }
        }
        public string OnlyPlayFilePath { get; set; }
        public DateTime LastTimePlayed { get; set; }
        public string AudioLanguages { get; set; }
        public int VideoBitrate { get; set; }
        public string AudioBitrate { get; set; }
        public int AudioStreams { get; set; }
        public string AudioCodec { get; set; }
        public string VideoCodec { get; set; }
        public string AudioChannels { get; set; }
        public decimal YourRating { get; set; }
        public string Comment { get; set; }

        public string IMDBRating { get; set; }

        [XmlIgnoreAttribute()]
        public Bitmap FilmPicture 
        {
            get
            {
                return MyFilmPicture;
            }
        }

        public void SetMyFilmPicture(Bitmap myFilmPicture)
        {
            MyFilmPicture = myFilmPicture;
        }

        Bitmap MyFilmPicture;



        // Serializes the 'Picture' Bitmap to XML.
        [XmlElementAttribute("Picture")]
        public byte[] PictureByteArray
        {
            get
            {
                if (FilmPicture != null)
                {
                    TypeConverter BitmapConverter =
                         TypeDescriptor.GetConverter(FilmPicture.GetType());
                    return (byte[])
                         BitmapConverter.ConvertTo(FilmPicture, typeof(byte[]));
                }
                else
                    return null;
            }

            set
            {
                if (value != null)
                    SetMyFilmPicture(new Bitmap(new MemoryStream(value)));
                else
                    SetMyFilmPicture(null);
            }
        }


        public object SortingProperty { get; set; }




        /// <summary>
        /// Initial Constructor
        /// </summary>
        public Film()
        {
            FilmID = String.Empty;
            InitProperties();   
        }

        public Film(string filmID)
        {
            FilmID = filmID;
            InitProperties();   
        }

        private void InitProperties()
        {
            Filmname = String.Empty;
            Path = String.Empty;
            SizeMB = 0;
            DateCreated = DateTime.Now;
            FileType = String.Empty;
            IMDBID = String.Empty;
            YearOfPrime = 0;
            Genre = String.Empty;
            Regie = String.Empty;
            Actors = String.Empty;
            Width = 0;
            Height = 0;
            IMDBRating = string.Empty;
            Length = "00:00:00";
            SortingProperty = null;
            SetMyFilmPicture(null);
            OnlyPlayFilePath = string.Empty;
            LastTimePlayed = DateTime.MinValue;
            AudioLanguages = string.Empty;
            AudioBitrate = "";
            AudioCodec = string.Empty;
            VideoBitrate = 0;
            AudioChannels = string.Empty;
        }


        /// <summary>
        /// Constructor with path of directory
        /// </summary>
        /// <param name="path">Path of Folder</param>
        public Film(string path, string filmID)
        {

            if (Directory.Exists(path))
            {
                Path = path;
                GetFilmDirectoryInfo();
                if (File.Exists(Path + @"\" + Application.ProductName + ".xml"))
                {
                    LoadXML();
                    if ((FilmID == null) ||
                        (FilmID == ""))
                    {
                        FilmID = filmID;
                        SaveXML();
                    }
                }
                else
                {
                    FilmID = filmID;
                    GetFilmDbTxtInfo();
                    SaveXML();
                }
            }
            else
            {

            }
        }

        /// <summary>
        /// Get info from directory of film
        /// </summary>
        public void GetFilmDirectoryInfo()
        {
            Filmname = Folder.GetFolderName(Path);
            SizeMB = Folder.GetFolderSize(Path) / 1024 / 1024;
            DateCreated = Folder.GetFolderCreationTime(Path);
            FileType = Folder.GetFilmTypeByFolder(Path);
        }


        /// <summary>
        /// ReadOldFilmdbFiles
        /// </summary>
        public void GetFilmDbTxtInfo()
        {
            if (File.Exists(Path + @"\filmdbinfo.txt"))
            {
                string strZeile;
                var streReader = new StreamReader(Path + @"\filmdbinfo.txt", Encoding.UTF8);
                strZeile = streReader.ReadLine();
                while ((strZeile != null) && (strZeile != ""))
                {
                    PropertyDescriptorCollection properties = TypeDescriptor.GetProperties(this);
                    foreach (PropertyDescriptor myProperty in properties)
                    {
                        if (strZeile.Substring(strZeile.IndexOf("=") + 1) != "")
                        {
                            if (strZeile.Substring(0, strZeile.IndexOf("=")) == "Dateityp")
                                this.FileType = strZeile.Substring(strZeile.IndexOf("=") + 1).Trim();
                            else if (strZeile.Substring(0, strZeile.IndexOf("=")) == "Premieredatum")
                                this.YearOfPrime = int.Parse(strZeile.Substring(strZeile.IndexOf("=") + 1).Trim());
                            else if (strZeile.Substring(0, strZeile.IndexOf("=")) == "IMDB-ID")
                                this.IMDBID = strZeile.Substring(strZeile.IndexOf("=") + 1).Trim();
                            else if (strZeile.Substring(0, strZeile.IndexOf("=")) == "Genres")
                                this.Genre = strZeile.Substring(strZeile.IndexOf("=") + 1).Trim();
                            else if (strZeile.Substring(0, strZeile.IndexOf("=")) == "Darsteller")
                                this.Actors = strZeile.Substring(strZeile.IndexOf("=") + 1).Trim();
                            else if (strZeile.Substring(0, strZeile.IndexOf("=")) == "IMDB-Wertung")
                                this.IMDBRating = strZeile.Substring(strZeile.IndexOf("=") + 1).Trim();
                            else if (strZeile.Substring(0, strZeile.IndexOf("=")) == "Länge")
                                this.Length = strZeile.Substring(strZeile.IndexOf("=") + 1).Trim();
                            else if (strZeile.Substring(0, strZeile.IndexOf("=")) == "Breite")
                                this.Width = int.Parse(strZeile.Substring(strZeile.IndexOf("=") + 1).Trim());
                            else if (strZeile.Substring(0, strZeile.IndexOf("=")) == "Höhe")
                                this.Height = int.Parse(strZeile.Substring(strZeile.IndexOf("=") + 1).Trim());
                            else if (strZeile.Substring(0, strZeile.IndexOf("=")) == myProperty.Name)
                            {
                                myProperty.SetValue(this, strZeile.Substring(strZeile.IndexOf("=") + 1).Trim());
                            }
                        }
                    }
                    strZeile = streReader.ReadLine();
                }
                streReader.Close();
            }
        }

        public void SaveXML()
        {
            var sT = new StreamWriter(Path + @"\" + Application.ProductName + ".xml", false);
            var xS = new XmlSerializer(typeof(Film));
            xS.Serialize(sT, this);
            sT.Close();
        }

        public void LoadXML()
        {
            GetFilmDirectoryInfo();
            try
            {
                var sT = new StreamReader(Path + @"\" + Application.ProductName + ".xml");
                var xS = new XmlSerializer(typeof(Film));
                var film = (Film)xS.Deserialize(sT);
                PropertyDescriptorCollection properties = TypeDescriptor.GetProperties(this);
                foreach (PropertyDescriptor myProperty in properties)
                {
                    switch (myProperty.Name)
                    {
                        case "Path":
                        case "SizeMB":
                        case "DateCreated":
                        case "FileType":
                            break;
                        default:
                            myProperty.SetValue(this, myProperty.GetValue(film));
                            break;
                    }

                }
                sT.Close();
            }
            catch (Exception)
            {
                
            }
            
            
        }

        public void OpenVideoFolder()
        {
            Process.Start("explorer.exe", Path);
        }

        public void OpenVideoInFolder()
        {
            
            string[] files =
                Directory.GetFiles(Path, fileTypes[0], System.IO.SearchOption.AllDirectories);
            int a = 1;

            while ((files.Count() == 0) & (a < fileTypes.Count()))
            {
                files =
                    Directory.GetFiles(Path, fileTypes[a], System.IO.SearchOption.AllDirectories);
                //if (files.Count() > 0 && fileTypes[a] == "*.mpls")
                //{
                //    List<string> filesList = new List<string>();
                //    List<string> folder = new List<string>();
                //    folder.Add(this.Path);
                //    filesList.Add(VideoPlaylist.GenerateMPCPL(folder, this.Path));
                //    files = filesList.ToArray();
                //}
                a++;
            }
            
            if (files.Count() > 0)
            {
                this.LastTimePlayed = DateTime.Now;
                this.SaveXML();
                Data.Save();
                if (files.Count() == 1)
                {
                    MyFile.StartFile(files[0], Settings.Default.DaemonToolsPath);
                }
                else
                {
                    if ((this.OnlyPlayFilePath != null) && (this.OnlyPlayFilePath != ""))
                    {
                        MyFile.StartFile(this.OnlyPlayFilePath, Settings.Default.DaemonToolsPath);
                    }
                    else
                    {
                        Films filmList = new Films();
                        filmList.Add(this);
                        var FMP = new MultiPlayForm();
                        FMP.addFilms(files, filmList, Path);
                        FMP.ShowDialog();
                    }                    
                }
            }
            else
            {
                MessageBox.Show("Keine Videodatei gefunden!", "Keine Datei", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        internal void StreamVideoInFolder()
        {
            string[] fileTypes2 = {
            "*.mkv", 
            "*.avi",
            "*.divx",
            "*.mpg",
            "*.ogm",
            "*.mpeg",
            "*.ts",
            "*.m2ts",
            "video_ts.ifo",
            "*.nrg",
            "*.iso",
            "*.img",
            "*.wmv",
            "*.mp4"
             };
            string[] files =
                Directory.GetFiles(Path, fileTypes2[0], System.IO.SearchOption.AllDirectories);
            int a = 1;

            while ((files.Count() == 0) & (a < fileTypes.Count()))
            {
                files =
                    Directory.GetFiles(Path, fileTypes2[a], System.IO.SearchOption.AllDirectories);
                a++;
            }



            if (files.Count() > 0)
            {
                this.LastTimePlayed = DateTime.Now;
                this.SaveXML();
                Data.Save();
                if (files.Count() == 1)
                {                    
                    VlcStreaming.PathToVLC = Settings.Default.VlcPath;
                    VlcStreaming.Filename = files[0];
                    VlcStreaming.Open_Stream(Settings.Default.VlcStreamingParameter);
                }
                else
                {
                    VlcStreaming.Filenames = files;                    
                    VlcStreaming.PathToVLC = Settings.Default.VlcPath;
                    VlcStreaming.OpenPlaylist_Stream(Settings.Default.VlcStreamingParameter);
                }
            }
            else
            {
                MessageBox.Show("Keine Videodatei gefunden!", "Keine Datei", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        public string GetVideoFilePath()
        {
            string[] files =
                Directory.GetFiles(Path, fileTypes[0], System.IO.SearchOption.AllDirectories);
            int a = 1;

            while ((files.Count() == 0) & (a < fileTypes.Count()))
            {
                files =
                    Directory.GetFiles(Path, fileTypes[a], System.IO.SearchOption.AllDirectories);
                a++;
            }
            return files[0];
        }

        public string[] GetVideoFilePaths()
        {
            string[] fileTypes2 = {
            "*.mkv", 
            "*.avi",
            "*.divx",
            "*.mpg",
            "*.ogm",
            "*.mpeg",
            "*.ts",
            "*.m2ts",
            "video_ts.ifo",
            "*.nrg",
            "*.iso",
            "*.img",
            "*.wmv",
            "*.mp4"
             };
            string[] files =
                Directory.GetFiles(Path, fileTypes2[0], System.IO.SearchOption.AllDirectories);
            int a = 1;

            while ((files.Count() == 0) & (a < fileTypes2.Count()))
            {
                files =
                    Directory.GetFiles(Path, fileTypes2[a], System.IO.SearchOption.AllDirectories);
                a++;
            }
            return files;
        }

        public void GetFileProperties()
        {            
            string[] fileTypes2 = {
            "*.mkv", 
            "*.avi",
            "*.divx",
            "*.mpg",
            "*.ogm",
            "*.mpeg",
            "*.ts",
            "*.m2ts",
            "*.vob",            
            "*.wmv",
            "*.mp4"
             };
            string[] files =
                Directory.GetFiles(Path, fileTypes2[0], System.IO.SearchOption.AllDirectories);
            int a = 1;

            while ((files.Count() == 0) & (a < fileTypes2.Count()))
            {
                files =
                    Directory.GetFiles(Path, fileTypes2[a], System.IO.SearchOption.AllDirectories);
                a++;
            }



            if (files.Count() > 0)
            {
                if (files.Count() == 1)
                {
                    GetFilePropertiesSub(files[0]);
                }
                else
                {
                    int i = 0;
                    int b = 0;
                    long mySize = 0;
                    TimeSpan myLength = TimeSpan.Zero;
                    foreach (string item in files)
                    {
                        FileInfo fi = new FileInfo(item);
                        if (mySize < fi.Length)
                        {
                            mySize = fi.Length;
                            i = b;                            
                        }
                        try
                        {
                            MediaInfo MI = new MediaInfo();
                            MI.Open(item);
                            myLength += Convert.ToDateTime(MI.Get(StreamKind.Video, 0, "Duration/String3")).TimeOfDay;
                        }
                        catch (Exception) { }
                        b++;
                    }
                    GetFilePropertiesSub(files[i]);
                    this.Length = myLength.ToString(@"hh\:mm\:ss");
                }
                this.SaveXML();
            }                        
        }

        public void GetFilePropertiesSub(string filePath)
        {
            MediaInfo MI = new MediaInfo();
            MI.Open(filePath);
            this.VideoCodec = MI.Get(0, 0, "Video_Format_WithHint_List");
            try
            {
                this.Width = Convert.ToInt32(MI.Get(StreamKind.Video, 0, "Width"));
            }
            catch (Exception) { }
            try
            {
                this.Height = Convert.ToInt32(MI.Get(StreamKind.Video, 0, "Height"));
            }
            catch (Exception) { }
            try
            {
                this.Length = Convert.ToDateTime(MI.Get(StreamKind.Video, 0, "Duration/String3")).TimeOfDay.ToString(@"hh\:mm\:ss");
            }
            catch (Exception) { }
            try
            {
                this.VideoBitrate = Convert.ToInt32(MI.Get(StreamKind.Video, 0, "BitRate"));
            }
            catch (Exception) { }
            try
            {
                this.AudioStreams = Convert.ToInt32(MI.Get(StreamKind.Audio, 0, "StreamCount"));
            }
            catch (Exception) { }
            
            
            
            
            
            
            this.AudioLanguages = string.Empty;
            this.AudioBitrate = string.Empty;
            this.AudioCodec = string.Empty;
            for (int i = 0; i < this.AudioStreams; i++)
            {
                this.AudioLanguages += MI.Get(StreamKind.Audio, i, "Language") + "|";
                try
                {
                    this.AudioBitrate += Convert.ToInt32(MI.Get(StreamKind.Audio, i, "BitRate")) + "|";
                }
                catch (Exception){}
                try
                {
                    this.AudioChannels += Convert.ToInt32(MI.Get(StreamKind.Audio, i, "Channel(s)")) + "|";
                }
                catch (Exception) { }                
                this.AudioCodec += MI.Get(StreamKind.Audio, i, "Format") + "|";
            }                                       
        }

        public void ResetPlayList()
        {
            File.Delete(this.Path + "\\playlist.mpcpl");
            File.Delete(this.Path + "\\playlist.asx");
        }
    }
}