﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO;
using ThiesGeneral.Media.Musik;
using System.Diagnostics;
using ThiesGeneral.FileFunctions;

namespace ThiesMediaProject.General
{
    public class MusikFile
    {
        string[] fileTypes = {
            "*.mp3",
            "*.wma"
        };

        public string Artist { get; set; }
        public string Titel { get; set; }
        public string Album { get; set; }
        public string TitelNo { get; set; }
        public string Year { get; set; }
        public string Genre { get; set; }
        public string MusicFileId { get; set; }
        public string FilePath { get; set; }
        public long SizeMB { get; set; }
        public DateTime DateCreated { get; set; }
        public string FileType { get; set; }
        public string Length { get; set; }
        
        public string Genere
        {
            get
            {
                return Genre;
            }
            set
            {
                Genre = value;
            }
        }

        public object SortingProperty { get; set; }

        public MusikFile()
        {
            MusicFileId = MusikList.GetNewMusicFileId();
            FilePath = string.Empty;
            SizeMB = 0;
            DateCreated = DateTime.Now;
            FileType = string.Empty;
            Artist = string.Empty;
            Titel = string.Empty;
            Album = string.Empty;
            TitelNo = string.Empty;
            Year = string.Empty;
            Genre = string.Empty;
            SortingProperty = string.Empty;
            Length = "00:00:00";
        }

        /// <summary>
        /// Constructor with path of directory
        /// </summary>
        /// <param name="filePath">Path of Folder</param>
        /// 

        public MusikFile(string filePath,bool getLength)
        {
            MusicFileId = MusikList.GetNewMusicFileId();
            FilePath = filePath;
            if (File.Exists(filePath))
            {
                Mp3.ReadMp3Tag(filePath);
                Album = Mp3.Album;
                Artist = Mp3.Artist;
                Titel = Mp3.Title;
                Album = Mp3.Album;
                TitelNo = Mp3.TrackNumber;
                Year = Mp3.Year;
                Genre = Mp3.Genre;
                SizeMB = new FileInfo(filePath).Length / 1024 / 1024;
                DateCreated = new FileInfo(filePath).CreationTime;
                FileType = new FileInfo(filePath).Extension;
                Length = Mp3.Length;
                if (getLength)
                {
                    try
                    {
                        Length = new DateTime(Convert.ToInt64(10000000 * Mp3.GetLength(filePath))).TimeOfDay.ToString("hh':'mm':'ss");
                        Mp3.WriteMp3Tag();
                    }
                    catch (Exception)
                    {

                    }    
                }
            }
        }

        public void WriteToFile()
        {
            Mp3.FilePath = FilePath;
            Mp3.Album = Album;
            Mp3.Artist = Artist;
            Mp3.Title = Titel;
            Mp3.Album = Album;
            Mp3.TrackNumber = TitelNo;
            Mp3.Year = Year;
            Mp3.Genre = Genre;
            Mp3.Length = Length;
            Mp3.WriteMp3Tag();
        }

        public void OpenMusikFolder()
        {
            
            Process.Start("explorer.exe", new FileInfo(FilePath).Directory.FullName);
        }

        public void OpenMusikFile()
        {
            Process.Start("explorer.exe", FilePath);
        }
    }
}
