﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;
using System.Collections.Specialized;
using System.IO;
using System.Threading;
using ThiesMediaProject.ToolForms;
using System.Windows.Forms;

namespace ThiesMediaProject.General
{
    public class MusikList : BindingList<MusikFile>
    {


        public StringCollection GlobalMusikPaths { get; set; }

        bool IsSorted = false;
        ListSortDirection LastSortDirection = ListSortDirection.Ascending;
        string lastPropertySorted = string.Empty;

        /// <summary>
        /// empty Constructor
        /// </summary>
        public MusikList()
        {

        }


        /// <summary>
        /// Constructor for adding films automaticly
        /// </summary>
        /// <param name="globalFilmPaths">list of global film directories</param>
        public MusikList(StringCollection globalMusikPaths, bool showDialog)
        {
            GlobalMusikPaths = globalMusikPaths;
            GetMusikFilesFromGlobalMusikPaths(showDialog);
        }


        /// <summary>
        /// for each path of directory found in global path a film item will be added
        /// </summary>
        public void GetMusikFilesFromGlobalMusikPaths(bool showDialog)
        {            
            var sF = new StatusForm("Loading Music");
            sF.AllowCancel = true;

            foreach (string globalPath in GlobalMusikPaths)
            {
                string[] musikFolders = Directory.GetDirectories(globalPath);
                if (showDialog)
                {
                    sF.MaxValue = Directory.GetFiles(globalPath, "*.mp3", SearchOption.AllDirectories).Count();
                    sF.Show();
                }
                
                foreach (string musikFolder in musikFolders)
                {
                    if (
                               !(new DirectoryInfo(musikFolder).Attributes.HasFlag(FileAttributes.System)) &&
                               !(new DirectoryInfo(musikFolder).Attributes.HasFlag(FileAttributes.ReadOnly)) &&
                               !(new DirectoryInfo(musikFolder).Attributes.HasFlag(FileAttributes.Hidden))
                               )
                    {
                        foreach (string musikFileName in Directory.GetFiles(musikFolder, "*.mp3", SearchOption.AllDirectories))
                        {
                            if (showDialog)
                            {
                                sF.Value++;
                            }
                            Application.DoEvents();
                            var musikfile = new MusikFile(musikFileName, false);
                            this.Add(musikfile);
                            if (showDialog)
                            {
                                if (sF.Canceled)
                                {
                                    sF.Value = 0;
                                    sF.Close();
                                    return;
                                }
                            }
                        }
                    }
                }
                if (showDialog)
                {
                    sF.Value = 0;
                    sF.Close();
                }
            }
        }

        protected override bool SupportsSortingCore
        {
            get
            {
                return true;
            }
        }

        public void Sort(PropertyDescriptor prop, ListSortDirection direction)
        {
            ApplySortCore(prop, direction);
        }

        protected override void ApplySortCore(PropertyDescriptor prop, ListSortDirection direction)
        {
            foreach (MusikFile musikFile in this)
            {
                musikFile.SortingProperty = prop.GetValue(musikFile);
            }
            IEnumerable<MusikFile> query;

            if (direction == ListSortDirection.Ascending)
            {
                query = this.OrderBy(musikFile => musikFile.SortingProperty);
            }
            else
            {
                query = this.OrderByDescending(musikFile => musikFile.SortingProperty);
            }

            int i = 0;
            foreach (MusikFile musikFile in query)
            {
                this.Items[i] = musikFile;
                i++;
            }
            IsSorted = true;
        }

        protected override void RemoveSortCore()
        {

        }

        protected override bool IsSortedCore
        {
            get
            {
                return IsSorted;
            }
        }

        protected override ListSortDirection SortDirectionCore
        {
            get
            {
                return LastSortDirection;
            }
        }

        public MusikFile GetMusicFileById(string musicFileId)
        {
            foreach (MusikFile item in this)
            {
                if (item.MusicFileId == musicFileId)
                {
                    return (item);
                }
            }
            return new MusikFile();
        }

        static public string GetNewMusicFileId()
        {
            var dateTime = DateTime.Now;
            string newID = "";
            newID = dateTime.Year.ToString();
            newID = newID + dateTime.Month.ToString("00");
            newID = newID + dateTime.Day.ToString("00");
            newID = newID + dateTime.Hour.ToString("00");
            newID = newID + dateTime.Minute.ToString("00");
            newID = newID + dateTime.Second.ToString("00");
            newID = newID + dateTime.Millisecond.ToString("0000");
            newID = newID + new Random().Next(999999999).ToString("000000000");
            return newID;
        }

    }
}
