﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;
using System.Collections.Specialized;
using System.IO;
using System.Windows.Forms;
using ThiesGeneral.FileFunctions;
using System.Xml.Serialization;

namespace ThiesMediaProject.General
{
    public class Series
    {
        string[] fileTypes = {
            "*.mpls",
            "*.mkv", 
            "*.avi",
            "*.divx",
            "*.mpg",
            "*.mpeg",
            "*.ogm",
            "*.ts",
            "*.m2ts",
            "video_ts.ifo",
            "*.nrg",
            "*.iso",
            "*.img",
            "*.wmv",
            "*.mp4"
                             };

        string lastPropertySorted = string.Empty;
        string _SeriesName;


        public string SeriesName {
            get
            {
                return _SeriesName;
            }
            set
            {
                _SeriesName = value;
                if (SeriesEpisodes != null)
                {
                    foreach (var seriesEpisode in SeriesEpisodes)
                    {
                        if (seriesEpisode.SeriesName != value)
                        {
                            seriesEpisode.SeriesName = value;
                            seriesEpisode.SaveXML(this);
                        }
                    }
                }
            }
        }
        public string SeriesFolder { get; set; }
        public string Genre { get; set; }
        public string Genere
        {
            get
            {
                return Genre;
            }
            set
            {
                Genre = value;
            }
        }
        int _EpisodeCount = 0;
        public int EpisodeCount
        {
            get
            {
                _EpisodeCount = 0;
                foreach (var seriesEpisode in this.SeriesEpisodes)
                {
                    _EpisodeCount = _EpisodeCount + seriesEpisode.EpisodeCount;
                }
                return _EpisodeCount;
            }
        }
        public long SizeMB { get; set; }
        public string DateCreated { get; set; }
        public string SortingProperty { get; set; }

        public SeriesEpisodeList SeriesEpisodes { get; set; }

        /// <summary>
        /// empty Constructor
        /// </summary>
        public Series()
        {
            SeriesName = string.Empty;
            SeriesFolder = string.Empty;
            SizeMB = 0;
            DateCreated = string.Empty;
            Genre = string.Empty;
            SeriesEpisodes = new SeriesEpisodeList();
        }


        /// <summary>
        /// Constructor for adding Series automaticly
        /// </summary>
        public Series(string seriesFolderPar)
        {
            SeriesEpisodes = new SeriesEpisodeList();
            SeriesFolder = seriesFolderPar;
            SeriesName = Folder.GetFolderName(seriesFolderPar);
            SizeMB = Folder.GetFolderSize(seriesFolderPar) / 1024 /1024;
            DateCreated = Folder.GetFolderCreationTime(seriesFolderPar).ToString();
            if (File.Exists(SeriesFolder + @"\" + Application.ProductName + "_SeriesInfo_" + new DirectoryInfo(SeriesFolder).Name + ".xml"))
            {
                LoadXML();
                SeriesEpisodes = new SeriesEpisodeList();
                GetSeriesFromGlobalSeriesPaths();
            }
            else
            {
                GetSeriesFromGlobalSeriesPaths();
                SaveXML();
            }
            
        }


        /// <summary>
        /// for each path of directory found in global path a film item will be added
        /// </summary>
        public void GetSeriesFromGlobalSeriesPaths()
        {
            foreach (string fileType in fileTypes)
            {
                foreach (string file in Directory.GetFiles(SeriesFolder, fileType, SearchOption.AllDirectories))
                {
                    var fI = new FileInfo(file);
                    var episode = new SeriesEpisode(file, fI.Directory.FullName, SeriesName, this);
                    this.Add(episode);
                }    
            }
            
        }

        private void Add(SeriesEpisode episode)
        {
            SeriesEpisodes.Add(episode);
        }

        public void SaveXML()
        {
            if (SeriesFolder != "")
            {
                var sT = new StreamWriter(SeriesFolder + @"\" + Application.ProductName + "_SeriesInfo_" + new DirectoryInfo(SeriesFolder).Name + ".xml", false);
                var xS = new XmlSerializer(typeof(Series));
                xS.Serialize(sT, this);
                sT.Close();
            }
        }

        public void LoadXML()
        {
            var sT = new StreamReader(SeriesFolder + @"\" + Application.ProductName + "_SeriesInfo_" + new DirectoryInfo(SeriesFolder).Name + ".xml");
            var xS = new XmlSerializer(typeof(Series));
            var series = (Series)xS.Deserialize(sT);
            PropertyDescriptorCollection properties = TypeDescriptor.GetProperties(this);
            foreach (PropertyDescriptor myProperty in properties)
            {
                switch (myProperty.Name)
                {
                    case "SeriesFolder":
                    case "SizeMB":
                    case "DateCreated":
                        break;
                    default:
                        myProperty.SetValue(this, myProperty.GetValue(series));
                        break;
                }
            }
            sT.Close();
        }


        public void SaveAllXml()
        {
            foreach (SeriesEpisode episode in SeriesEpisodes)
            {
                episode.SaveXML(this);
            }
        }

        public void LoadAllXml()
        {
            foreach (SeriesEpisode episode in SeriesEpisodes)
            {
                episode.LoadXML();
            }
        }

        public Series Clone()
        {
            var rSeries = new Series();
            rSeries.SeriesFolder = this.SeriesFolder;
            rSeries.SeriesName = this.SeriesName;
            rSeries.SizeMB = this.SizeMB;
            rSeries.DateCreated = this.DateCreated;
            return rSeries;
        }
    }
}
