﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO;
using ThiesGeneral.FileFunctions;
using System.ComponentModel;
using System.Xml.Serialization;
using System.Windows.Forms;
using System.Diagnostics;
using ThiesMediaProject.ToolForms;
using System.Threading;
using ThiesGeneral.Media.VLC_Streaming;
using ThiesMediaProject.Properties;

namespace ThiesMediaProject.General
{
    public class SeriesEpisode
    {
        string length;
        string mEpisodeName = string.Empty;
  
        public string EpisodeName { get; set; }
        public string FilePath { get; set; }
        public string FolderPath { get; set; }
        public string SeriesName
        {
            get
            {
                return mEpisodeName;
            }
            set
            {
                mEpisodeName = value;
            }
        }
        public int Season { get; set; }
        public long SizeMB { get; set; }
        public DateTime DateCreated { get; set; }
        public string FileType { get; set; }
        public int EpisodeCount { get; set; }
        public int Width { get; set; }
        public int Height { get; set; }
        public int EpisodeNo { get; set; }
        public DateTime LastTimePlayed { get; set; }
        public string SeasonAndEpisodeNo
        {
            get
            {
                return Season.ToString("000") + "_" + EpisodeNo.ToString("000");
            }
        }

        public string Length
        {
            get
            {
                return length;
            }
            set
            {
                length = value;
            }
        }
        public string AudioLanguages { get; set; }
        public int VideoBitrate { get; set; }
        public string AudioBitrate { get; set; }
        public int AudioStreams { get; set; }
        public string AudioCodec { get; set; }
        public string VideoCodec { get; set; }
        public string AudioChannels { get; set; }
        public decimal YourRating { get; set; }
        public string Comment { get; set; }



        public object SortingProperty { get; set; }



        /// <summary>
        /// Initial Constructor
        /// </summary>
        public SeriesEpisode()
        {
            EpisodeName = String.Empty;
            FilePath = String.Empty;
            SeriesName = String.Empty;
            Season = 0;
            SizeMB = 0;
            DateCreated = DateTime.Now;
            FileType = String.Empty;
            Width = 0;
            Height = 0;
            EpisodeCount = 1;
            Length = "00:00:00";
            SortingProperty = String.Empty;
            LastTimePlayed = DateTime.MinValue;
        }

        /// <summary>
        /// Constructor with path of directory
        /// </summary>
        /// <param name="filePath">Path of Episodefile</param>
        /// <param name="folderPath">Path of Folder</param>
        public SeriesEpisode(string filePath, string folderPath, string seriesName, Series parentSeries)
        {
            EpisodeCount = 1;
            SeriesName = seriesName;
            if (Directory.Exists(folderPath))
            {
                FilePath = filePath;
                FolderPath = folderPath;
                GetEpisodeFileInfo();
                if (File.Exists(folderPath + @"\" + Application.ProductName + "_" + new FileInfo(FilePath).Name + ".xml"))
                {
                    LoadXML();
                }
                else
                {
                    SaveXML(parentSeries);
                }
            }
            else
            {
                throw new DirectoryNotFoundException(filePath);
            }
        }

        /// <summary>
        /// Get info from directory of film
        /// </summary>
        public void GetEpisodeFileInfo()
        {
            var fInfo = new FileInfo(FilePath);
            SizeMB = fInfo.Length / 1024 / 1024;
            DateCreated = fInfo.CreationTime;
            FileType = Folder.GetFilmTypeByFolder(FolderPath);
            EpisodeName = fInfo.Name; 
        }

        public void SaveXML(Series seriesParent)
        {
            seriesParent.SaveXML();
            try
            {
                var sT = new StreamWriter(FolderPath + @"\" + Application.ProductName + "_" + new FileInfo(FilePath).Name + ".xml", false);
                var xS = new XmlSerializer(typeof(SeriesEpisode));
                xS.Serialize(sT, this);
                sT.Close();
            }
            catch (Exception)
            {            }
            
            
        }

        public void LoadXML()
        {
            GetEpisodeFileInfo();
            var sT = new StreamReader(FolderPath + @"\" + Application.ProductName + "_" + new FileInfo(FilePath).Name + ".xml");
            var xS = new XmlSerializer(typeof(SeriesEpisode));
            var film = (SeriesEpisode)xS.Deserialize(sT);
            PropertyDescriptorCollection properties = TypeDescriptor.GetProperties(this);
            foreach (PropertyDescriptor myProperty in properties)
            {
                switch (myProperty.Name)
                {
                    case "FolderPath":
                    case "FilePath":
                    case "SizeMB":
                    case "DateCreated":
                    case "FileType":
                        break;
                    default:
                        myProperty.SetValue(this, myProperty.GetValue(film));
                        break;
                }
            }
            sT.Close();
            if (EpisodeCount == 0)
            {
                EpisodeCount = 1;
            }
        }

        public void OpenVideoFolder()
        {
            Process.Start("explorer.exe", FolderPath);
        }

        public void OpenVideoInFolder()
        {
            LastTimePlayed = DateTime.Now;
            MyFile.StartFile(FilePath,Settings.Default.DaemonToolsPath);
        }

        public bool MyEquals(SeriesEpisode seriesEpisode)
        {
            LoadXML();
            Thread.Sleep(100);
            foreach (System.Reflection.PropertyInfo myProperty in this.GetType().GetProperties())
            {
                if ((myProperty.GetValue(this, null) != null) && (myProperty.GetValue(seriesEpisode, null) != null))
                {
                    if (myProperty.Name != "SortingProperty")
                    {
                        if (myProperty.GetValue(this, null).ToString() != myProperty.GetValue(seriesEpisode, null).ToString())
                        {
                            return false;
                        }
                    }
                }
            }
            return true;
        }

        public void StreamVideoInFolder()
        {
            LastTimePlayed = DateTime.Now;
            VlcStreaming.PathToVLC = Settings.Default.VlcPath;
            VlcStreaming.Filename = FilePath;
            VlcStreaming.Open_Stream(Settings.Default.VlcStreamingParameter);
        }

        
        
    }
    
}
