﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using ThiesGeneral.FileFunctions;
using System.ComponentModel;
using System.Xml.Serialization;
using System.Windows.Forms;
using System.Diagnostics;
using ThiesMediaProject.ToolForms;
using System.Collections.Specialized;
using System.IO;

namespace ThiesMediaProject.General
{
    public class SeriesList : BindingList<Series>
    {
        string lastPropertySorted = string.Empty;
        bool IsSorted = false;

        public StringCollection SeriesFolderList { get; set; }
        public  ListSortDirection LastSortDirection { get; set; }


        /// <summary>
        /// empty Constructor
        /// </summary>
        public SeriesList()
        {
            SeriesFolderList = new StringCollection();
        }


        /// <summary>
        /// Constructor for adding films automaticly
        /// </summary>
        public SeriesList(StringCollection seriesFolderList, bool showDialog)
        {
            if (seriesFolderList != null)
            {
                foreach (string seriesMainFolder in seriesFolderList)
                {
                    var sF = new StatusForm("Loading Series");
                    if (showDialog)
                    {
                        sF.MaxValue = Directory.GetDirectories(seriesMainFolder).Count();
                        sF.Show();
                    }
                    foreach (string seriesFolder in Directory.GetDirectories(seriesMainFolder))
                    {
                        if (
                                !(new DirectoryInfo(seriesFolder).Attributes.HasFlag(FileAttributes.System)) &&
                                !(new DirectoryInfo(seriesFolder).Attributes.HasFlag(FileAttributes.ReadOnly)) &&
                                !(new DirectoryInfo(seriesFolder).Attributes.HasFlag(FileAttributes.Hidden))
                                )
                        {
                            if (showDialog)
                            {
                                sF.Value++;
                            }
                            var newSeries = new Series(seriesFolder);
                            this.Add(newSeries);
                        }
                    }
                    if (showDialog)
                    {
                        sF.Value = 0;
                        sF.Close();
                    }
                }
            }
            else
            {
                var newSeries = new Series();
                this.Add(newSeries);
            }
        }
               

        public void SaveAllXml()
        {
            foreach (Series series in this)
            {
                series.SaveXML();
                series.SaveAllXml();
            }
        }

        public void LoadAllXml()
        {
            foreach (Series series in this)
            {
                series.LoadXML();
                series.LoadAllXml();
            }
        }

        public SeriesEpisode GetSeriesEpisode(string seriesName, string seriesEpisodeName)
        {
            int index = 0;
            while (this[index].SeriesName != seriesName)
            {
                if (this.Count == index + 1)
                {
                    return new SeriesEpisode();
                }
                index++;
                
            }

            int index2 = 0;
            while (this[index].SeriesEpisodes[index2].EpisodeName.Trim() != seriesEpisodeName.Trim())
            {
                if (this[index].SeriesEpisodes.Count == index2 + 1)
                {
                    return new SeriesEpisode();
                }
                index2++;
            }

            return this[index].SeriesEpisodes[index2];
        }

        protected override bool SupportsSortingCore
        {
            get
            {
                return true;
            }
        }

        public void Sort(PropertyDescriptor prop, ListSortDirection direction)
        {
            ApplySortCore(prop, direction);
        }

        protected override void ApplySortCore(PropertyDescriptor prop, ListSortDirection direction)
        {
            foreach (Series series in this)
            {
                series.SortingProperty = prop.GetValue(series).ToString();
            }
            IEnumerable<Series> query;

            if (direction == ListSortDirection.Ascending)
            {
                query = this.OrderBy(series => series.SortingProperty);
            }
            else
            {
                query = this.OrderByDescending(series => series.SortingProperty);
            }

            int i = 0;
            foreach (Series series in query)
            {
                this.Items[i] = series;
                i++;
            }
            IsSorted = true;
        }

        protected override void RemoveSortCore()
        {
            
        }

        protected override bool IsSortedCore
        {
            get
            {
                return IsSorted;
            }
        }

        protected override ListSortDirection SortDirectionCore
        {
            get
            {
                return LastSortDirection;
            }
        }
    

    }
}
