﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using ThiesGeneral.Web.HtmlBuilder;
using System.Reflection;
using ThiesMediaProject.General;
using System.Windows;
using System.IO;
using ThiesGeneral.Web;
using System.Web;
using System.ComponentModel;

namespace ThiesMediaProject
{
    public class HtmlData
    {
        public HtmlDocument FilmsDoc = new HtmlDocument();
        public HtmlDocument MusicDoc = new HtmlDocument();
        public HtmlDocument IndexDoc = new HtmlDocument();
        public HtmlDocument StreamDoc = new HtmlDocument();
        public HtmlDocument SeriesDoc = new HtmlDocument();
        private string LastMusicColumnSorted = string.Empty;
        private string LastMusicMusicFilter = string.Empty;
        private int LastMusicShow = 0;


        public HtmlData()
        {
            CreateFilmsData("Filmname","",true);
            CreateMusicData("Artist", "",0,99,0);
            CreateSeriesData();
            CreaStreamData();
            CreateIndexData();
        }

        public void SortFilmData(string sortProperty, bool sortedAscending)
        {
            CreateFilmsData(sortProperty,"",sortedAscending);
        }

        public void FilterFilmData(string filterProperty)
        {
            CreateFilmsData("Filmname", filterProperty,true);
        }

        public void SortAndFilterFilmData(string sortProperty, string filterProperty, bool sortAscending)
        {
            CreateFilmsData(sortProperty, filterProperty,sortAscending);
        }

        public void SortAndFilterMusicData(string sortProperty, string filterProperty, int show, byte sortOrder)
        {
            CreateMusicData(sortProperty, filterProperty,show, show + 99,sortOrder);
        }

        public void WriteInFolder(string folderToWriteIn)
        {
            WriteStreamingHtmlFile(folderToWriteIn);
            FilmsDoc.WriteInFolder(folderToWriteIn);
            IndexDoc.WriteInFolder(folderToWriteIn);
        }

        private void CreaStreamData()
        {
            StreamReader streReader = new StreamReader(System.Windows.Forms.Application.StartupPath + "\\StreaminPageSource.txt",
                        Encoding.Unicode);
            StreamDoc.InnerText = streReader.ReadToEnd();
            streReader.Close();
        }



        private void WriteStreamingHtmlFile(string folder)
        {
            string fileName = "stream.html";
            if ((fileName != "") && (folder != ""))
            {
                FileStream fsStream;
                string filePath = folder + "\\" + fileName;

                if (!Directory.Exists(folder))
                {
                    Directory.CreateDirectory(folder);
                }

                string fileContent;
                StreamWriter streWriter;

                // Datei erzeugen/öffnen
                if (!File.Exists(filePath))
                {
                    fsStream = File.Create(filePath);
                    fsStream.Close();
                }


                StreamReader streReader = new StreamReader(System.Windows.Forms.Application.StartupPath + "\\StreaminPageSource.txt",
                        Encoding.Unicode);
                fileContent = streReader.ReadToEnd();
                streReader.Close();

                // in Datei schreiben
                streWriter = new StreamWriter(filePath, false, Encoding.Unicode);
                streWriter.Write(fileContent);
                streWriter.Close();
            }
        }

        private void CreateIndexData()
        {
            HtmlDocument indexDoc = new HtmlDocument("index.html");
            HtmlElement titleElem = indexDoc.CreateElement("TITLE");
            titleElem.InnerText = "Thies Mediaproject Index";
            indexDoc.AppendChild(titleElem);

            HtmlElement bodyElem = indexDoc.CreateElement("BODY");
            indexDoc.AppendChild(bodyElem);

            HtmlElement linkElem = indexDoc.CreateElement("A href=\"" + FilmsDoc.FileName + "\"");
            linkElem.InnerText = "Films";
            bodyElem.AppendChild(linkElem);

            HtmlElement brElem = indexDoc.CreateElement("BR",true);
            bodyElem.AppendChild(brElem);

            HtmlElement linkElem2 = indexDoc.CreateElement("A href=\"" + SeriesDoc.FileName + "\"");
            linkElem2.InnerText = "Series";
            bodyElem.AppendChild(linkElem2);

            bodyElem.AppendChild(brElem);

            HtmlElement linkElem3 = indexDoc.CreateElement("A href=\"" + MusicDoc.FileName + "\"");
            linkElem3.InnerText = "Music";
            bodyElem.AppendChild(linkElem3);

            bodyElem.AppendChild(brElem);
            bodyElem.AppendChild(brElem);

            HtmlElement linkElem4 = indexDoc.CreateElement("A href=\"stream.html" + "\"");
            linkElem4.AddAtribute("target", "_blank");
            linkElem4.InnerText = "Vlc Stream";
            bodyElem.AppendChild(linkElem4);

            IndexDoc = indexDoc;
        }


        private void CreateFilmsData(string sortColumnName, string filterText, bool sortedAscending)
        {
            string filterLinkText = string.Empty;

            var result = Data.DataFilms;
            try
            {
                if (sortedAscending)
                {
                    result.Sort(TypeDescriptor.GetProperties(new Film())[sortColumnName], ListSortDirection.Ascending);
                }
                else
                {
                    result.Sort(TypeDescriptor.GetProperties(new Film())[sortColumnName], ListSortDirection.Descending);
                }
            }
            catch (Exception)
            {
                return;

            }
            

                

            HtmlElement tableRow = null;
            HtmlElement headerElem = null;

            HtmlDocument filmsDoc = new HtmlDocument("films.html");
            HtmlElement titleElem = filmsDoc.CreateElement("TITLE");
            titleElem.InnerText = "Films";
            filmsDoc.AppendChild(titleElem);
            filmsDoc.AppendChild(filmsDoc.CreateElement("!--[if !IE]><!--", true));
            HtmlElement styleSheetElem = filmsDoc.CreateElement("STYLE");

            styleSheetElem.AddAtribute("type", "text/css");
            styleSheetElem.InnerText =
            @"
                ul li
                {
                    display:block;
                    text-decoration:none;
                    color:#4f4f4f;
                    background-color:#F7F7F7;
                }
                ul li ul
                {
                    display: none;
                }
                ul li:hover ul
                {
                    display:block;
                    text-decoration:none;
                    position:absolute;
                    background-color:#fff;
                    color:#000;
                    left:0px;
                    width:206px;
                }

                
                

                <!--<![endif]-->
            ";
            filmsDoc.AppendChild(styleSheetElem);
             

            HtmlElement bodyElem = filmsDoc.CreateElement("BODY");
            filmsDoc.AppendChild(bodyElem);

            HtmlElement linkElem = filmsDoc.CreateElement("A href=\"/\"");
            linkElem.InnerText = "<---Index";
            bodyElem.AppendChild(linkElem);


            //formular fürs filtern
            HtmlElement formElement = filmsDoc.CreateElement("FORM");
            formElement.AddAtribute("action", filmsDoc.FileName);
            formElement.AddAtribute("method", "get");
            formElement.AddText("Filter: ");
            HtmlElement textBoxElement = filmsDoc.CreateElement("input");
            textBoxElement.AddAtribute("name", "filter");
            textBoxElement.AddAtribute("type", "text");
            textBoxElement.AddAtribute("size", "30");
            textBoxElement.AddAtribute("maxlength", "30");
            if (filterText != "")
            {
                textBoxElement.AddAtribute("value", filterText);
                filterLinkText = "=" + filterText;
            }
            formElement.AppendChild(textBoxElement);
            //<input type="submit" value=" Absenden ">
            HtmlElement submitButtonElement = filmsDoc.CreateElement("input");
            submitButtonElement.AddAtribute("type", "submit");
            submitButtonElement.AddAtribute("value", "Absenden");
            formElement.AppendChild(submitButtonElement);
            bodyElem.AppendChild(formElement);


            var result2 = new Films();
            foreach (Film film in result)
            {
                foreach (var property in film.GetType().GetProperties())
                {
                    if (property.GetValue(film, null) != null)
                    {
                        if (property.GetValue(film, null).ToString().ToUpper().Contains(filterText.ToUpper()))
                        {
                            result2.Add(film);
                            break;
                        }
                    }
                }
            }
            result = result2;

            HtmlElement tableElem = filmsDoc.CreateElement("TABLE border=1");
            bodyElem.AppendChild(tableElem);

            HtmlElement tableHeader = filmsDoc.CreateElement("THEAD");
            tableElem.AppendChild(tableHeader);
            tableRow = filmsDoc.CreateElement("TR");
            tableHeader.AppendChild(tableRow);

            //actions
            headerElem = filmsDoc.CreateElement("TH");
            headerElem.InnerText = "Actions";
            tableRow.AppendChild(headerElem);

            

            foreach (PropertyInfo col in typeof(Film).GetProperties())
            {
                switch (col.Name)
                {
                    case "FilmID":
                    case "FilmPicture":
                    case "Path":
                    case "Genere":
                    case "PictureByteArray":
                    case "SortingProperty":
                        break;
                    default:
                        headerElem = filmsDoc.CreateElement("TH");
                        HtmlElement linkSortEl = filmsDoc.CreateElement("A");
                        if ((col.Name == sortColumnName) && sortedAscending)
                        {
                            linkSortEl.AddAtribute("href", "?sortdescending=" + HttpUtility.UrlEncode(col.Name) + filterLinkText);
                        }
                        else
                        {                            
                            linkSortEl.AddAtribute("href", "?sortascending=" + HttpUtility.UrlEncode(col.Name) + filterLinkText);
                        }
                        
                        linkSortEl.InnerText = col.Name;
                        headerElem.AppendChild(linkSortEl); 
                        tableRow.AppendChild(headerElem);
                        break;
                }
            }

            // Create table rows.
            HtmlElement tableBody = filmsDoc.CreateElement("TBODY");
            tableElem.AppendChild(tableBody);
            foreach (Film dr in result)
            {
                tableRow = filmsDoc.CreateElement("TR");
                tableBody.AppendChild(tableRow);

                //actions
                HtmlElement tableCella = filmsDoc.CreateElement("TD");
                HtmlElement listMain = filmsDoc.CreateElement("UL");
                HtmlElement listElementMain = filmsDoc.CreateElement("LI");
                listElementMain.AddText("ACTIONS");                
                HtmlElement listSub = filmsDoc.CreateElement("UL");
                HtmlElement listElementSub = filmsDoc.CreateElement("LI");

                listElementSub = filmsDoc.CreateElement("LI");
                HtmlElement linkEle = filmsDoc.CreateElement("A href=\"" +
                    "?play=" + dr.FilmID + "#" + dr.FilmID + "\"");
                linkEle.InnerText = "-play on host";
                listElementSub.AppendChild(linkEle);                

                listSub.AppendChild(listElementSub);

                listElementSub = filmsDoc.CreateElement("LI");
                linkEle = filmsDoc.CreateElement("A href=\"" +
                    "?opendir=" + dr.FilmID + "#" + dr.FilmID + "\"");
                linkEle.InnerText = "-open directory on host";
                listElementSub.AppendChild(linkEle);
                listSub.AppendChild(listElementSub);

                listElementSub = filmsDoc.CreateElement("LI");
                linkEle = filmsDoc.CreateElement("A href=\"" +
                    "?stream=" + dr.FilmID + "#" + dr.FilmID + "\"");
                linkEle.InnerText = "-stream with vlc";
                listElementSub.AppendChild(linkEle);
                listSub.AppendChild(listElementSub);

                listElementSub = filmsDoc.CreateElement("LI");
                linkEle = filmsDoc.CreateElement("A href=\"" +
                    "stream.html" + "\"");
                linkEle.AddAtribute("target", "_blank");
                linkEle.InnerText = "-open vlc stream";
                listElementSub.AppendChild(linkEle);
                listSub.AppendChild(listElementSub);

                listElementSub = filmsDoc.CreateElement("LI");
                linkEle = filmsDoc.CreateElement("A href=\"" +
                "getfile=musicfile!" + dr.FilmID + "#" + dr.FilmID + "\"");
                linkEle.InnerText = "-download";
                listElementSub.AppendChild(linkEle);
                listSub.AppendChild(listElementSub);

                listElementSub = filmsDoc.CreateElement("LI");
                linkEle = filmsDoc.CreateElement("A href=\"" +
                    "?addtoplaylist=" + dr.FilmID + "#" + dr.FilmID + "\"");
                linkEle.InnerText = "-add to streaminglist";
                listElementSub.AppendChild(linkEle);
                listSub.AppendChild(listElementSub);

                listElementSub = filmsDoc.CreateElement("LI");
                linkEle = filmsDoc.CreateElement("A href=\"" +
                    "?playstreaming=" + MyHtml.enCodeUrlPart(dr.FilmID) + "#" + dr.FilmID + "\"");
                linkEle.InnerText = "-play streamingplaylist";
                listElementSub.AppendChild(linkEle);
                listSub.AppendChild(listElementSub);

                listElementSub = filmsDoc.CreateElement("LI");
                linkEle = filmsDoc.CreateElement("A href=\"" +
                    "?clearstreaming=" + MyHtml.enCodeUrlPart(dr.FilmID) + "#" + dr.FilmID + "\"");
                linkEle.InnerText = "-clear streamingplaylist";
                listElementSub.AppendChild(linkEle);
                listSub.AppendChild(listElementSub);

                listElementSub = filmsDoc.CreateElement("LI");
                linkEle = filmsDoc.CreateElement("A href=\"" +
                    "/playlist.html" + "\"");
                linkEle.AddAtribute("target", "_blank");
                linkEle.InnerText = "-streamingplaylist";
                listElementSub.AppendChild(linkEle);
                listSub.AppendChild(listElementSub);

                listElementSub = filmsDoc.CreateElement("LI");
                linkEle = filmsDoc.CreateElement("script");
                linkEle.AddAtribute("type", "text/javascript");
                linkEle.InnerText = "window.document.write(\"<a href='MMS://\" + window.location.hostname + \":8090'>-open stream in mms-player</a>\")";
                listElementSub.AppendChild(linkEle);
                listSub.AppendChild(listElementSub);

                listElementMain.AppendChild(listSub);
                listMain.AppendChild(listElementMain);
                tableCella.AppendChild(listMain);
                tableRow.AppendChild(tableCella);

                foreach (PropertyInfo col in typeof(Film).GetProperties())
                {
                    Object dbCell = col.GetValue(dr, null);
                    HtmlElement tableCell = filmsDoc.CreateElement("TD");
                    switch (col.Name)
                    {
                        case "FilmID":
                        case "FilmPicture":
                        case "Path":
                        case "Genere":
                        case "PictureByteArray":
                        case "SortingProperty":
                            break;
                        case "Filmname":
                            if (dbCell != null)
                            {
                                HtmlElement anchorEl = filmsDoc.CreateElement("A");
                                anchorEl.AddAtribute("Name", dr.FilmID);
                                anchorEl.InnerText = dbCell.ToString();
                                tableCell.AppendChild(anchorEl);
                            }
                            tableRow.AppendChild(tableCell);
                            break;
                        default:
                            if (dbCell != null)
                            {
                                tableCell.InnerText = dbCell.ToString();
                            }
                            tableRow.AppendChild(tableCell);
                            break;
                    }
                }
            }
            FilmsDoc = filmsDoc;
        }
        private void CreateMusicData(string sortColumnName, string filterText, int beginAt, int stopAt, byte sortOrder)
        {
            if (Data.DataMusikList != null)
            {


                MusikList result = new MusikList();
                foreach (MusikFile item in Data.DataMusikList)
                {
                    result.Add(item);
                }
                if (sortOrder == 0)
                    result.Sort(TypeDescriptor.GetProperties(new MusikFile())[sortColumnName], ListSortDirection.Ascending);
                else
                    result.Sort(TypeDescriptor.GetProperties(new MusikFile())[sortColumnName], ListSortDirection.Descending);
                LastMusicShow = beginAt;
                LastMusicColumnSorted = sortColumnName;
                LastMusicMusicFilter = filterText;




                HtmlElement tableRow = null;
                HtmlElement headerElem = null;

                HtmlDocument musicsDoc = new HtmlDocument("music.html");
                HtmlElement titleElem = musicsDoc.CreateElement("TITLE");
                titleElem.InnerText = "Music";
                musicsDoc.AppendChild(titleElem);
                musicsDoc.AppendChild(musicsDoc.CreateElement("!--[if !IE]><!--", true));
                HtmlElement styleSheetElem = musicsDoc.CreateElement("STYLE");
                styleSheetElem.AddAtribute("type", "text/css");
                styleSheetElem.InnerText =
                @"
                ul li
                {
                    display:block;
                    text-decoration:none;
                    color:#4f4f4f;
                    background-color:#F7F7F7;
                }
                ul li ul
                {
                    display: none;
                }
                ul li:hover ul
                {
                    display:block;
                    text-decoration:none;
                    position:absolute;
                    background-color:#fff;
                    color:#000;
                    left:0px;
                    width:206px;
                }
                <!--<![endif]-->
            ";
                musicsDoc.AppendChild(styleSheetElem);

                HtmlElement bodyElem = musicsDoc.CreateElement("BODY");
                musicsDoc.AppendChild(bodyElem);

                HtmlElement linkElem = musicsDoc.CreateElement("A href=\"/\"");
                linkElem.InnerText = "<---Index";
                bodyElem.AppendChild(linkElem);



                //formular fürs filtern
                HtmlElement formElement = musicsDoc.CreateElement("FORM");
                formElement.AddAtribute("action", musicsDoc.FileName);
                formElement.AddAtribute("method", "get");
                formElement.AddText("Filter: ");

                HtmlElement textBoxElement = musicsDoc.CreateElement("input");
                textBoxElement.AddAtribute("name", "filter");
                textBoxElement.AddAtribute("type", "hidden");
                textBoxElement.AddAtribute("value", filterText);
                formElement.AppendChild(textBoxElement);

                textBoxElement = musicsDoc.CreateElement("input");
                textBoxElement.AddAtribute("name", "filter");
                textBoxElement.AddAtribute("type", "text");
                textBoxElement.AddAtribute("size", "30");
                textBoxElement.AddAtribute("maxlength", "30");
                if (filterText != "")
                {
                    textBoxElement.AddAtribute("value", filterText);
                }
                formElement.AppendChild(textBoxElement);



                textBoxElement = musicsDoc.CreateElement("input");
                textBoxElement.AddAtribute("name", "sort");
                textBoxElement.AddAtribute("type", "hidden");
                textBoxElement.AddAtribute("value", sortColumnName);
                formElement.AppendChild(textBoxElement);

                textBoxElement = musicsDoc.CreateElement("input");
                textBoxElement.AddAtribute("name", "show");
                textBoxElement.AddAtribute("type", "hidden");
                textBoxElement.AddAtribute("value", 0.ToString());
                formElement.AppendChild(textBoxElement);

                textBoxElement = musicsDoc.CreateElement("input");
                textBoxElement.AddAtribute("name", "sortOrder");
                textBoxElement.AddAtribute("type", "hidden");
                textBoxElement.AddAtribute("value", 0.ToString());
                formElement.AppendChild(textBoxElement);

                //<input type="submit" value=" Absenden ">
                HtmlElement submitButtonElement = musicsDoc.CreateElement("input");
                submitButtonElement.AddAtribute("type", "submit");
                submitButtonElement.AddAtribute("value", "Absenden");
                formElement.AppendChild(submitButtonElement);
                bodyElem.AppendChild(formElement);


                var result2 = new MusikList();

                foreach (MusikFile musicFile in result)
                {

                    foreach (var property in musicFile.GetType().GetProperties())
                    {
                        if (property.GetValue(musicFile, null) != null)
                        {
                            if (property.GetValue(musicFile, null).ToString().ToUpper().Contains(filterText.ToUpper()))
                            {
                                result2.Add(musicFile);
                            }
                            break;
                        }
                    }
                }

                result.Clear();
                if (beginAt < 0)
                {
                    beginAt = 0;
                }
                int setCount = result2.Count;
                for (int i = beginAt; i < stopAt; i++)
                {
                    if (i >= result2.Count - 1)
                    {
                        break;
                    }
                    result.Add(result2[i]);

                }

                HtmlElement firstLink = musicsDoc.CreateElement("A");
                firstLink.AddAtribute("href", "?first=go" + "&filter=" + filterText + "&sort=" + sortColumnName + "&show=" + (0).ToString() + "&sortOrder=" + sortOrder.ToString());
                firstLink.InnerText = "first";
                bodyElem.AppendChild(firstLink);
                bodyElem.AddText(" | ");
                HtmlElement prevLink = musicsDoc.CreateElement("A");
                prevLink.AddAtribute("href", "?prev=go" + "&filter=" + filterText + "&sort=" + sortColumnName + "&show=" + (beginAt - 99).ToString() + "&sortOrder=" + sortOrder.ToString());
                prevLink.InnerText = "prev";
                bodyElem.AppendChild(prevLink);
                bodyElem.AddText(" | ");
                HtmlElement nextLink = musicsDoc.CreateElement("A");
                nextLink.AddAtribute("href", "?next=go" + "&filter=" + filterText + "&sort=" + sortColumnName + "&show=" + (beginAt + 99).ToString() + "&sortOrder=" + sortOrder.ToString());
                nextLink.InnerText = "next";
                bodyElem.AppendChild(nextLink);
                bodyElem.AddText(" | ");
                HtmlElement lastLink = musicsDoc.CreateElement("A");
                lastLink.AddAtribute("href", "?last=go" + "&filter=" + filterText + "&sort=" + sortColumnName + "&show=" + (setCount - 99).ToString() + "&sortOrder=" + sortOrder.ToString());
                lastLink.InnerText = "last";
                bodyElem.AppendChild(lastLink);
                bodyElem.AddText(" | " + beginAt.ToString() + "-" + stopAt.ToString());


                HtmlElement tableElem = musicsDoc.CreateElement("TABLE border=1");
                bodyElem.AppendChild(tableElem);

                HtmlElement tableHeader = musicsDoc.CreateElement("THEAD");
                tableElem.AppendChild(tableHeader);
                tableRow = musicsDoc.CreateElement("TR");
                tableHeader.AppendChild(tableRow);

                //actions
                headerElem = musicsDoc.CreateElement("TH");
                headerElem.InnerText = "Actions";
                tableRow.AppendChild(headerElem);

                string sortingFilterShow =
                    "&filter=" + filterText + "&sort=" + sortColumnName + "&show=" + beginAt.ToString() + "&sortOrder=" + sortOrder.ToString();
                if (sortOrder == 0)
                    sortOrder = 1;
                else
                    sortOrder = 0;
                foreach (PropertyInfo col in typeof(MusikFile).GetProperties())
                {
                    switch (col.Name)
                    {
                        case "FilePath":
                        case "MusicFileId":
                        case "FileType":
                        case "SortingProperty":
                            break;
                        default:

                            headerElem = musicsDoc.CreateElement("TH");
                            HtmlElement linkSortEl = musicsDoc.CreateElement("A");
                            linkSortEl.AddAtribute("href", "?sort=" + HttpUtility.UrlEncode(col.Name) +
                                "&filter=" + filterText + "&sort=" + HttpUtility.UrlEncode(col.Name) + "&show=" + beginAt.ToString()
                                 + "&sortOrder=" + sortOrder.ToString());
                            linkSortEl.InnerText = col.Name;
                            headerElem.AppendChild(linkSortEl);
                            tableRow.AppendChild(headerElem);
                            break;
                    }
                }

                // Create table rows.
                HtmlElement tableBody = musicsDoc.CreateElement("TBODY");
                tableElem.AppendChild(tableBody);



                foreach (MusikFile dr in result)
                {
                    tableRow = musicsDoc.CreateElement("TR");
                    tableBody.AppendChild(tableRow);

                    //actions
                    HtmlElement tableCella = musicsDoc.CreateElement("TD");
                    HtmlElement listMain = musicsDoc.CreateElement("UL");
                    HtmlElement listElementMain = musicsDoc.CreateElement("LI");
                    listElementMain.AddText("ACTIONS");
                    HtmlElement listSub = musicsDoc.CreateElement("UL");
                    HtmlElement listElementSub = musicsDoc.CreateElement("LI");

                    listElementSub = musicsDoc.CreateElement("LI");
                    HtmlElement linkEle = musicsDoc.CreateElement("A href=\"" +
                        "?play=" + dr.MusicFileId + sortingFilterShow + "#" + dr.MusicFileId + "\"");
                    linkEle.InnerText = "-play on host";
                    listElementSub.AppendChild(linkEle);
                    listSub.AppendChild(listElementSub);

                    listElementSub = musicsDoc.CreateElement("LI");
                    linkEle = musicsDoc.CreateElement("A href=\"" +
                        "?opendir=" + dr.MusicFileId + sortingFilterShow + "#" + dr.MusicFileId + "\"");
                    linkEle.InnerText = "-open directory on host";
                    listElementSub.AppendChild(linkEle);
                    listSub.AppendChild(listElementSub);

                    listElementSub = musicsDoc.CreateElement("LI");
                    linkEle = musicsDoc.CreateElement("A href=\"" +
                        "?stream=" + dr.MusicFileId + sortingFilterShow + "#" + dr.MusicFileId + "\"");
                    linkEle.InnerText = "-stream with vlc";
                    listElementSub.AppendChild(linkEle);
                    listSub.AppendChild(listElementSub);

                    listElementSub = musicsDoc.CreateElement("LI");
                    linkEle = musicsDoc.CreateElement("A href=\"" +
                        "stream.html" + "\"");
                    linkEle.AddAtribute("target", "_blank");
                    linkEle.InnerText = "-open vlc stream";
                    listElementSub.AppendChild(linkEle);
                    listSub.AppendChild(listElementSub);

                    listElementSub = musicsDoc.CreateElement("LI");
                    linkEle = musicsDoc.CreateElement("A href=\"" +
                    "getfile=musicfile!" + dr.MusicFileId + "#" + dr.MusicFileId + "\"");
                    linkEle.InnerText = "-download";
                    listElementSub.AppendChild(linkEle);
                    listSub.AppendChild(listElementSub);

                    listElementSub = musicsDoc.CreateElement("LI");
                    linkEle = musicsDoc.CreateElement("A href=\"" +
                        "?addtoplaylist=" + dr.MusicFileId + sortingFilterShow + "#" + dr.MusicFileId + "\"");
                    linkEle.InnerText = "-add to streaminglist";
                    listElementSub.AppendChild(linkEle);
                    listSub.AppendChild(listElementSub);

                    listElementSub = musicsDoc.CreateElement("LI");
                    linkEle = musicsDoc.CreateElement("A href=\"" +
                        "?playstreaming=" + MyHtml.enCodeUrlPart(dr.MusicFileId) + sortingFilterShow + "#" + dr.MusicFileId + "\"");
                    linkEle.InnerText = "-play streamingplaylist";
                    listElementSub.AppendChild(linkEle);
                    listSub.AppendChild(listElementSub);

                    listElementSub = musicsDoc.CreateElement("LI");
                    linkEle = musicsDoc.CreateElement("A href=\"" +
                        "?clearstreaming=" + MyHtml.enCodeUrlPart(dr.MusicFileId) + sortingFilterShow + "#" + dr.MusicFileId + "\"");
                    linkEle.InnerText = "-clear streamingplaylist";
                    listElementSub.AppendChild(linkEle);
                    listSub.AppendChild(listElementSub);

                    listElementSub = musicsDoc.CreateElement("LI");
                    linkEle = musicsDoc.CreateElement("A href=\"" +
                        "/playlist.html" + "\"");
                    linkEle.AddAtribute("target", "_blank");
                    linkEle.InnerText = "-streamingplaylist";
                    listElementSub.AppendChild(linkEle);
                    listSub.AppendChild(listElementSub);

                    listElementSub = musicsDoc.CreateElement("LI");
                    linkEle = musicsDoc.CreateElement("script");
                    linkEle.AddAtribute("type", "text/javascript");
                    linkEle.InnerText = "window.document.write(\"<a href='MMS://\" + window.location.hostname + \":8090'>-open stream in mms-player</a>\")";
                    listElementSub.AppendChild(linkEle);
                    listSub.AppendChild(listElementSub);

                    listElementMain.AppendChild(listSub);
                    listMain.AppendChild(listElementMain);
                    tableCella.AppendChild(listMain);
                    tableRow.AppendChild(tableCella);

                    foreach (PropertyInfo col in typeof(MusikFile).GetProperties())
                    {
                        Object dbCell = col.GetValue(dr, null);
                        HtmlElement tableCell = musicsDoc.CreateElement("TD");
                        switch (col.Name)
                        {
                            case "FilePath":
                            case "MusicFileId":
                            case "FileType":
                            case "SortingProperty":
                                break;
                            case "Artist":
                                if (dbCell != null)
                                {
                                    HtmlElement anchorEl = musicsDoc.CreateElement("A");
                                    anchorEl.AddAtribute("Name", dr.MusicFileId);
                                    anchorEl.InnerText = dbCell.ToString();
                                    tableCell.AppendChild(anchorEl);
                                }
                                else
                                {
                                    tableCell.InnerText = "&nbsp;";
                                }
                                if (tableCell.InnerText == "")
                                {
                                    tableCell.InnerText = "&nbsp;";
                                }
                                tableRow.AppendChild(tableCell);
                                break;
                            default:
                                if (dbCell != null)
                                {
                                    tableCell.InnerText = dbCell.ToString();
                                }
                                else
                                {
                                    tableCell.InnerText = "&nbsp;";
                                }
                                if (tableCell.InnerText == "")
                                {
                                    tableCell.InnerText = "&nbsp;";
                                }
                                tableRow.AppendChild(tableCell);
                                break;
                        }
                    }
                }
                bodyElem.AppendChild(firstLink);
                bodyElem.AddText(" | ");
                bodyElem.AppendChild(prevLink);
                bodyElem.AddText(" | ");
                bodyElem.AppendChild(nextLink);
                bodyElem.AddText(" | ");
                bodyElem.AppendChild(lastLink);
                bodyElem.AddText(" | " + beginAt.ToString() + "-" + stopAt.ToString());

                MusicDoc = musicsDoc;
            }
        }
        private void CreateSeriesData()
        {
            if (Data.DataSeriesList != null)
            {
                HtmlElement tableRow = null;
                HtmlElement headerElem = null;

                HtmlDocument seriesDoc = new HtmlDocument("series.html");
                HtmlElement titleElem = seriesDoc.CreateElement("TITLE");
                titleElem.InnerText = "Series";
                seriesDoc.AppendChild(titleElem);


                HtmlElement bodyElem = seriesDoc.CreateElement("BODY");
                seriesDoc.AppendChild(bodyElem);

                HtmlElement linkElem = seriesDoc.CreateElement("A href=\"/\"");
                linkElem.InnerText = "<---Index";
                bodyElem.AppendChild(linkElem);

                HtmlElement tableElem = seriesDoc.CreateElement("TABLE border=1");
                bodyElem.AppendChild(tableElem);

                HtmlElement tableHeader = seriesDoc.CreateElement("THEAD");
                tableElem.AppendChild(tableHeader);
                tableRow = seriesDoc.CreateElement("TR");
                tableHeader.AppendChild(tableRow);

                foreach (PropertyInfo col in typeof(Series).GetProperties())
                {
                    switch (col.Name)
                    {
                        case "SortingProperty":
                        case "SeriesEpisodes":
                        case "Genere":
                            break;
                        default:
                            headerElem = seriesDoc.CreateElement("TH");
                            headerElem.InnerText = col.Name;
                            tableRow.AppendChild(headerElem);
                            break;
                    }
                }

                // Create table rows.
                HtmlElement tableBody = seriesDoc.CreateElement("TBODY");
                tableElem.AppendChild(tableBody);
                foreach (Series dr in Data.DataSeriesList)
                {
                    tableRow = seriesDoc.CreateElement("TR");
                    tableBody.AppendChild(tableRow);


                    foreach (PropertyInfo col in typeof(Series).GetProperties())
                    {
                        if (col.Name != "lala")
                        {
                            Object dbCell = col.GetValue(dr, null);
                            HtmlElement tableCell = seriesDoc.CreateElement("TD");
                            switch (col.Name)
                            {
                                case "SortingProperty":
                                case "SeriesEpisodes":
                                case "Genere":
                                    break;
                                case "SeriesName":
                                    if (dbCell != null)
                                    {
                                        HtmlElement linkEl = seriesDoc.CreateElement("A");
                                        linkEl.AddAtribute("href", "?" + MyHtml.enCodeUrlPart(dbCell.ToString()));
                                        linkEl.InnerText = dbCell.ToString();
                                        tableCell.AppendChild(linkEl);
                                    }
                                    tableRow.AppendChild(tableCell);
                                    break;
                                default:
                                    if (dbCell != null)
                                    {
                                        tableCell.InnerText = dbCell.ToString();
                                    }
                                    tableRow.AppendChild(tableCell);
                                    break;
                            }
                        }
                    }
                }
                SeriesDoc = seriesDoc;
            }
        }
        public HtmlDocument SeriesEpisodeData(string seriesName)
        {
            HtmlDocument seriesEpisodeDoc = new HtmlDocument("SeriesEpisode.html");

            
            int index = 0;
            while (Data.DataSeriesList[index].SeriesName != seriesName)
            {
                if (Data.DataSeriesList.Count == index + 1)
                {
                    seriesEpisodeDoc.InnerText = "series " + seriesName + " not found!";
                    return seriesEpisodeDoc;
                }
                index++;
            } 

            HtmlElement tableRow = null;
            HtmlElement headerElem = null;

            
            HtmlElement titleElem = seriesEpisodeDoc.CreateElement("TITLE");
            titleElem.InnerText = Data.DataSeriesList[index].SeriesName;
            seriesEpisodeDoc.AppendChild(titleElem);


            HtmlElement bodyElem = seriesEpisodeDoc.CreateElement("BODY");
            seriesEpisodeDoc.AppendChild(bodyElem);

            HtmlElement linkElem = seriesEpisodeDoc.CreateElement("A href=\"" + SeriesDoc.FileName + "\"");
            linkElem.InnerText = "<---Series";
            bodyElem.AppendChild(linkElem);

            HtmlElement tableElem = seriesEpisodeDoc.CreateElement("TABLE border=1");
            bodyElem.AppendChild(tableElem);

            HtmlElement tableHeader = seriesEpisodeDoc.CreateElement("THEAD");
            tableElem.AppendChild(tableHeader);
            tableRow = seriesEpisodeDoc.CreateElement("TR");
            tableHeader.AppendChild(tableRow);

            //actions
            headerElem = seriesEpisodeDoc.CreateElement("TH");
            headerElem.InnerText = "Actions";
            tableRow.AppendChild(headerElem);

            foreach (PropertyInfo col in typeof(SeriesEpisode).GetProperties())
            {
                switch (col.Name)
                {
                    case "SortingProperty":
                        break;
                    default:
                        headerElem = seriesEpisodeDoc.CreateElement("TH");
                        headerElem.InnerText = col.Name;
                        tableRow.AppendChild(headerElem);
                        break;
                }
            }

            // Create table rows.
            HtmlElement tableBody = seriesEpisodeDoc.CreateElement("TBODY");
            tableElem.AppendChild(tableBody);
            foreach (SeriesEpisode dr in Data.DataSeriesList[index].SeriesEpisodes)
            {
                tableRow = seriesEpisodeDoc.CreateElement("TR");
                tableBody.AppendChild(tableRow);

                //actions
                HtmlElement tableCella = seriesEpisodeDoc.CreateElement("TD");

                HtmlElement linkEle = seriesEpisodeDoc.CreateElement("A href=\"" +
                   "?" + MyHtml.enCodeUrlPart(dr.SeriesName) +
                   "&play=" + HttpUtility.UrlEncode(MyHtml.enCodeUrlPart(dr.EpisodeName)) + "#" + HttpUtility.UrlEncode(MyHtml.enCodeUrlPart(dr.EpisodeName)) + "\"");
                linkEle.InnerText = "-play on host";
                tableCella.AppendChild(linkEle);

                HtmlElement brEle = seriesEpisodeDoc.CreateElement("HR",true);
                tableCella.AppendChild(brEle);

                HtmlElement linkEle2 = seriesEpisodeDoc.CreateElement("A href=\"" +
                    "?" + MyHtml.enCodeUrlPart(dr.SeriesName) + "&opendir=" + HttpUtility.UrlEncode(MyHtml.enCodeUrlPart(dr.EpisodeName)) + "#" + HttpUtility.UrlEncode(MyHtml.enCodeUrlPart(dr.EpisodeName)) + "\"");
                linkEle2.InnerText = "-open directory on host";
                tableCella.AppendChild(linkEle2);

                tableCella.AppendChild(brEle);

                HtmlElement linkEle3 = seriesEpisodeDoc.CreateElement("A href=\"" +
                    "?" + MyHtml.enCodeUrlPart(dr.SeriesName) + "&stream=" + HttpUtility.UrlEncode(MyHtml.enCodeUrlPart(dr.EpisodeName)) + "#" + HttpUtility.UrlEncode(MyHtml.enCodeUrlPart(dr.EpisodeName)) + "\"");
                linkEle3.InnerText = "-stream with vlc";
                tableCella.AppendChild(linkEle3);

                tableCella.AppendChild(brEle);

                HtmlElement linkEle4 = seriesEpisodeDoc.CreateElement("A href=\"" +
                    "stream.html" + "\"");
                linkEle4.AddAtribute("target", "_blank");
                linkEle4.InnerText = "-open vlc stream";
                tableCella.AppendChild(linkEle4);

                tableCella.AppendChild(brEle);

                HtmlElement linkEle5 = seriesEpisodeDoc.CreateElement("A href=\"" +
                "getfile=series!" + MyHtml.enCodeUrlPart(dr.SeriesName) + "!" + HttpUtility.UrlEncode(MyHtml.enCodeUrlPart(dr.EpisodeName)) + "#" + HttpUtility.UrlEncode(MyHtml.enCodeUrlPart(dr.EpisodeName)) + "\"");
                linkEle5.InnerText = "-download";
                tableCella.AppendChild(linkEle5);

                tableCella.AppendChild(brEle);

                HtmlElement linkEle6 = seriesEpisodeDoc.CreateElement("A href=\"" +
                    "?" + MyHtml.enCodeUrlPart(dr.SeriesName) + "&streamlistadd=" + HttpUtility.UrlEncode(MyHtml.enCodeUrlPart(dr.EpisodeName)) + "#" + HttpUtility.UrlEncode(MyHtml.enCodeUrlPart(dr.EpisodeName)) + "\"");
                linkEle6.InnerText = "-add file to streamingplaylist";
                tableCella.AppendChild(linkEle6);

                tableCella.AppendChild(brEle);

                HtmlElement linkEle7 = seriesEpisodeDoc.CreateElement("A href=\"" +
                    "?" + MyHtml.enCodeUrlPart(dr.SeriesName) + "&playstreamlist=" + HttpUtility.UrlEncode(MyHtml.enCodeUrlPart(dr.EpisodeName)) + "#" + HttpUtility.UrlEncode(MyHtml.enCodeUrlPart(dr.EpisodeName)) + "\"");
                linkEle7.InnerText = "-play streamingplaylist";
                tableCella.AppendChild(linkEle7);

                tableCella.AppendChild(brEle);

                HtmlElement linkEle8 = seriesEpisodeDoc.CreateElement("A href=\"" +
                    "?" + MyHtml.enCodeUrlPart(dr.SeriesName) + "&clearstreamlist=" + HttpUtility.UrlEncode(MyHtml.enCodeUrlPart(dr.EpisodeName)) + "#" + HttpUtility.UrlEncode(MyHtml.enCodeUrlPart(dr.EpisodeName)) + "\"");
                linkEle8.InnerText = "-clear streamingplaylist";
                tableCella.AppendChild(linkEle8);
                

                tableCella.AppendChild(brEle);

                HtmlElement linkEle9 = seriesEpisodeDoc.CreateElement("A href=\"" +
                    "/playlist.html" + "\"");
                linkEle9.AddAtribute("target", "_blank");
                linkEle9.InnerText = "-streamingplaylist";
                tableCella.AppendChild(linkEle9);

                tableRow.AppendChild(tableCella);
                foreach (PropertyInfo col in typeof(SeriesEpisode).GetProperties())
                {
                    Object dbCell = col.GetValue(dr, null);
                    HtmlElement tableCell = seriesEpisodeDoc.CreateElement("TD");
                    switch (col.Name)
                    {
                        case "SortingProperty":
                            break;           
             
                        case "EpisodeName":
                            HtmlElement anchEl = SeriesDoc.CreateElement("A");
                            anchEl.AddAtribute("name",HttpUtility.UrlEncode(MyHtml.enCodeUrlPart(dbCell.ToString())));
                            anchEl.InnerText = dbCell.ToString();
                            tableCell.AppendChild(anchEl);
                            tableRow.AppendChild(tableCell);
                            break;
                        default:
                            if (dbCell != null)
                            {
                                tableCell.InnerText = dbCell.ToString();
                            }
                            tableRow.AppendChild(tableCell);
                            break;
                    }
                }
            }
            return seriesEpisodeDoc;
        }
    
    }
}
