﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ThiesMediaProject.Properties;
using ThiesMediaProject.General;
using System.Net;
using System.Diagnostics;

namespace ThiesMediaProject
{
    public partial class MainForm : Form
    {
        FilmForm fF = new FilmForm();
        SeriesForm sF = new SeriesForm();
        MusikForm mF = new MusikForm();

        public MainForm()
        {            
            InitializeComponent();
            this.Size = Settings.Default.MainFormSize;
            Translate.TranslateForm(this);
            this.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            this.Icon = Properties.Resources.tmp_icon;
        }

        private void filmsButton_Click(object sender, EventArgs e)
        {
            fF = new FilmForm();
            fF.DataSource = Data.DataFilms;
            formShowTimer.Enabled = true;
            fF.Show();
        }

        private void seriesButton_Click(object sender, EventArgs e)
        {
            sF = new SeriesForm();
            formShowTimer.Enabled = true;
            sF.Show();
        }

        private void musikButton_Click(object sender, EventArgs e)
        {
            mF = new MusikForm();
            formShowTimer.Enabled = true;
            mF.Show();
        }

        private void formShowTimer_Tick(object sender, EventArgs e)
        {

            foreach (Form item in Application.OpenForms)
            {
                if (item.Name != this.Name)
                {
                    this.Visible = false;
                    return;
                }
            }
            System.GC.Collect();
            formShowTimer.Enabled = false;
            if (FormWindowState.Minimized != this.WindowState)
            {
                this.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
                this.Visible = true;
            }
            
        }

        private void MainForm_Load(object sender, EventArgs e)
        {
            backgroundWorker1.RunWorkerAsync();
            if (!Settings.Default.SettingsAssiUsed)
            {
                new SettingForms.SettingsAssistentForm().ShowDialog();
                this.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            }
            formShowTimer.Enabled = true;
        }

        private void backgroundWorker1_DoWork(object sender, DoWorkEventArgs e)
        {
            try
            {
                WebClient wcWebclient = new WebClient();
                wcWebclient.OpenRead("http://www.dfsdfsdfasdfw222.de");
            }
            catch (WebException)
            {
                
            }
        }

        

        private void MainForm_Resize(object sender, EventArgs e)
        {
            if (FormWindowState.Minimized == this.WindowState)
            {
                notifyIcon1.Icon = this.Icon;
                notifyIcon1.Text = Application.ProductName;
                notifyIcon1.BalloonTipTitle = "Application minimized";
                notifyIcon1.BalloonTipText = "Application is now minimized to tray";
                notifyIcon1.Visible = true;
                notifyIcon1.ShowBalloonTip(500);
                ShowInTaskbar = false;
                Visible = false;
            }
            else if (FormWindowState.Normal == this.WindowState)
            {
                notifyIcon1.Visible = false;
            }
        }

        private void notifyIcon1_DoubleClick(object sender, EventArgs e)
        {
            this.ShowInTaskbar = true;
            Visible = true;
            this.WindowState = FormWindowState.Normal;
            this.Activate();
        }

        private void infoButton_Click(object sender, EventArgs e)
        {
            var frm = new AboutBox().ShowDialog();
        }

        private void setupButton_Click(object sender, EventArgs e)
        {
            new SettingForms.SettingsAssistentForm().ShowDialog();
            this.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
        }

        private void checkForUpdatesButton_Click(object sender, EventArgs e)
        {
            var updateInfo = new UpdateInfo();
            updateInfo.Load();
            if (updateInfo.VersionNo != Application.ProductVersion)
            {
                if (MessageBox.Show(
                    string.Format("Your version is {0}, version {1} is available. Do you want to download update now?",
                        Application.ProductVersion,updateInfo.VersionNo),
                    "update",
                    MessageBoxButtons.YesNo) == System.Windows.Forms.DialogResult.Yes)
                {
                    Process.Start(updateInfo.UpdateUrl);
                }
            }
            else
            {
                MessageBox.Show("Your version is up to date!!!");
            }
        }

        private void tableLayoutPanel1_Paint(object sender, PaintEventArgs e)
        {

        }

        private void MainForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            this.WindowState = FormWindowState.Normal;
            Settings.Default.MainFormSize = this.Size;
            Settings.Default.Save();
        }
    }
}
