﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ThiesMediaProject.Properties;
using ThiesMediaProject.SettingForms;
using ThiesMediaProject.General;
using ThiesMediaProject.ToolForms;
using System.IO;
using System.Threading;
using ThiesGeneral.MsOffice;
using System.Drawing.Imaging;
using ThiesGeneral.Media.VLC_Streaming;

namespace ThiesMediaProject
{
    public partial class SeriesForm : Form
    {
        SeriesList mySeriesList = new SeriesList();

        private int indexOfItemUnderMouseToDrag;

        private Rectangle dragBoxFromMouseDown;
        private Point screenOffset;
        static public string[] FilesToStream;

        public SeriesForm()
        {
            InitializeComponent();
            this.Size = Settings.Default.SeriesFormSize;
            Translate.TranslateForm(this);
            this.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            seriesEpisodeBindingNavigator.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            mainFormMenuStrip.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            bindingNavigatorPositionItem.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            this.Icon = Properties.Resources.tmp_icon;
        }

        private void SeriesForm_Load(object sender, EventArgs e)
        {
            if (Data.DataSeriesList.Count > 0)
            {
                Data.DataSeriesList.Sort(TypeDescriptor.GetProperties(new Series())["SeriesName"],
                    ListSortDirection.Ascending);
                mySeriesList = Data.DataSeriesList;
                seriesBindingSource.DataSource = mySeriesList;
                seriesEpisodeBindingSource.DataSource = mySeriesList[0].SeriesEpisodes;

                seriesDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);
                seriesEpisodeDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);
                changeBackColor();
                if (Settings.Default.SeriesColumnsNotToShow != null)
                {
                    foreach (string item in Settings.Default.SeriesColumnsNotToShow)
                    {
                        foreach (DataGridViewColumn column in seriesEpisodeDataGridView.Columns)
                        {
                            if (column.HeaderText == item)
                            {
                                column.Visible = false;
                            }
                        }
                    }
                }
            }
        }

        private void pathSettingsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            var sPf = new SeriesPathForm();
            sPf.ShowDialog();
            ReloadSeries();
        }

        private void seriesEpisodeBindingNavigator_RefreshItems(object sender, EventArgs e)
        {

        }

        private void seriesEpisodeBindingNavigator_RefreshItems_1(object sender, EventArgs e)
        {

        }

        private void reloadFilmsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            ReloadSeries();
        }

        private void ReloadSeries()
        {
            Data.ReloadSeries(true);
            mySeriesList = Data.DataSeriesList;
            seriesBindingSource.DataSource = mySeriesList;
            seriesEpisodeBindingSource.DataSource = mySeriesList[0].SeriesEpisodes;
            if (Data.DataSeriesList.Count > 0)
            {
                Data.DataSeriesList.Sort(TypeDescriptor.GetProperties(new Series())["SeriesName"],
                    ListSortDirection.Ascending);
            }
            seriesDataGridView.Refresh();
            seriesEpisodeDataGridView.Refresh();
            changeBackColor();
            seriesDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);
            seriesEpisodeDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);
            if (seriesDataGridView.Rows.Count > 0)
            {
                seriesDataGridView.CurrentCell = seriesDataGridView.Rows[0].Cells[0];
                seriesDataGridView_CellEnter(this, new DataGridViewCellEventArgs(0, 0));
                if (seriesEpisodeDataGridView.Rows.Count > 0)
                {
                    seriesEpisodeDataGridView.CurrentCell = seriesEpisodeDataGridView.Rows[0].Cells[0];
                }
            }            
        }

        private void playButton_Click(object sender, EventArgs e)
        {
            selectRowsFromCells();
            string[] fileTypes = {
            "*.mpcpl",
            "*.asx",
            "*.mpls",
            "*.mkv", 
            "*.avi",
            "*.divx",
            "*.mpg",
            "*.ogm",
            "*.mpeg",
            "*.ts",
            "*.m2ts",
            "video_ts.ifo",
            "*.nrg",
            "*.iso",
            "*.img",
            "*.wmv",
            "*.mp4"
        };
            selectRowsFromCells();

            if (seriesEpisodeDataGridView.SelectedRows.Count > 1)
            {
                if (MessageBox.Show("Make and play Playlist?",
                    "Playlist",
                    MessageBoxButtons.YesNo,
                    MessageBoxIcon.Question) == System.Windows.Forms.DialogResult.Yes)
                {
                    List<string> myFiles = new List<string>();
                    Films filmList = new Films();
                    foreach (DataGridViewRow item in seriesEpisodeDataGridView.SelectedRows)
                    {
                        myFiles.Add(mySeriesList[seriesDataGridView.CurrentRow.Index].SeriesEpisodes[
                            item.Index].FilePath);
                        mySeriesList[seriesDataGridView.CurrentRow.Index].SeriesEpisodes[item.Index].LastTimePlayed = DateTime.Now;
                        mySeriesList[seriesDataGridView.CurrentRow.Index].SeriesEpisodes[item.Index].SaveXML(mySeriesList[seriesDataGridView.CurrentRow.Index]);
                    }
                    Data.Save();
                    var FMP = new MultiPlayForm();
                    FMP.addFilms(myFiles.ToArray(),filmList, Application.CommonAppDataPath);
                    FMP.ShowDialog();
                }
            }
            else
            {
                if (seriesEpisodeDataGridView.CurrentRow != null)
                {
                    mySeriesList[seriesDataGridView.CurrentRow.Index].SeriesEpisodes[
                        seriesEpisodeDataGridView.CurrentRow.Index].OpenVideoInFolder();
                }
            }


            
        }

        private void playToolStripMenuItem_Click(object sender, EventArgs e)
        {
            playButton_Click(sender, e);
        }

        private void openDirectoryButtton_Click(object sender, EventArgs e)
        {
            selectRowsFromCells();
            if (seriesEpisodeDataGridView.CurrentRow != null)
            {
                mySeriesList[seriesDataGridView.CurrentRow.Index].SeriesEpisodes[
                    seriesEpisodeDataGridView.CurrentRow.Index].OpenVideoFolder();
            }
        }

        private void openDirectoryToolStripMenuItem_Click(object sender, EventArgs e)
        {
            openDirectoryButtton_Click(sender, e);
        }

        private void endToolStripMenuItem_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void searchTextBox_TextChanged(object sender, EventArgs e)
        {
            foreach (Series series in mySeriesList)
            {
                foreach (SeriesEpisode seriesEpisode in series.SeriesEpisodes)
                {
                    foreach (var property in seriesEpisode.GetType().GetProperties())
                    {
                        if (property.GetValue(seriesEpisode, null).ToString().ToUpper().Contains(searchTextBox.Text.ToUpper()))
                        {
                            seriesDataGridView.CurrentCell =
                                seriesDataGridView.Rows[mySeriesList.IndexOf(series)].Cells[0];
                            seriesEpisodeDataGridView.CurrentCell =
                                seriesEpisodeDataGridView.Rows[series.SeriesEpisodes.IndexOf(seriesEpisode)].Cells[0];
                            return;
                        }
                    }
                }
            }
        }


        private void Next()
        {
            if ((seriesDataGridView.CurrentRow != null) && (seriesEpisodeDataGridView.CurrentRow != null))
            {
                for (int a = seriesDataGridView.CurrentRow.Index; a < mySeriesList.Count; a++)
                {
                    int beginIndex;
                    if (a == seriesDataGridView.CurrentRow.Index)
                    {
                        beginIndex = seriesEpisodeDataGridView.CurrentRow.Index + 1;
                    }
                    else
                        beginIndex = 0;
                    for (int i = beginIndex; i < mySeriesList[a].SeriesEpisodes.Count; i++)
                    {
                        foreach (var property in mySeriesList[a].SeriesEpisodes[i].GetType().GetProperties())
                        {
                            if (property.GetValue(mySeriesList[a].SeriesEpisodes[i], null) != null)
                            {
                                if (property.GetValue(mySeriesList[a].SeriesEpisodes[i], null).ToString().ToUpper().Contains(searchTextBox.Text.ToUpper()))
                                {
                                    seriesDataGridView.CurrentCell =
                                        seriesDataGridView.Rows[a].Cells[0];
                                    seriesEpisodeDataGridView.CurrentCell =
                                        seriesEpisodeDataGridView.Rows[i].Cells[0];
                                    return;
                                }
                            }
                        }
                    }
                }
            }
        }

        private void searchTextBox_KeyUp(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Enter)
            {
                Next();
            }
        }

        private void nextButton_Click(object sender, EventArgs e)
        {
            Next();
        }

        private void Filter()
        {
            if (filterTextbox.Text != "")
            {
                seriesDataGridView.EditMode = DataGridViewEditMode.EditProgrammatically;
                mySeriesList = new SeriesList();
                foreach (Series series in Data.DataSeriesList)
                {
                    Series series2 = series.Clone();
                    foreach (SeriesEpisode seriesEpisode in series.SeriesEpisodes)
                    {
                        foreach (var property in seriesEpisode.GetType().GetProperties())
                        {
                            if (property.GetValue(seriesEpisode, null).ToString().ToUpper().Contains(filterTextbox.Text.ToUpper()))
                            {
                                if (mySeriesList.Contains(series2))
                                {
                                    mySeriesList[mySeriesList.IndexOf(series2)].SeriesEpisodes.Add(seriesEpisode);
                                }
                                else
                                {
                                    mySeriesList.Add(series2);
                                    mySeriesList[mySeriesList.IndexOf(series2)].SeriesEpisodes.Add(seriesEpisode);
                                }
                            }
                            break;
                        }
                    }
                }
            }
            else
            {
                seriesDataGridView.EditMode = DataGridViewEditMode.EditOnKeystrokeOrF2;
                mySeriesList = Data.DataSeriesList;
            }
            seriesBindingSource.DataSource = mySeriesList;
            seriesEpisodeBindingSource.DataSource = mySeriesList[0].SeriesEpisodes;
            seriesEpisodeDataGridView.Refresh();
            seriesDataGridView.Refresh();
            changeBackColor();
            seriesDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);
            seriesEpisodeDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);
        }

        private void filterButton_Click(object sender, EventArgs e)
        {
            Filter();
        }

        private void seriesDataGridView_CellEndEdit(object sender, DataGridViewCellEventArgs e)
        {
            mySeriesList[seriesDataGridView.CurrentRow.Index].SaveXML();
            Data.Save();
        }

        private void seriesEpisodeDataGridView_CellEndEdit(object sender, DataGridViewCellEventArgs e)
        {
            mySeriesList[seriesDataGridView.CurrentRow.Index].
                SeriesEpisodes[seriesEpisodeDataGridView.CurrentRow.Index].
                SaveXML(mySeriesList[seriesDataGridView.CurrentRow.Index]);
            Data.Save();
        }

        private void toolStripMenuItem1_Click(object sender, EventArgs e)
        {
            if (seriesEpisodeDataGridView.CurrentCell != null)
            {
                if (seriesEpisodeDataGridView.SelectedCells.Count == 0)
                {
                    seriesEpisodeDataGridView.CurrentCell.Selected = true;
                }
                new PropertyChangerForm(seriesEpisodeDataGridView.SelectedCells).ShowDialog();
                foreach (DataGridViewCell cell in seriesEpisodeDataGridView.SelectedCells)
                {
                    mySeriesList[seriesDataGridView.CurrentRow.Index].
                        SeriesEpisodes[cell.RowIndex].SaveXML(mySeriesList[seriesDataGridView.CurrentRow.Index]);
                }
                Data.Save();
            }
        }

        private void filePropertiesToolStripMenuItem_Click(object sender, EventArgs e)
        {
            selectRowsFromCells();
            var myNewSeries = new Series();
            foreach (DataGridViewRow row in seriesEpisodeDataGridView.SelectedRows)
            {
                myNewSeries.SeriesEpisodes.Add(
                    mySeriesList[seriesDataGridView.CurrentRow.Index].SeriesEpisodes[
                        row.Index]);
            }
            new SeriesFilePropertyForm(myNewSeries).ShowDialog();
            Data.Save();
        }

        private void filterTextbox_KeyUp(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Enter)
            {
                Filter();
            }
        }

        private void wishlistToolStripMenuItem_Click(object sender, EventArgs e)
        {
            new WishListForm().ShowDialog();
        }

        private void specialPropertyChangerToolStripMenuItem_Click(object sender, EventArgs e)
        {
            BindingList<SpecialPropertyChanger> myCells = new BindingList<SpecialPropertyChanger>();
            foreach (DataGridViewCell item in seriesEpisodeDataGridView.SelectedCells)
            {
                var myCell = new SpecialPropertyChanger();
                myCell.ValueBeforeChange = item.Value.ToString();
                myCells.Add(myCell);
            }
            var mySPCF = new SpecialPropertyChangerForm();
            mySPCF.MProperties = myCells;
            mySPCF.ShowDialog();

            int i = 0;
            foreach (SpecialPropertyChanger item in myCells)
            {
                seriesEpisodeDataGridView.SelectedCells[i].Value = item.ValueAfterChange;
                mySeriesList[seriesDataGridView.CurrentRow.Index].
                    SeriesEpisodes[seriesEpisodeDataGridView.SelectedCells[i].RowIndex].SaveXML(mySeriesList[seriesDataGridView.CurrentRow.Index]);
                i++;
            }
            Data.Save();
        }

        private void seriesEpisodeDataGridView_ColumnHeaderMouseClick(object sender, DataGridViewCellMouseEventArgs e)
        {
            if (seriesEpisodeDataGridView.SortedColumn == seriesEpisodeDataGridView.Columns[e.ColumnIndex])
            {
                if (seriesEpisodeDataGridView.SortOrder == SortOrder.Ascending)
                {
                    seriesEpisodeDataGridView.Sort(seriesEpisodeDataGridView.Columns[e.ColumnIndex], ListSortDirection.Ascending);
                }
                else
                {
                    seriesEpisodeDataGridView.Sort(seriesEpisodeDataGridView.Columns[e.ColumnIndex], ListSortDirection.Descending);
                }
            }
            else
                seriesEpisodeDataGridView.Sort(seriesEpisodeDataGridView.Columns[e.ColumnIndex], ListSortDirection.Ascending);
            seriesEpisodeDataGridView.Refresh();
            changeBackColor();
            seriesEpisodeDataGridView.CurrentCell = seriesEpisodeDataGridView.Rows[0].Cells[0];
        }

        private void numerateCellsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            int i = seriesEpisodeDataGridView.SelectedCells.Count;
            foreach (DataGridViewCell item in seriesEpisodeDataGridView.SelectedCells)
            {
                item.Value = i;
                i--;
                mySeriesList[seriesDataGridView.CurrentRow.Index].
                    SeriesEpisodes[item.RowIndex].SaveXML(mySeriesList[seriesDataGridView.CurrentRow.Index]);
            }
            Data.Save();
        }

        private void columnDontShowToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (seriesEpisodeDataGridView.CurrentCell != null)
            {
                if (Settings.Default.SeriesColumnsNotToShow == null)
                {
                    Settings.Default.SeriesColumnsNotToShow = new System.Collections.Specialized.StringCollection();
                }
                Settings.Default.SeriesColumnsNotToShow.Add(
                    seriesEpisodeDataGridView.CurrentCell.OwningColumn.HeaderText);
                seriesEpisodeDataGridView.CurrentCell.OwningColumn.Visible = false;
                Settings.Default.Save();
            }
        }

        private void columnsSettingsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            new SeriesColumnsForm().ShowDialog();

            foreach (DataGridViewColumn column in seriesEpisodeDataGridView.Columns)
            {
                column.Visible = true;
            }

            if (Settings.Default.SeriesColumnsNotToShow != null)
            {
                foreach (string item in Settings.Default.SeriesColumnsNotToShow)
                {
                    foreach (DataGridViewColumn column in seriesEpisodeDataGridView.Columns)
                    {
                        if (column.HeaderText == item)
                        {
                            column.Visible = false;
                        }
                    }
                }
            }
        }

        private void selectRowsFromCells()
        {
            foreach (DataGridViewCell item in seriesEpisodeDataGridView.SelectedCells)
            {
                item.OwningRow.Selected = true;
            }
        }

        private void exportToExcelToolStripMenuItem_Click(object sender, EventArgs e)
        {
            var myExcel = new MyExcelSerializer();
            myExcel.Seriliaze(Data.DataSeriesList,@"C:\MyExcel.xls");
        }

        private void excelExportToolStripMenuItem_Click(object sender, EventArgs e)
        {

        }

        private void generalSettingsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            var gS = new GeneralSettingsForm();
            gS.ShowDialog();
            this.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            seriesEpisodeBindingNavigator.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            mainFormMenuStrip.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            bindingNavigatorPositionItem.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
        }

        private void seriesEpisodeDataGridView_MouseDown(object sender, MouseEventArgs e)
        {
            // Get the index of the item the mouse is below.
            indexOfItemUnderMouseToDrag = seriesDataGridView.CurrentRow.Index;

            if (indexOfItemUnderMouseToDrag != ListBox.NoMatches)
            {

                // Remember the point where the mouse down occurred. The DragSize indicates
                // the size that the mouse can move before a drag event should be started.                
                Size dragSize = SystemInformation.DragSize;

                // Create a rectangle using the DragSize, with the mouse position being
                // at the center of the rectangle.
                dragBoxFromMouseDown = new Rectangle(new Point(e.X - (dragSize.Width / 2),
                                                               e.Y - (dragSize.Height / 2)), dragSize);
            }
            else
                // Reset the rectangle if the mouse is not over an item in the ListBox.
                dragBoxFromMouseDown = Rectangle.Empty;


        }

        private void seriesEpisodeDataGridView_MouseUp(object sender, MouseEventArgs e)
        {
            // Reset the drag rectangle when the mouse button is raised.
            dragBoxFromMouseDown = Rectangle.Empty;
        }

        private void seriesEpisodeDataGridView_MouseMove(object sender, MouseEventArgs e)
        {
            if (activateDragCheckBox.Checked)
            {
                if ((e.Button & MouseButtons.Left) == MouseButtons.Left)
                {

                    // If the mouse moves outside the rectangle, start the drag.
                    if (dragBoxFromMouseDown != Rectangle.Empty &&
                        !dragBoxFromMouseDown.Contains(e.X, e.Y))
                    {
                        // The screenOffset is used to account for any desktop bands 
                        // that may be at the top or left side of the screen when 
                        // determining when to cancel the drag drop operation.
                        screenOffset = SystemInformation.WorkingArea.Location;

                        // Proceed with the drag-and-drop, passing in the list item.                    
                        selectRowsFromCells();
                        List<string> mF = new List<string>();
                        foreach (DataGridViewRow item in seriesEpisodeDataGridView.SelectedRows)
                        {
                            mF.Add(
                                mySeriesList[seriesDataGridView.CurrentRow.Index].SeriesEpisodes[
                                    item.Index].FilePath);
                        }
                        string[] mf = mF.ToArray();
                        DragDropEffects dropEffect = seriesDataGridView.DoDragDrop(
                            new DataObject(DataFormats.FileDrop, mf),
                            DragDropEffects.All | DragDropEffects.Link);

                    }
                }
            }
        }

        private void toolStripButton2_Click(object sender, EventArgs e)
        {
            new FilmForm().Show();
            this.Close();
        }

        private void toolStripButton1_Click(object sender, EventArgs e)
        {
            new MusikForm().Show();
            this.Close();
        }

        private void seriesDataGridView_CellEnter(object sender, DataGridViewCellEventArgs e)
        {
            if (seriesDataGridView.CurrentRow != null && !seriesDataGridView.Disposing)
            {
                seriesEpisodeBindingSource.DataSource = mySeriesList[e.RowIndex].SeriesEpisodes;
                seriesDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);
                seriesEpisodeDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);
                changeBackColor();
            }    
        }

        private void streamingButton_Click(object sender, EventArgs e)
        {
            streamingContextMenuStrip.Show(streamingButton, new Point(streamingButton.Width, 0));
        }

        private void streamToolStripMenuItem2_Click(object sender, EventArgs e)
        {
            if (seriesEpisodeDataGridView.CurrentRow != null)
            {
                SeriesEpisode mySeriesEpisode =
                    mySeriesList[seriesDataGridView.CurrentRow.Index].
                        SeriesEpisodes[seriesEpisodeDataGridView.CurrentRow.Index];
                mySeriesEpisode.StreamVideoInFolder();
            }
        }

        private void addToStreaminglistToolStripMenuItem2_Click(object sender, EventArgs e)
        {
            List<string> filesToStream = new List<string>();
            if (FilesToStream != null)
            {
                filesToStream.AddRange(FilesToStream);
            }
            selectRowsFromCells();
            if (seriesEpisodeDataGridView.SelectedRows != null)
            {
                foreach (DataGridViewRow item in seriesEpisodeDataGridView.SelectedRows)
                {
                    SeriesEpisode mySeriesEpisode =
                    mySeriesList[seriesDataGridView.CurrentRow.Index].
                        SeriesEpisodes[item.Index];
                    filesToStream.Add(mySeriesEpisode.FilePath);
                }
            }
            FilesToStream = filesToStream.ToArray();
        }

        private void streamStreaminglistToolStripMenuItem2_Click(object sender, EventArgs e)
        {
            if (FilesToStream != null)
            {
                VlcStreaming.PathToVLC = Settings.Default.VlcPath;
                VlcStreaming.Filenames = FilesToStream;
                VlcStreaming.OpenPlaylist_Stream(Settings.Default.VlcStreamingParameter);
            }
        }

        private void clearStreaminglistToolStripMenuItem2_Click(object sender, EventArgs e)
        {
            FilesToStream = null;
        }

        private void streaminglistToolStripMenuItem2_Click(object sender, EventArgs e)
        {
            if (FilesToStream != null)
            {
                StreamPlayForm sPF = new StreamPlayForm();
                sPF.AddFilms(FilesToStream);
                sPF.ShowDialog();
                FilesToStream = sPF.ReturnFilms();
            }
        }

        private void seriesDataGridView_DataError(object sender, DataGridViewDataErrorEventArgs e)
        {

        }

        private void seriesEpisodeDataGridView_DataError(object sender, DataGridViewDataErrorEventArgs e)
        {

        }

        private void SeriesForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            this.WindowState = FormWindowState.Normal;
            Settings.Default.SeriesFormSize = this.Size;
            Settings.Default.Save();
        }

        private void seriesEpisodeDataGridView_DoubleClick(object sender, EventArgs e)
        {
            playButton_Click(sender, new EventArgs());
        }

        private void statisticToolStripMenuItem_Click(object sender, EventArgs e)
        {
            new SeriesStatisticForm().Show();
        }

        private void changeBackColor()
        {
            bool changeColor = false;
            foreach (DataGridViewRow item in seriesDataGridView.Rows)
            {
                if (changeColor)
                {
                    item.DefaultCellStyle.BackColor = Color.AntiqueWhite;
                    changeColor = false;
                }
                else
                {
                    changeColor = true;
                }

            }

            changeColor = false;
            foreach (DataGridViewRow item in seriesEpisodeDataGridView.Rows)
            {
                if (changeColor)
                {
                    item.DefaultCellStyle.BackColor = Color.AntiqueWhite;
                    changeColor = false;
                }
                else
                {
                    changeColor = true;
                }

            }
        }

        private void seriesDataGridView_CellContentClick(object sender, DataGridViewCellEventArgs e)
        {

        }
    }
}
