﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ThiesMediaProject.Properties;
using ThiesMediaProject.General;

namespace ThiesMediaProject.SettingForms
{
    public partial class SettingsAssistentForm : Form
    {
        List<Panel> AssiPanels = new List<Panel>();
        List<string> DescriptionList = new List<string>();
        List<string> UnderDescriptionList = new List<string>();

        int CurrentPanelNo = -1;
        public SettingsAssistentForm()
        {
            InitializeComponent();
            this.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            this.Icon = Properties.Resources.tmp_icon;
            AssiPanels.Add(panel1);
            DescriptionList.Add(Translate.GetText("General Settings"));
            UnderDescriptionList.Add(Translate.GetText("set general settings"));

            AssiPanels.Add(panel2);
            DescriptionList.Add(Translate.GetText("Film Paths"));
            UnderDescriptionList.Add(Translate.GetText("set Filmpaths for example D:\\Films"));

            AssiPanels.Add(panel3);
            DescriptionList.Add(Translate.GetText("Series Paths"));
            UnderDescriptionList.Add(Translate.GetText("set Seriespaths for example D:\\Series"));

            AssiPanels.Add(panel4);
            DescriptionList.Add(Translate.GetText("Music Paths"));
            UnderDescriptionList.Add(Translate.GetText("set Musicpaths for example D:\\Music"));

            AssiPanels.Add(panel5);
            DescriptionList.Add(Translate.GetText("Webservices Settings"));
            UnderDescriptionList.Add(Translate.GetText("set these for Webservice settings"));

            AssiPanels.Add(panel6);
            DescriptionList.Add(Translate.GetText("VLC Settings"));
            UnderDescriptionList.Add(Translate.GetText("set these if you want to stream via VLC"));

            Translate.TranslateForm(this);
            foreach (Panel item in AssiPanels)
            {
                item.Visible = false;
            }
            Size formSize = new Size(panel0.Width, descriptionPanel.Height + panel0.Height + buttonPanel.Height);
            this.ClientSize = formSize;
            panel0.Visible = false;
            descriptionLabel.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize) + 3);
        }

        private void SettingsAssistentForm_Load(object sender, EventArgs e)
        {
            LoadSettingsFromDefault();
            ShowNextPanel();
        }


        private void LoadSettingsFromDefault()
        {
            Settings.Default.Reload();
            formFontSizeTextBox.Text = Settings.Default.FormFontSize;
            proofFilmFoldersInBackgroundCheckBox.Checked = Settings.Default.ProofFilmFoldersInBackground;
            proofMusikFoldersInBackgroundCheckBox.Checked = Settings.Default.ProofMusikFoldersInBackground;
            proofSeriesFoldersInBackgroundCheckBox.Checked = Settings.Default.ProofSeriesFoldersInBackground;
            durationProofTextBox.Text = Settings.Default.DurationProof.ToString();
            webServerCheckBox.Checked = Settings.Default.WebServer;
            webServerPortTextbox.Text = Settings.Default.WebServerPort.ToString();
            vlcPathTextBox.Text = Settings.Default.VlcPath;
            vlcStreamingParameterTextBox.Text = Settings.Default.VlcStreamingParameter;
            daemonToolsTextBox.Text = Settings.Default.DaemonToolsPath;

            if (Settings.Default.Paths != null)
            {
                foreach (String item in Settings.Default.Paths)
                {
                    filmPathsListBox.Items.Add(item);
                }    
            }

            if (Settings.Default.MusikPaths != null)
            {
                foreach (String item in Settings.Default.MusikPaths)
                {
                    musikPathsListBox.Items.Add(item);
                }    
            }

            if (Settings.Default.SeriesPaths != null)
            {
                foreach (String item in Settings.Default.SeriesPaths)
                {
                    seriesPathsListBox.Items.Add(item);
                }    
            }
            
        }

        private void SaveSettingsToDefault()
        {
            Settings.Default.FormFontSize = formFontSizeTextBox.Text;
            Settings.Default.ProofFilmFoldersInBackground = proofFilmFoldersInBackgroundCheckBox.Checked;
            Settings.Default.ProofMusikFoldersInBackground = proofMusikFoldersInBackgroundCheckBox.Checked;
            Settings.Default.ProofSeriesFoldersInBackground = proofSeriesFoldersInBackgroundCheckBox.Checked;
            Settings.Default.DurationProof = Convert.ToInt32(durationProofTextBox.Text);
            Settings.Default.WebServer = webServerCheckBox.Checked;
            Settings.Default.WebServerPort = Convert.ToInt32(webServerPortTextbox.Text);
            Settings.Default.VlcPath = vlcPathTextBox.Text;
            Settings.Default.VlcStreamingParameter = vlcStreamingParameterTextBox.Text;
            Settings.Default.DaemonToolsPath = daemonToolsTextBox.Text;

            if (Settings.Default.Paths != null)
            {
                Settings.Default.Paths.Clear();    
            }
            else
            {
                Settings.Default.Paths = new System.Collections.Specialized.StringCollection();
            }
            foreach (String item in filmPathsListBox.Items)
            {
                Settings.Default.Paths.Add(item);
            }

            if (Settings.Default.MusikPaths != null)
            {
                Settings.Default.MusikPaths.Clear();
            }
            else
            {
                Settings.Default.MusikPaths = new System.Collections.Specialized.StringCollection();
            }            
            foreach (String item in musikPathsListBox.Items)
            {
                Settings.Default.MusikPaths.Add(item);
            }

            if (Settings.Default.SeriesPaths != null)
            {
                Settings.Default.SeriesPaths.Clear();
            }
            else
            {
                Settings.Default.SeriesPaths = new System.Collections.Specialized.StringCollection();
            }            
            foreach (String item in seriesPathsListBox.Items)
            {
                Settings.Default.SeriesPaths.Add(item);
            }
            Settings.Default.SettingsAssiUsed = true;
            Settings.Default.Save();



            Data.ReloadFilms(true);
            Data.ReloadMusik(true);
            Data.ReloadSeries(true);
            if (TMPWebserver.IsStarted && !Settings.Default.WebServer)
            {
                TMPWebserver.StopWebSever();
            }

            if (!TMPWebserver.IsStarted && Settings.Default.WebServer)
            {
                TMPWebserver.StartWebSever();
            }
        }

        private void ShowNextPanel()
        {
            CurrentPanelNo++;
            if (CurrentPanelNo != 0)
            {
                AssiPanels[CurrentPanelNo - 1].Visible = false;
            }
            AssiPanels[CurrentPanelNo].Location = panel0.Location;
            AssiPanels[CurrentPanelNo].Visible = true;
            UpdateButtonPanel();
            UpdateDescriptionPanel();
        }

        private void ShowPrevPanel()
        {
            CurrentPanelNo--;
            if (CurrentPanelNo != AssiPanels.Count - 1)
            {
                AssiPanels[CurrentPanelNo + 1].Visible = false;
            }
            AssiPanels[CurrentPanelNo].Location = panel0.Location;
            AssiPanels[CurrentPanelNo].Visible = true;
            UpdateButtonPanel();
            UpdateDescriptionPanel();
        }

        private void UpdateDescriptionPanel()
        {
            descriptionLabel.Text = DescriptionList[CurrentPanelNo];
            underDescriptionLabel.Text = UnderDescriptionList[CurrentPanelNo];
        }

        private void UpdateButtonPanel()
        {
            finishButton.Location = nextButton.Location;
            finishButton.Visible = (CurrentPanelNo == AssiPanels.Count - 1);
            prevButton.Enabled = (CurrentPanelNo > 0);
            nextButton.Enabled = (CurrentPanelNo != AssiPanels.Count - 1);
            nextButton.Visible = (CurrentPanelNo != AssiPanels.Count - 1);
        }

        private void nextButton_Click(object sender, EventArgs e)
        {
            ShowNextPanel();
        }

        private void prevButton_Click(object sender, EventArgs e)
        {
            ShowPrevPanel();
        }

        private void finishButton_Click(object sender, EventArgs e)
        {
            SaveSettingsToDefault();
            this.Close();
        }

        private void buttonAdd_Click(object sender, EventArgs e)
        {
            if (folderBrowserDialog1.ShowDialog()== System.Windows.Forms.DialogResult.OK)
	        {
                filmPathsListBox.Items.Add(folderBrowserDialog1.SelectedPath);		 
	        }
        }

        private void button2_Click(object sender, EventArgs e)
        {
            if (folderBrowserDialog1.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                seriesPathsListBox.Items.Add(folderBrowserDialog1.SelectedPath);
            }
        }

        private void button4_Click(object sender, EventArgs e)
        {
            if (folderBrowserDialog1.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                musikPathsListBox.Items.Add(folderBrowserDialog1.SelectedPath);
            }
        }

        private void buttonDelete_Click(object sender, EventArgs e)
        {
            if (filmPathsListBox.SelectedItem != null)
            {
                filmPathsListBox.Items.Remove(filmPathsListBox.SelectedItem);
            }
        }

        private void button1_Click(object sender, EventArgs e)
        {
            if (seriesPathsListBox.SelectedItem != null)
            {
                seriesPathsListBox.Items.Remove(seriesPathsListBox.SelectedItem);
            }
        }

        private void button3_Click(object sender, EventArgs e)
        {
            if (musikPathsListBox.SelectedItem != null)
            {
                musikPathsListBox.Items.Remove(musikPathsListBox.SelectedItem);
            }
        }

        private void vlcPathButton_Click(object sender, EventArgs e)
        {
            openFileDialog1.Filter = "vlc.exe|vlc.exe";
            if (openFileDialog1.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                vlcPathTextBox.Text = openFileDialog1.FileName;
            }
        }

        private void searchForDaemonToolsButton_Click(object sender, EventArgs e)
        {
            openFileDialog1.Filter = "DTLite.exe|DTLite.exe";
            if (openFileDialog1.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                daemonToolsTextBox.Text = openFileDialog1.FileName;
            }
        }
    }
}
