﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO;
using System.Web;
using ThiesGeneral.Web;
using ThiesGeneral.Media.VLC_Streaming;
using ThiesMediaProject.General;
using ThiesMediaProject.Properties;
using ThiesGeneral.Web.WebServer;


namespace ThiesMediaProject
{
    public static class TMPWebserver
    {
        static public ThiesGeneral.Web.WebServer.Server MyWebServer;
        static public HtmlData Hd;
        static public string[] FilesToStream;

        public static bool IsStarted { get; set; }

        static public void StartWebSever()
        {
            Hd = new HtmlData();
            try
            {
                string HtmlPath = "";
                MyWebServer = new ThiesGeneral.Web.WebServer.Server(Settings.Default.WebServerPort, 5000, HtmlPath);
                MyWebServer.ApplicationOrder += new applicationOrder_event(GetOrdersFromWebserver);
                MyWebServer.GetFile += new fileGet_event(MyWebServer_GetFile);
                MyWebServer.GetStream += new streamGet_event(MyWebServer_GetStream);
                MyWebServer.Start();
                IsStarted = true;
            }
            catch (Exception)
            {

            }

        }

        static void MyWebServer_GetStream(string s, ref System.IO.Stream stream)
        {
            Hd = new HtmlData();
            string parameter = string.Empty;
            if (s.Contains("?"))
            {
                string[] split = s.Split("?".ToCharArray());
                s = split[0];
                parameter = split[1];
            }
            byte[] byteArray = null;
            switch (s)
            {
                case "/":
                case "/index.html":
                    byteArray = Encoding.UTF8.GetBytes(Hd.IndexDoc.GetInnerText());
                    stream = new MemoryStream(byteArray);
                    break;
                case "/films.html":
                    GetOrdersFromWebserver(parameter);
                    byteArray = Encoding.UTF8.GetBytes(Hd.FilmsDoc.GetInnerText());
                    stream = new MemoryStream(byteArray);
                    break;
                case "/series.html":
                    if (parameter != "")
                    {
                        parameter = HttpUtility.UrlDecode(parameter);
                        string seriesName = string.Empty;
                        string seriesEpisodeName = string.Empty;
                        string order = string.Empty;
                        if (parameter.Contains("="))
                        {
                            string[] split = parameter.Split("=".ToCharArray());
                            if (split[0].Contains("&"))
                            {
                                seriesEpisodeName = MyHtml.deCodeUrlPart(split[1]);
                                split = split[0].Split("&".ToCharArray());
                                seriesName = MyHtml.deCodeUrlPart(split[0]);
                                order = split[1];
                                switch (order)
                                {
                                    case "play":
                                        var mySeriesEpisode = Data.DataSeriesList.GetSeriesEpisode(seriesName, seriesEpisodeName);
                                        mySeriesEpisode.OpenVideoInFolder();
                                        break;
                                    case "opendir":
                                        var mySeriesEpisode2 = Data.DataSeriesList.GetSeriesEpisode(seriesName, seriesEpisodeName);
                                        mySeriesEpisode2.OpenVideoFolder();
                                        break;
                                    case "stream":
                                        var mySeriesEpisode3 = Data.DataSeriesList.GetSeriesEpisode(seriesName, seriesEpisodeName);
                                        mySeriesEpisode3.StreamVideoInFolder();
                                        break;
                                    case "streamlistadd":
                                        var mySeriesEpisode4 = Data.DataSeriesList.GetSeriesEpisode(seriesName, seriesEpisodeName);
                                        if (FilesToStream == null)
                                        {
                                            FilesToStream = new string[1];
                                            FilesToStream[0] = mySeriesEpisode4.FilePath;
                                        }
                                        else
                                        {
                                            Array.Resize(ref FilesToStream, FilesToStream.Count() + 1);
                                            FilesToStream[FilesToStream.Count() - 1] = mySeriesEpisode4.FilePath;
                                        }
                                        break;
                                    case "playstreamlist":
                                        if (FilesToStream != null)
                                        {
                                            VlcStreaming.PathToVLC = Settings.Default.VlcPath;
                                            VlcStreaming.Filenames = FilesToStream;
                                            VlcStreaming.OpenPlaylist_Stream(Settings.Default.VlcStreamingParameter);
                                        }
                                        break;
                                    case "clearstreamlist":
                                        FilesToStream = null;
                                        break;
                                    default:
                                        break;
                                }
                            }
                            else
                            {
                                seriesName = MyHtml.deCodeUrlPart(split[0]);
                            }


                        }
                        else
                        {
                            seriesName = MyHtml.deCodeUrlPart(parameter);
                        }
                        byteArray = Encoding.UTF8.GetBytes(Hd.SeriesEpisodeData(seriesName).GetInnerText());
                        stream = new MemoryStream(byteArray);
                    }
                    else
                    {
                        byteArray = Encoding.UTF8.GetBytes(Hd.SeriesDoc.GetInnerText());
                        stream = new MemoryStream(byteArray);
                    }

                    break;
                case "/music.html":
                    if (parameter != "")
                    {
                        parameter = HttpUtility.UrlDecode(parameter);
                        string musicName = string.Empty;
                        string seriesEpisodeName = string.Empty;
                        string order = string.Empty;
                        if (parameter.Contains("="))
                        {
                            string[] sortOrderShowParameter;
                            string sortParameter = "Artist";
                            string filterParameter = "";
                            string showParameter = "0";
                            string sortOrderParameter = "0";

                            if (parameter.Contains("&"))
                            {
                                sortOrderShowParameter = parameter.Split("&".ToCharArray());
                                parameter = sortOrderShowParameter[0];
                                filterParameter = sortOrderShowParameter[1].Split("=".ToCharArray())[1];
                                sortParameter = sortOrderShowParameter[2].Split("=".ToCharArray())[1];
                                showParameter = sortOrderShowParameter[3].Split("=".ToCharArray())[1];
                                sortOrderParameter = sortOrderShowParameter[4].Split("=".ToCharArray())[1];
                            }
                            string[] split = parameter.Split("=".ToCharArray());
                            musicName = MyHtml.deCodeUrlPart(split[1]);
                            order = split[0];
                            switch (order)
                            {
                                case "play":
                                    Data.DataMusikList.GetMusicFileById(musicName).OpenMusikFile();

                                    break;
                                case "opendir":
                                    Data.DataMusikList.GetMusicFileById(musicName).OpenMusikFolder();
                                    break;
                                case "stream":
                                    VlcStreaming.PathToVLC = Settings.Default.VlcPath;
                                    VlcStreaming.Filename = Data.DataMusikList.GetMusicFileById(musicName).FilePath;
                                    VlcStreaming.Open_Stream(Settings.Default.VlcStreamingParameter);                                    
                                    break;
                                case "addtoplaylist":
                                    if (FilesToStream == null)
                                    {
                                        FilesToStream = new string[1];
                                        FilesToStream[0] = Data.DataMusikList.GetMusicFileById(musicName).FilePath;
                                    }
                                    else
                                    {
                                        Array.Resize(ref FilesToStream, FilesToStream.Count() + 1);
                                        FilesToStream[FilesToStream.Count() - 1] = Data.DataMusikList.GetMusicFileById(musicName).FilePath;
                                    }
                                    break;
                                case "playstreaming":
                                    if (FilesToStream != null)
                                    {
                                        VlcStreaming.PathToVLC = Settings.Default.VlcPath;
                                        VlcStreaming.Filenames = FilesToStream;
                                        VlcStreaming.OpenPlaylist_Stream(Settings.Default.VlcStreamingParameter);
                                    }
                                    break;
                                case "clearstreamlist":
                                    FilesToStream = null;
                                    break;
                                default:
                                    break;
                            }
                            Hd.SortAndFilterMusicData(sortParameter, filterParameter, Convert.ToInt32(showParameter),Convert.ToByte(sortOrderParameter));
                        }
                        else
                        {
                            musicName = MyHtml.deCodeUrlPart(parameter);
                        }
                        byteArray = Encoding.UTF8.GetBytes(Hd.MusicDoc.GetInnerText());
                        stream = new MemoryStream(byteArray);
                    }
                    else
                    {
                        byteArray = Encoding.UTF8.GetBytes(Hd.MusicDoc.GetInnerText());
                        stream = new MemoryStream(byteArray);
                    }

                    break;
                case "/stream.html":
                    byteArray = Encoding.UTF8.GetBytes(Hd.StreamDoc.GetInnerText());
                    stream = new MemoryStream(byteArray);
                    break;
                case "/playlist.html":
                    if (FilesToStream != null)
                    {
                        if (parameter != "")
                        {
                            if (parameter.Contains("delete"))
                            {
                                string[] split = parameter.Split("=".ToCharArray());
                                string[] newFilesToStream = new string[FilesToStream.Count() - 1];
                                int i = 0;
                                int a = 0;
                                foreach (var item in FilesToStream)
                                {
                                    if (i.ToString() != split[1])
                                    {
                                        newFilesToStream[a] = FilesToStream[i];
                                        a++;
                                    }
                                    i++;
                                }
                                FilesToStream = newFilesToStream;
                            }
                            if ((parameter.Contains("up")) || (parameter.Contains("down")))
                            {
                                string[] split = parameter.Split("=".ToCharArray());
                                string[] newFilesToStream = new string[FilesToStream.Count()];
                                int i = 0;
                                foreach (string item in FilesToStream)
                                {
                                    if (i.ToString() != split[1])
                                    {
                                        newFilesToStream[i] = FilesToStream[i];
                                    }
                                    else
                                    {
                                        if (parameter.Contains("up"))
                                        {
                                            newFilesToStream[i] = newFilesToStream[i - 1];
                                            newFilesToStream[i - 1] = FilesToStream[i];
                                        }
                                        else
                                        {
                                            newFilesToStream[i] = FilesToStream[i + 1];
                                            FilesToStream[i + 1] = FilesToStream[i];
                                        }

                                    }
                                    i++;
                                }
                                FilesToStream = newFilesToStream;
                            }
                        }
                        string htmlString = string.Empty;
                        int index = 0;
                        foreach (string item in FilesToStream)
                        {
                            htmlString = htmlString + "<a href=playlist.html?delete=" + index.ToString() + ">" +
                                item + "</a>";
                            if (index > 0)
                            {
                                htmlString = htmlString + " | <a href=playlist.html?up=" + index.ToString() + ">" +
                                "up" + "</a>";
                            }
                            if (index < FilesToStream.Count() - 1)
                            {
                                htmlString = htmlString + " | <a href=playlist.html?down=" + index.ToString() + ">" +
                                "down" + "</a>";
                            }
                            htmlString = htmlString + "<br>";
                            index++;
                        }
                        byteArray = Encoding.UTF8.GetBytes(htmlString);
                        stream = new MemoryStream(byteArray);
                    }
                    break;
                default:
                    break;
            }

        }

        static public void StopWebSever()
        {
            if (MyWebServer != null)
            {
                try
                {
                    MyWebServer.Stop();
                    IsStarted = false;
                }
                catch (Exception)
                {

                }
            }
        }

        static void MyWebServer_GetFile(string s, ref string filePath)
        {
            if (s.Contains("film"))
            {
                string filmId = s.Split("!".ToCharArray())[1];
                var myFilm = Data.DataFilms.GetFilmById(filmId);
                filePath = myFilm.GetVideoFilePath();
            }
            if (s.Contains("series"))
            {
                s = HttpUtility.UrlDecode(s);
                string seriesName = s.Split("!".ToCharArray())[1];
                string seriesEpisodeName = s.Split("!".ToCharArray())[2];
                var mySeriesEpisode = Data.DataSeriesList.GetSeriesEpisode(seriesName, seriesEpisodeName);
                filePath = mySeriesEpisode.FilePath;
            }
            if (s.Contains("music"))
            {
                string musicId = s.Split("!".ToCharArray())[1];
                var myMusicFile = Data.DataMusikList.GetMusicFileById(musicId);
                filePath = myMusicFile.FilePath;
            }

        }
       
        private static void GetOrdersFromWebserver(string orderString)
        {
            string order = string.Empty;
            string orderParameter = string.Empty;
            string orderParameter2 = string.Empty;

            orderString = HttpUtility.UrlDecode(orderString);
            if (orderString.Contains("="))
            {
                string[] orderStringSplit = orderString.Split("=".ToCharArray());
                order = orderStringSplit[0];
                orderParameter = orderStringSplit[1];
                if (orderStringSplit.Count() == 3)
                {
                    orderParameter2 = orderStringSplit[2];
                }

                switch (order)
                {
                    case "filter":
                        Hd.FilterFilmData(orderParameter);
                        break;
                    case "sortascending":
                        if (orderParameter2 == "")
                        {
                            Hd.SortFilmData(orderParameter,true);    
                        }
                        else
                        {
                            Hd.SortAndFilterFilmData(orderParameter, orderParameter2,true);
                        }
                        break;
                    case "sortdescending":
                        if (orderParameter2 == "")
                        {
                            Hd.SortFilmData(orderParameter,false);
                        }
                        else
                        {
                            Hd.SortAndFilterFilmData(orderParameter, orderParameter2,false);
                        }
                        break;
                    case "play":
                        var myFilm = Data.DataFilms.GetFilmById(orderParameter);
                        myFilm.OpenVideoInFolder();
                        break;
                    case "opendir":
                        var myFilm2 = Data.DataFilms.GetFilmById(orderParameter);
                        myFilm2.OpenVideoFolder();
                        break;
                    case "stream":
                        var myFilm3 = Data.DataFilms.GetFilmById(orderParameter);
                        myFilm3.StreamVideoInFolder();
                        break;
                    case "addtoplaylist":
                        var myFilm4 = Data.DataFilms.GetFilmById(orderParameter);
                        if (FilesToStream == null)
                        {
                            FilesToStream = new string[1];
                            FilesToStream[0] = myFilm4.GetVideoFilePath();
                        }
                        else
                        {
                            Array.Resize(ref FilesToStream, FilesToStream.Count() + 1);
                            FilesToStream[FilesToStream.Count() - 1] = myFilm4.GetVideoFilePath();
                        }
                        break;
                    case "playstreaming":
                        if (FilesToStream != null)
                        {
                            VlcStreaming.PathToVLC = Settings.Default.VlcPath;
                            VlcStreaming.Filenames = FilesToStream;
                            VlcStreaming.OpenPlaylist_Stream(Settings.Default.VlcStreamingParameter);
                        }
                        break;
                    case "clearstreaming":
                        FilesToStream = null;
                        break;
                    default:
                        break;
                }
            }
        }
    }
}
