﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using Microsoft.VisualBasic.FileIO;
using System.Windows.Forms;
using System.IO;
using ThiesMediaProject.Properties;
using ThiesGeneral.FileFunctions;
using ThiesMediaProject.General;

namespace ThiesMediaProject.ToolForms
{
    public partial class CopyToolForm : Form
    {
        Films MyFilms = new Films();
        public CopyToolForm(Films myFilms)
        {
            InitializeComponent();
            this.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            this.Icon = Properties.Resources.tmp_icon;
            MyFilms = myFilms;
        }

        private void label4_Click(object sender, EventArgs e)
        {

        }

        private void button3_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void FormCopyTool_Load(object sender, EventArgs e)
        {
            listViewTargetFolder.Columns.Add("Pfad");
            listViewTargetFolder.Columns.Add("Freier Speicher");
            if (Settings.Default.Paths != null)
            {
                foreach (string strFolder in Settings.Default.Paths)
                {
                    ListViewItem lviItem = listViewTargetFolder.Items.Add(strFolder);
                    decimal dcSize = Convert.ToDecimal(Folder.GetFreeSpaceFromFolder(strFolder)) / 1024 / 1024 / 1024;
                    lviItem.SubItems.Add(
                        dcSize.ToString("F2")
                        + " GB"
                        );
                }
                listViewTargetFolder.AutoResizeColumns(ColumnHeaderAutoResizeStyle.HeaderSize);
            }
            else
            {
                this.Close();
            }
            
        }

        private void buttonSelectMainFolder_Click(object sender, EventArgs e)
        {
            if (textBoxMainFolder.Text != "")
            {
                folderBrowserDialogMainFolder.SelectedPath = textBoxMainFolder.Text;
            }
            folderBrowserDialogMainFolder.ShowDialog();
            if (folderBrowserDialogMainFolder.SelectedPath != "")
            {
                textBoxMainFolder.Text = folderBrowserDialogMainFolder.SelectedPath;
                textBoxVideoFolder.Text = textBoxMainFolder.Text;
            }
        }

        private void buttonSelectVideoFolder_Click(object sender, EventArgs e)
        {
            
            if (folderBrowserDialogMainFolder.SelectedPath != "")
            {

                folderBrowserDialogVideoFolder.SelectedPath =
                    folderBrowserDialogMainFolder.SelectedPath;
                folderBrowserDialogVideoFolder.ShowDialog();
                if (folderBrowserDialogVideoFolder.SelectedPath != "")
                {
                    textBoxVideoFolder.Text = folderBrowserDialogVideoFolder.SelectedPath;
                    decimal dcSize = Convert.ToDecimal(Folder.GetFolderSize(textBoxVideoFolder.Text)) /1024/1024/1024;
                    textBoxSize.Text = dcSize.ToString("F2") + " GB";
                    textBoxTargetName.Text = new DirectoryInfo(textBoxVideoFolder.Text).Name;
                }
            }

        }

        private void buttonCopy_Click(object sender, EventArgs e)
        {
            if ((textBoxMainFolder.Text != "") &
                (textBoxVideoFolder.Text != "") &
                (textBoxTargetName.Text != "") &
                (listViewTargetFolder.SelectedItems.Count > 0))
            {
                if (checkBoxDeleteRar.Checked)
                {
                    Folder.DeleteAllRarFilesInFolder(
                        textBoxVideoFolder.Text);
                }
                Folder.CopyOrMoveFilesFromFolderToNewFolder(
                    textBoxVideoFolder.Text,
                    listViewTargetFolder.SelectedItems[0].Text + @"\" +
                        textBoxTargetName.Text);
                Film myFilm = new Film(listViewTargetFolder.SelectedItems[0].Text + @"\" +
                        textBoxTargetName.Text, Data.DataFilms.GetNewFilmId());
                MyFilms.Add(myFilm);
                if (MyFilms != Data.DataFilms)
                {
                    Data.DataFilms.Add(myFilm);
                    Data.Save();
                }

                MessageBox.Show("copied or moved!", "Finished", MessageBoxButtons.OK, MessageBoxIcon.Information);
            }
            else
            {
                MessageBox.Show("Not all required fields selected" , "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void buttonDeleteMainDirectory_Click(object sender, EventArgs e)
        {
            if (textBoxMainFolder.Text != "")
            {
                try
                {
                    FileSystem.DeleteDirectory(textBoxMainFolder.Text, DeleteDirectoryOption.DeleteAllContents);
                    textBoxMainFolder.Text = "";
                    textBoxVideoFolder.Text = "";
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message,"Error",MessageBoxButtons.OK,MessageBoxIcon.Error);
                }
            }
            else
            {
                MessageBox.Show("Not all required fields selected", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

        }

        private void button1_Click(object sender, EventArgs e)
        {
            if (textBoxVideoFolder.Text != "")
            {
                try
                {
                    FileSystem.DeleteDirectory(textBoxVideoFolder.Text, DeleteDirectoryOption.DeleteAllContents);
                    textBoxVideoFolder.Text = "";
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
            else
            {
                MessageBox.Show("Not all required fields selected", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void checkBox1_CheckedChanged(object sender, EventArgs e)
        {
            if (textBoxVideoFolder.Text != "")
            {
                var dInfo = new DirectoryInfo(textBoxVideoFolder.Text);
                long rarSize = 0;
                if (checkBoxDeleteRar.Checked)
                {


                    foreach (FileInfo item in dInfo.GetFiles("*.rar", System.IO.SearchOption.AllDirectories))
                    {
                        rarSize += item.Length;

                    }
                }

                textBoxVideoFolder.Text = folderBrowserDialogVideoFolder.SelectedPath;
                decimal dcSize = (Convert.ToDecimal(Folder.GetFolderSize(textBoxVideoFolder.Text))
                    -rarSize)
                    / 1024 / 1024 / 1024;
                textBoxSize.Text = dcSize.ToString("F2") + " GB";
            }
        }

        private void textBoxMainFolder_TextChanged(object sender, EventArgs e)
        {
            textBoxVideoFolder.Text = textBoxMainFolder.Text;
            folderBrowserDialogMainFolder.SelectedPath = textBoxMainFolder.Text;
            if (textBoxMainFolder.Text != "")
            {
                if (Directory.GetDirectories(textBoxMainFolder.Text).Count() > 0)
                {
                    folderBrowserDialogVideoFolder.SelectedPath = Directory.GetDirectories(textBoxMainFolder.Text)[0];
                    textBoxVideoFolder.Text = folderBrowserDialogVideoFolder.SelectedPath;
                    decimal dcSize = Convert.ToDecimal(Folder.GetFolderSize(textBoxVideoFolder.Text)) / 1024 / 1024 / 1024;
                    textBoxSize.Text = dcSize.ToString("F2") + " GB";
                    textBoxTargetName.Text = new DirectoryInfo(textBoxVideoFolder.Text).Name;
                }
                else
                {
                    folderBrowserDialogVideoFolder.SelectedPath = textBoxVideoFolder.Text;
                    decimal dcSize = Convert.ToDecimal(Folder.GetFolderSize(textBoxVideoFolder.Text)) / 1024 / 1024 / 1024;
                    textBoxSize.Text = dcSize.ToString("F2") + " GB";
                    textBoxTargetName.Text = new DirectoryInfo(textBoxVideoFolder.Text).Name;
                }
            }            
        }

        private void textBoxVideoFolder_TextChanged(object sender, EventArgs e)
        {

        }
    }
}
