﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Net;
using System.Windows.Forms;
using System.IO;
using ThiesMediaProject.General;
using ThiesGeneral.Web;
using ThiesMediaProject.Properties;
using System.Threading;
using System.Diagnostics;
using System.Collections;

namespace ThiesMediaProject.ToolForms
{
    public partial class IMDBForm : Form
    {
        FilmToChange[] MyFilmsToChange;
        List<Thread> Threads = new List<Thread>();
        DateTime StartingTime;
        bool Finished = false;

        public IMDBForm()
        {
            InitializeComponent();
            this.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            this.Icon = Properties.Resources.tmp_icon;
        }

        private void FormIMDB_Load(object sender, EventArgs e)
        {
            StartingTime = DateTime.Now;
            new Thread(new ThreadStart(LoadFilms)).Start();
        }

        private void LoadFilms()
        {
            int loadingFilms = 0;
            foreach (FilmToChange lviItem in MyFilmsToChange)
            {
                while (loadingFilms -LoadedFilms() > 2)
                {
                    Thread.Sleep(100);
                }
                Thread filmThread = new Thread(new ParameterizedThreadStart(LoadPageFilmSearch));
                filmThread.Start(lviItem);
                Threads.Add(filmThread);
                loadingFilms++;
            }
        }

        private int LoadedFilms()
        {
            int i = 0;
            foreach (FilmToChange item in MyFilmsToChange)
            {
                if (item.FilmLoadedBool)
                {
                    i++;
                }
            }
            return i;
        }

        private void LoadPageFilmSearch(Object stateInfo)
        {
            FilmToChange item = (FilmToChange)stateInfo;
            item.loadPageFilmSearch(1);
        }

        public void setItemsToChange(Films selectedFilms)
        {
            MyFilmsToChange = new FilmToChange[selectedFilms.Count];
            int i = 0;
            foreach (Film Item in selectedFilms)
            {
                ListViewItem lVI = listViewFilmsToUpdate.Items.Add(Item.Filmname);
                lVI.SubItems.Add(false.ToString());
                lVI.SubItems.Add("0");
                lVI.SubItems.Add("0");
                lVI.SubItems.Add("");
                lVI.SubItems.Add("0");
                MyFilmsToChange[i] = new FilmToChange(Item.Filmname, Item.Path,Item);
                i++;
            }
            ResizeColumnsFilmsToUpdate();
        }

        private void fillIMDBList()
        {
            foreach (ListViewItem lviItem in listViewIMDBTitel.Items)
            {
                lviItem.Remove();
            }

            foreach (ListViewItem lviItem in listViewEigenschaften.Items)
            {
                lviItem.Remove();
            }

            IMDBFilm[] IMDBFilms;
            IMDBFilms = MyFilmsToChange[listViewFilmsToUpdate.SelectedItems[0].Index].getIMDBFilms();
            foreach(IMDBFilm IMDBFilm in IMDBFilms)
            {
                if (IMDBFilm != null)
                {
                    listViewIMDBTitel.Items.Add(IMDBFilm.FilmTitelString).SubItems.Add(IMDBFilm.FilmIdString);    
                }
            }
        }

        private void fillEigenschaftenList()
        {
            foreach (ListViewItem lviItem in listViewEigenschaften.Items)
            {
                lviItem.Remove();
            }

            IMDBFilm IMDBFilm;
            IMDBFilm = MyFilmsToChange[listViewFilmsToUpdate.SelectedItems[0].Index].
                            IMDBFilme[listViewIMDBTitel.SelectedItems[0].Index];

            for (int i = 0; i < IMDBFilm.AnzahlEigenschaften; i++)
            {
                ListViewItem lviItem =
                listViewEigenschaften.Items.Add(IMDBFilm.EigenschaftenNamenStringArray[i]);
                lviItem.
                    SubItems.Add(IMDBFilm.EigenschaftenWerteStringArray[i]);
                lviItem.
                    SubItems.Add(IMDBFilm.EigenschaftUebernehmenBooleanArray[i].ToString());
            }
            filmPictureBox.Image = IMDBFilm.MyPicture;
            
        }



        private void listViewFilmsToUpdate_SelectedIndexChanged(object sender, EventArgs e)
        {
            listViewIMDBTitel.Items.Clear();
            if (listViewFilmsToUpdate.SelectedItems.Count > 0)
            {
                if (MyFilmsToChange[listViewFilmsToUpdate.SelectedItems[0].Index].Status == FilmToChangeStatus.FilmsLoaded)
                {
                    fillIMDBList();
                }
            }
        }

        private void buttonLoadAllFilms_Click(object sender, EventArgs e)
        {
            
        }

        private void listViewIMDBTitel_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (listViewIMDBTitel.SelectedItems.Count > 0)
            {
                fillEigenschaftenList();
            }
        }

        private void timerUpdateGelesen_Tick(object sender, EventArgs e)
        {
            int i = 0;
            progressBar1.Maximum = listViewFilmsToUpdate.Items.Count;
            bool newChange = false;
            foreach (ListViewItem lviItem in listViewFilmsToUpdate.Items)
            {
                if (MyFilmsToChange[lviItem.Index].Status.ToString() != lviItem.SubItems[4].Text)
                {
                    lviItem.SubItems[4].Text = MyFilmsToChange[lviItem.Index].Status.ToString();
                    newChange = true;
                    if (MyFilmsToChange[lviItem.Index].Status == FilmToChangeStatus.FilmsLoaded)
                    {
                        if (true.ToString() != lviItem.SubItems[1].Text)
                        {
                            if (listViewFilmsToUpdate.SelectedItems.Count > 0)
                            {
                                if (listViewFilmsToUpdate.SelectedItems[0] == lviItem)
                                {
                                    listViewFilmsToUpdate_SelectedIndexChanged(this, new EventArgs());
                                }
                            }

                        }
                    }
                }

                if (MyFilmsToChange[lviItem.Index].TryCount.ToString() != lviItem.SubItems[2].Text)
                {
                    lviItem.SubItems[2].Text =
                        MyFilmsToChange[lviItem.Index].TryCount.ToString();
                }

                if (MyFilmsToChange[lviItem.Index].FilmsLoadedCount.ToString() != lviItem.SubItems[5].Text)
                {
                    lviItem.SubItems[5].Text =
                        MyFilmsToChange[lviItem.Index].FilmsLoadedCount.ToString();
                }


                if (MyFilmsToChange[lviItem.Index].IMDBFilme != null)
                {
                    if (MyFilmsToChange[lviItem.Index].IMDBFilme.Count().ToString() != lviItem.SubItems[3].Text)
                    {
                        lviItem.SubItems[3].Text =
                            MyFilmsToChange[lviItem.Index].IMDBFilme.Count().ToString();
                    }
                }



                if (MyFilmsToChange[lviItem.Index].FilmLoadedBool)
                {
                    i++;
                }
            }
            if (newChange)
            {
                if (!listViewFilmsToUpdate.IsDisposed)
                {
                    listViewFilmsToUpdate.AutoResizeColumns(ColumnHeaderAutoResizeStyle.ColumnContent);
                    ListView.ColumnHeaderCollection headers = new ListView.ColumnHeaderCollection(new ListView());
                    foreach (ColumnHeader item in listViewFilmsToUpdate.Columns)
                    {
                        ColumnHeader nHeader = new ColumnHeader();
                        nHeader.Width = item.Width;
                        headers.Add(nHeader);
                    }
                    listViewFilmsToUpdate.AutoResizeColumns(ColumnHeaderAutoResizeStyle.HeaderSize);
                    int c = 0;
                    foreach (ColumnHeader item in listViewFilmsToUpdate.Columns)
                    {
                        if (headers[c].Width > item.Width)
                        {
                            item.Width = headers[c].Width;
                        }
                        c++;
                    }
                }
                
                newChange = false;
            }
            statusLabel.Text = string.Format("{0}/{1}", i, listViewFilmsToUpdate.Items.Count);
            if ((i >0) && (i<listViewFilmsToUpdate.Items.Count))
            {
                TimeSpan runningTime = DateTime.Now - StartingTime;
                TimeSpan timeToRun = new TimeSpan(runningTime.Ticks / i * listViewFilmsToUpdate.Items.Count);
                timeToGoLabel.Text = string.Format("{0}/{1}", runningTime.ToString(@"hh\:mm\:ss"), timeToRun.ToString(@"hh\:mm\:ss"));
            }

            if ((i == listViewFilmsToUpdate.Items.Count) && !Finished)
            {
                Finished = true;
                TimeSpan runningTime = DateTime.Now - StartingTime;
                timeToGoLabel.Text = string.Format("{0}/{1}", runningTime.ToString(@"hh\:mm\:ss"), runningTime.ToString(@"hh\:mm\:ss"));
            }
            progressBar1.Value = i;

            
        }

        private void ResizeColumnsFilmsToUpdate()
        {
            listViewFilmsToUpdate.AutoResizeColumns(ColumnHeaderAutoResizeStyle.ColumnContent);
            ListView.ColumnHeaderCollection myColumns = listViewFilmsToUpdate.Columns;
            listViewFilmsToUpdate.AutoResizeColumns(ColumnHeaderAutoResizeStyle.HeaderSize);
            int i = 0;
            foreach (ColumnHeader item in myColumns)
            {
                if (item.Width > listViewFilmsToUpdate.Columns[i].Width)
                {
                    listViewFilmsToUpdate.Columns[i].AutoResize(ColumnHeaderAutoResizeStyle.ColumnContent);
                }
                i++;
            }
        }

        private void listViewEigenschaften_SelectedIndexChanged(object sender, EventArgs e)
        {

        }

        private void buttonUebernehmen_Click(object sender, EventArgs e)
        {
            if (listViewEigenschaften.SelectedItems.Count > 0)
            {
                MyFilmsToChange[listViewFilmsToUpdate.SelectedItems[0].Index].
                    IMDBFilme[listViewIMDBTitel.SelectedItems[0].Index].
                        EigenschaftUebernehmenBooleanArray[listViewEigenschaften.SelectedItems[0].Index] =
                            !MyFilmsToChange[listViewFilmsToUpdate.SelectedItems[0].Index].
                                    IMDBFilme[listViewIMDBTitel.SelectedItems[0].Index].
                                        EigenschaftUebernehmenBooleanArray[listViewEigenschaften.SelectedItems[0].Index];
                listViewEigenschaften.SelectedItems[0].SubItems[2].Text =
                    MyFilmsToChange[listViewFilmsToUpdate.SelectedItems[0].Index].
                                    IMDBFilme[listViewIMDBTitel.SelectedItems[0].Index].
                                        EigenschaftUebernehmenBooleanArray[listViewEigenschaften.SelectedItems[0].Index].ToString();
                listViewFilmsToUpdate.SelectedItems[0].SubItems[2].Text = true.ToString();

            }
        }

        private void buttonAllesUebernehmen_Click(object sender, EventArgs e)
        {
            foreach (ListViewItem lviItem in listViewEigenschaften.Items)
            {
                MyFilmsToChange[listViewFilmsToUpdate.SelectedItems[0].Index].
                    IMDBFilme[listViewIMDBTitel.SelectedItems[0].Index].
                        EigenschaftUebernehmenBooleanArray[lviItem.Index] =
                            !MyFilmsToChange[listViewFilmsToUpdate.SelectedItems[0].Index].
                                    IMDBFilme[listViewIMDBTitel.SelectedItems[0].Index].
                                        EigenschaftUebernehmenBooleanArray[lviItem.Index];
                lviItem.SubItems[2].Text =
                    MyFilmsToChange[listViewFilmsToUpdate.SelectedItems[0].Index].
                                    IMDBFilme[listViewIMDBTitel.SelectedItems[0].Index].
                                        EigenschaftUebernehmenBooleanArray[lviItem.Index].ToString();
                listViewFilmsToUpdate.SelectedItems[0].SubItems[2].Text = true.ToString();
            }

        }

        private void FormIMDB_FormClosed(object sender, FormClosedEventArgs e)
        {
            foreach (FilmToChange item in MyFilmsToChange)
            {
                item.CancelLoads();
            }
            foreach (Thread item in Threads)
            {
                item.Abort();
            }
        }

        private void buttonNameAendern_Click(object sender, EventArgs e)
        {
            if (listViewFilmsToUpdate.SelectedItems.Count > 0)
            {

                InputBoxForm InpBox = new InputBoxForm();
                InpBox.Text = "Name ändern";
                InpBox.ValueString = listViewFilmsToUpdate.SelectedItems[0].Text;
                InpBox.ShowDialog();
                if (InpBox.ValueString != listViewFilmsToUpdate.SelectedItems[0].Text)
                {
                    listViewFilmsToUpdate.SelectedItems[0].Text = InpBox.ValueString;
                    MyFilmsToChange[listViewFilmsToUpdate.SelectedItems[0].Index].FilmLoadedBool = false;
                    MyFilmsToChange[listViewFilmsToUpdate.SelectedItems[0].Index].FilmNameString = InpBox.ValueString;
                    Thread filmThread = new Thread(new ParameterizedThreadStart(LoadPageFilmSearch));
                    filmThread.Start(MyFilmsToChange[listViewFilmsToUpdate.SelectedItems[0].Index]);
                    Threads.Add(filmThread);
                }
            }
        }

        private void buttonOk_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void OkButton_Click(object sender, EventArgs e)
        {
            if (MyFilmsToChange != null)
            {


                foreach (FilmToChange FilmTochange in MyFilmsToChange)
                {
                    if (FilmTochange.IMDBFilme != null)
                    {
                        foreach (IMDBFilm SubFilmToChange in FilmTochange.IMDBFilme)
                        {

                            for (int i = 0; i < SubFilmToChange.AnzahlEigenschaften; i++)
                            {
                                if (SubFilmToChange.EigenschaftUebernehmenBooleanArray[i])
                                {
                                    if (SubFilmToChange.EigenschaftenNamenStringArray[i] == "Filmname")
                                    {
                                        FilmTochange.TheFilm.Filmname =
                                            SubFilmToChange.EigenschaftenWerteStringArray[i];
                                    }

                                    if (SubFilmToChange.EigenschaftenNamenStringArray[i] == "Darsteller")
                                    {
                                        FilmTochange.TheFilm.Actors =
                                            SubFilmToChange.EigenschaftenWerteStringArray[i];
                                    }

                                    if (SubFilmToChange.EigenschaftenNamenStringArray[i] == "IMDB-ID")
                                    {
                                        FilmTochange.TheFilm.IMDBID =
                                            SubFilmToChange.EigenschaftenWerteStringArray[i];
                                    }

                                    if (SubFilmToChange.EigenschaftenNamenStringArray[i] == "Premieredatum")
                                    {
                                        try
                                        {
                                            FilmTochange.TheFilm.YearOfPrime =
                                            int.Parse(SubFilmToChange.EigenschaftenWerteStringArray[i]);
                                        }
                                        catch (Exception)
                                        {

                                        }

                                    }

                                    if (SubFilmToChange.EigenschaftenNamenStringArray[i] == "Genres")
                                    {
                                        FilmTochange.TheFilm.Genre =
                                            SubFilmToChange.EigenschaftenWerteStringArray[i];
                                    }

                                    if (SubFilmToChange.EigenschaftenNamenStringArray[i] == "Regie")
                                    {
                                        FilmTochange.TheFilm.Regie =
                                            SubFilmToChange.EigenschaftenWerteStringArray[i];
                                    }

                                    if (SubFilmToChange.EigenschaftenNamenStringArray[i] == "IMDB-Wertung")
                                    {
                                        FilmTochange.TheFilm.IMDBRating =
                                            SubFilmToChange.EigenschaftenWerteStringArray[i];
                                    }

                                    if (SubFilmToChange.EigenschaftenNamenStringArray[i] == "MyPicture")
                                    {
                                        //FilmTochange.TheFilm.FilmPicture =
                                        //    SubFilmToChange.MyPicture;
                                    }

                                }
                            }

                        }
                    }
                    FilmTochange.TheFilm.SaveXML();
                }
            }
        }

        private void listViewFilmsToUpdate_Click(object sender, EventArgs e)
        {
            listViewFilmsToUpdate_SelectedIndexChanged(sender, e);
        }
    }

    class IMDBFilm
    {
        // initiale Eigenschaftem
        string strFilmTitel;
        string strFilmId;

        // weitere Eigenschaften aus IMDB
        string strFilmPremiere;
        string strFilmGenre;
        string strFilmRegie;
        string strFilmDarsteller;
        string strFilmWertung;

        WebClient wcWebclient = new WebClient();

        string strQuelltext;

        // hinzufügen weiterer Eigenschaften
        // überarbeiten von EigenschaftenWerte/Namen
        int intAnzahlEigenschaften = 8;
        bool[] boolEigenschaftUebernehmen = new bool[8];

        bool boolGelesen = false;

        public IMDBFilm()
        {
            strFilmTitel = "";
            strFilmId = "";
        }
        public IMDBFilm(string strFilmTitelPar, string strFilmIdPar)
        {
            strFilmTitel = strFilmTitelPar;
            strFilmId = strFilmIdPar;
            loadPageFilmSearch();
        }

        public void CancelLoad()
        {
            if (wcWebclient.IsBusy)
            {
                wcWebclient.CancelAsync();
            }
        }

        public int AnzahlEigenschaften
        {
            get
            {
                return intAnzahlEigenschaften;
            }
        }

        public string[] EigenschaftenNamenStringArray
        {
            get
            {
                string[] strProperties = new string[intAnzahlEigenschaften];
                strProperties[0] = "Filmname";
                strProperties[1] = "IMDB-ID";
                strProperties[2] = "Premieredatum";
                strProperties[3] = "Genres";
                strProperties[4] = "Regie";
                strProperties[5] = "Darsteller";
                strProperties[6] = "IMDB-Wertung";
                strProperties[7] = "MyPicture";

                return strProperties;
            }
        }
        public string[] EigenschaftenWerteStringArray
        {
            get
            {
                string[] strProperties = new string[intAnzahlEigenschaften];
                strProperties[0] = strFilmTitel;
                strProperties[1] = strFilmId;
                strProperties[2] = strFilmPremiere;
                strProperties[3] = strFilmGenre;
                strProperties[4] = strFilmRegie;
                strProperties[5] = strFilmDarsteller;
                strProperties[6] = strFilmWertung;
                strProperties[7] = (MyPicture != null).ToString();
                return strProperties;
            }
        }

        public bool[] EigenschaftUebernehmenBooleanArray
        {
            get
            {
                return (boolEigenschaftUebernehmen);
            }
        }

        public string FilmTitelString
        {
            get
            {
                return (strFilmTitel);
            }
            set
            {
                strFilmTitel = value;
            }
        }
        public string FilmIdString
        {
            get
            {
                return (strFilmId);
            }
            set
            {
                strFilmId = value;
                loadPageFilmSearch();
            }
        }
        public string FilmPremiereString
        {
            get
            {
                return (strFilmPremiere);
            }
            set
            {
                strFilmPremiere = value;
            }
        }
        public string FilmGenreString
        {
            get
            {
                return (strFilmGenre);
            }
            set
            {
                strFilmPremiere = value;
            }
        }
        public string FilmRegieString
        {
            get
            {
                return (strFilmRegie);
            }
            set
            {
                strFilmRegie = value;
            }
        }
        public string FilmDarstellerString
        {
            get
            {
                return (strFilmDarsteller);
            }
            set
            {
                strFilmDarsteller = value;
            }
        }
        public string FilmWertungString
        {
            get
            {
                return (strFilmWertung);
            }
            set
            {
                strFilmWertung = value;
            }
        }

        public bool FilmgelesenBoolean
        {
            get
            {
                return boolGelesen;
            }
        }

        public Bitmap MyPicture { get; set; }

        public void loadPageFilmSearch()
        {
            if (strFilmId != "")
            {
                Uri uriAdress = new Uri("http://www.imdb.de/title/" + strFilmId + "/");
                
                wcWebclient.DownloadStringCompleted += new DownloadStringCompletedEventHandler(FilmQueryComplete);
                while (wcWebclient.IsBusy) 
                {
                    Thread.Sleep(100);
                }
                wcWebclient.DownloadStringAsync(uriAdress);
                DateTime startingTime = DateTime.Now;
                while (wcWebclient.IsBusy)
                {
                    Thread.Sleep(100);
                    if ((DateTime.Now - startingTime) > (new TimeSpan(0,0,30)))
                    {
                        wcWebclient.CancelAsync();
                        loadPageFilmSearch();
                        return;
                    }
                }
            }
            else
            {
                boolGelesen = true;
            }
        }


        private void FilmQueryComplete(Object sender, DownloadStringCompletedEventArgs e)
        {
            if (e != null)
            {
                if (e.Error == null)
                {                    
                    strQuelltext = e.Result;
                    loadFilm();
                }
            }
            boolGelesen = true;
        }

        private void loadFilm()
        {

            // Premiere Jahr
            string strAnfang = "<title>";
            string strEnde = "</title>";
            long lngAnfang = strQuelltext.IndexOf(strAnfang);
            long lngEnde = strQuelltext.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            strFilmPremiere = MyHtml.TransferHtmlToString(
                    strQuelltext.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length))
                );


            // Filmtitel
            strEnde = "(";
            lngAnfang = 0;
            lngEnde = strFilmPremiere.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            if ((lngAnfang > -1) & (lngEnde > -1))
            {
                strFilmTitel = MyHtml.TransferHtmlToString(
                        strFilmPremiere.Substring(Convert.ToInt32(lngAnfang), Convert.ToInt32(lngEnde - strEnde.Length))
                    );
            }
            else
            {
                lngEnde = strFilmPremiere.Length;
                lngAnfang = 0;
                if ((lngAnfang > -1) & (lngEnde < 100))
                {
                    strFilmTitel = MyHtml.TransferHtmlToString(
                            strFilmPremiere.Substring(Convert.ToInt32(lngAnfang), Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length))
                        );
                }
            }

            strAnfang = "(";
            strEnde = ")";
            lngAnfang = strFilmPremiere.IndexOf(strAnfang);
            lngEnde = strFilmPremiere.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            if((lngAnfang>-1)&(lngEnde>-1))
            {
                strFilmPremiere = MyHtml.TransferHtmlToString(
                        strFilmPremiere.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length))
                    );
            }


            // Genres
            IMDBFilm ss = new IMDBFilm();
            strAnfang = "<h5>Genre:</h5>\n<div class=\"info-content\">\n";
            strEnde = "\n</div>";
            lngAnfang = strQuelltext.IndexOf(strAnfang);
            lngEnde = strQuelltext.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            if (lngAnfang > -1)
            {
                strFilmGenre = MyHtml.TransferHtmlToString(
                        strQuelltext.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length))
                    );
            }

            // Regie                    
            strAnfang = "<h5>Regisseur:</h5>\n        <div class=\"info-content\">\n";
            strEnde = "\n</div>";
            lngAnfang = strQuelltext.IndexOf(strAnfang);
            lngEnde = strQuelltext.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            if (lngAnfang > -1)
            {
                FilmRegieString = strQuelltext.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length));
                strAnfang = "';\">";
                strEnde = "</a>";
                lngAnfang = FilmRegieString.IndexOf(strAnfang);
                lngEnde = FilmRegieString.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                if (lngAnfang > -1)
                {
                    FilmRegieString = MyHtml.TransferHtmlToString(
                            FilmRegieString.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length))
                        );

                }
            }

            // FilmWertung
            strAnfang = "<div class=\"starbar-meta\">";
            strEnde = "</div>";
            lngAnfang = strQuelltext.IndexOf(strAnfang);
            lngEnde = strQuelltext.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            if (lngAnfang > -1)
            {
                strFilmWertung = strQuelltext.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length));
                strAnfang = "<b>";
                strEnde = "/";
                lngAnfang = strFilmWertung.IndexOf(strAnfang);
                lngEnde = strFilmWertung.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                if (lngAnfang > -1)
                {
                    strFilmWertung = MyHtml.TransferHtmlToString(
                            strFilmWertung.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length))
                        );

                }
            }






            //string strFilmDarsteller;            
            strAnfang = "(Hauptdarsteller)";
            strEnde = "</table>";

            lngAnfang = strQuelltext.IndexOf(strAnfang);
            lngEnde = strQuelltext.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            if (lngAnfang > -1)
            {
                strFilmDarsteller = strQuelltext.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length));
                string[] strZeile = strFilmDarsteller.Split(new string[1] { "</tr>" }, StringSplitOptions.None);
                strFilmDarsteller = "";
                for (int i = 0; i < strZeile.Count() - 1; i++)
                {
                    strAnfang = "';\">";
                    strEnde = "</a>";
                    lngAnfang = strZeile[i].IndexOf(strAnfang);
                    lngAnfang = strZeile[i].IndexOf(strAnfang, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                    lngEnde = strZeile[i].IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                    if (lngAnfang > -1)
                    {
                        strFilmDarsteller = strFilmDarsteller + "| " + MyHtml.TransferHtmlToString(
                                strZeile[i].Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length))
                            );
                    }
                }
            }
            
            //Bitmap Bild
            strAnfang = "id=\"primary-poster\"";
            strEnde = "</a>";

            lngAnfang = strQuelltext.IndexOf(strAnfang);
            lngEnde = strQuelltext.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            if (lngAnfang > -1)
            {
                string pictureUrl = strQuelltext.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length));
                strAnfang = "src=\"";
                strEnde = "\" />";

                lngAnfang = pictureUrl.IndexOf(strAnfang);
                lngEnde = pictureUrl.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                if (lngAnfang > -1)
                {
                    pictureUrl = pictureUrl.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length));
                    Uri uriAdress = new Uri(pictureUrl);
                    WebClient wcWebclient = new WebClient();
                    Stream pcStream;
                    try
                    {
                        pcStream = wcWebclient.OpenRead(uriAdress);
                        MyPicture = new Bitmap(pcStream);
                    }
                    catch (Exception)
                    {
                        
                    }
                    
                }
            }
        }       
    }

    class FilmToChange
    {
        string strFilmName;
        string strFilmPath;
        public FilmToChangeStatus Status;
        public int TryCount = 1;
        public Film TheFilm { get; set; }
        List<WebClient> wcWebClients = new List<WebClient>();        
        bool boolFilmloaded = false;
        IMDBFilm[] IMDBFilms;
        string strQuelltext = "";
        public FilmToChange(string strFilmnamePar,string strFilmPathPar, Film theFilm)
        {
            strFilmName = strFilmnamePar;
            strFilmPath = strFilmPathPar;
            TheFilm = theFilm;
        }
        public string FilmPathString
        {
            get
            {
                return strFilmPath;
            }
        }

        public string FilmNameString
        {
            get
            {
                return strFilmName;
            }
            set
            {
                strFilmName = value;
            }
        }


        public bool FilmLoadedBool
        {
            get
            {
                if (IMDBFilms == null)
                {
                    return false;
                }
                foreach (IMDBFilm csiFilm in IMDBFilms)
                {
                    if (csiFilm != null)
                    {
                        if (csiFilm.FilmgelesenBoolean == false)
                        {
                            return false;
                        }
                    }
                    else
                    {
                        return false;
                    }

                }
                return true;
            }
            set
            {
                boolFilmloaded = false;
            }

        }

        public int FilmsLoadedCount 
        {
            get
            {
                int myCount = 0;
                if (IMDBFilms == null)
                {
                    return myCount;
                }
                foreach (IMDBFilm csiFilm in IMDBFilms)
                {
                    if (csiFilm != null)
                    {
                        if (csiFilm.FilmgelesenBoolean == false)
                        {
                            return myCount;
                        }
                        else
                        {
                            myCount++;
                        }
                    }
                    else
                    {
                        return myCount;
                    }

                }
                return myCount;
            }
        }

        public IMDBFilm[] IMDBFilme
        {
            get
            {
                return (IMDBFilms);
            }
        }

        public void CancelLoads()
        {
            if (IMDBFilms != null)
            {
                foreach (IMDBFilm item in IMDBFilms)
                {
                    if (item != null)
                    {
                        item.CancelLoad();    
                    }
                }    
            }
            
            foreach (WebClient item in wcWebClients)
            {
                if (item.IsBusy)
                {
                    item.CancelAsync();
                }
            }
        }
        private void loadFilm()
        {
            if (strQuelltext != "")
            {
                string[] strFilmTitles = new string[1];
                string[] strFilmIDs = new string[1];
                if (strQuelltext.IndexOf("<title>IMDb Titelsuche</title>") > -1)
                {
                    if (!searchFilmsinIMDBForTitle(ref strFilmTitles, ref strFilmIDs, strFilmName))
                    {
                        return;
                    }
                    IMDBFilms = new IMDBFilm[strFilmTitles.Count()];
                    for (int i = 0; i < strFilmTitles.Count(); i++)
                    {
                        IMDBFilms[i] = new IMDBFilm(strFilmTitles[i], strFilmIDs[i]);
                    }
                    DateTime starTime = DateTime.Now;
                    bool allFilmsLoaded = false;
                    while (!allFilmsLoaded || (DateTime.Now - starTime > new TimeSpan(0,5,0)))
                    {
                        Thread.Sleep(1);
                        allFilmsLoaded = true;
                        foreach (IMDBFilm item in IMDBFilms)
                        {
                            Thread.Sleep(1);
                            if (item.FilmTitelString == "")
                            {
                                allFilmsLoaded = false;
                                break;
                            }
                        }
                    }
                    if (allFilmsLoaded)
                    {
                        Status = FilmToChangeStatus.FilmsLoaded;
                    }
                    else
                    {
                        Status = FilmToChangeStatus.TimeOut;
                    }
                }
                else
                {
                    string strAnfang = "<link rel=\"canonical\" href=\"http://www.imdb.de/title/";
                    string strEnde = "/\"";
                    long lngAnfang = strQuelltext.IndexOf(strAnfang);
                    long lngEnde = strQuelltext.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                    if (strQuelltext.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length)).Contains("/"))
                    {
                        strEnde = "/";
                        lngEnde = strQuelltext.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                    }
                    IMDBFilms = new IMDBFilm[1];
                    IMDBFilms[0] = new IMDBFilm(strFilmName, MyHtml.TransferHtmlToString(
                        strQuelltext.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length))
                    ));
                    Status = FilmToChangeStatus.FilmsLoaded;
                }
            }
        }

        public void loadPageFilmSearch(int newTry)
        {
            Status = FilmToChangeStatus.FilmSearch;
            Uri uriAdress = new Uri("http://www.imdb.de/find?s=tt&q=" + strFilmName);
            WebClient wcWebclient = new WebClient();
            wcWebClients.Add(wcWebclient);
            wcWebclient.DownloadStringCompleted += new DownloadStringCompletedEventHandler(FilmQueryComplete);
            wcWebclient.DownloadStringAsync(uriAdress);
            DateTime startingTime = DateTime.Now;
            while (wcWebclient.IsBusy)
            {
                Thread.Sleep(100);
                if ((DateTime.Now - startingTime) > (new TimeSpan(0, 0, 30)))
                {
                    Status = FilmToChangeStatus.TimeOut;
                    wcWebclient.CancelAsync();
                    loadPageFilmSearch(newTry++);
                    if (newTry > 10)
                    {
                        Array.Resize(ref IMDBFilms, 1);
                        IMDBFilms[0] = new IMDBFilm("Error - no Film found", "");
                        boolFilmloaded = true;
                        Status = FilmToChangeStatus.Error;
                    }
                    return;
                }
            }

            

            while (!boolFilmloaded)
            {
                Thread.Sleep(100);
            }

            while (!FilmLoadedBool)
            {
                Thread.Sleep(100);
            }
        }

        private bool searchFilmsinIMDBForTitle(ref string[] strFilmTitlesRef, ref string[] strFilmIDsRef, string strFilmTitlePar)
        {
            string strAnfang = "bereinstimmung)</b>";
            string strEnde = "bereinstimmung)</b>";
            long lngAnfang = strQuelltext.IndexOf(strAnfang);
            long lngEnde = strQuelltext.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            if (lngEnde == -1)
            {
                strEnde = "<script type=";
                lngEnde = strQuelltext.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            }

            
            if ((lngAnfang == -1) | (lngEnde == -1))
            {
                ChangeFilmTitleAndRetry();
                return false;
            }
            string strInhalt = strQuelltext.Substring(Convert.ToInt32(lngAnfang), Convert.ToInt32(lngEnde - lngAnfang));

            string[] strZeile = strInhalt.Split(new string[1] { "</tr>" }, StringSplitOptions.None);

            Array.Resize(ref strFilmTitlesRef, strZeile.Count() - 1);
            Array.Resize(ref strFilmIDsRef, strZeile.Count() - 1);
            for (int i = 0; i < strZeile.Count() - 1; i++)
            {
                strAnfang = "';\">";
                strEnde = "</a>";
                // Anfangszeichen 2 mal suchen, kommt oft 2 mal pro Film vor
                lngAnfang = strZeile[i].IndexOf(strAnfang);
                int lngAnfang2 = strZeile[i].IndexOf(strAnfang, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                if (lngAnfang2 > -1)
                {
                    lngAnfang = lngAnfang2;
                }
                if ((lngAnfang == -1) | (lngEnde == -1))
                {
                    ChangeFilmTitleAndRetry();
                    return false;
                }
                lngEnde = strZeile[i].IndexOf(strEnde, Convert.ToInt32(lngAnfang));
                strFilmTitlesRef[i] = MyHtml.TransferHtmlToString(
                    strZeile[i].Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length))
                );

                strAnfang = "<a href=\"/title/";
                strEnde = "/\"";
                lngAnfang = strZeile[i].IndexOf(strAnfang);
                if ((lngAnfang == -1) | (lngEnde == -1))
                {
                    ChangeFilmTitleAndRetry();
                    return false;
                }
                lngEnde = strZeile[i].IndexOf(strEnde, Convert.ToInt32(lngAnfang));
                strFilmIDsRef[i] = strZeile[i].Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length));
            }


            strAnfang = "Meistgesuchte Titel";
            strEnde = "bereinstimmung)</b>";
            lngAnfang = strQuelltext.IndexOf(strAnfang);
            lngEnde = strQuelltext.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            if (lngEnde == -1)
            {
                strEnde = "<script type=";
                lngEnde = strQuelltext.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            }


            if ((lngAnfang == -1) | (lngEnde == -1))
            {
                if (strFilmTitlesRef.Count() == 0)
                {
                    ChangeFilmTitleAndRetry();
                    return false;
                }
            }
            else
            {
                strInhalt = strQuelltext.Substring(Convert.ToInt32(lngAnfang), Convert.ToInt32(lngEnde - lngAnfang));

                strZeile = strInhalt.Split(new string[1] { "</tr>" }, StringSplitOptions.None);

                int intZeilenBereits = strFilmTitlesRef.Count();
                Array.Resize(ref strFilmTitlesRef, intZeilenBereits + strZeile.Count() - 1);
                Array.Resize(ref strFilmIDsRef, intZeilenBereits + strZeile.Count() - 1);
                for (int i = 0; i < strZeile.Count() - 1; i++)
                {
                    strAnfang = "';\">";
                    strEnde = "</a>";
                    // Anfangszeichen 2 mal suchen, kommt oft 2 mal pro Film vor
                    lngAnfang = strZeile[i].IndexOf(strAnfang);
                    int lngAnfang2 = strZeile[i].IndexOf(strAnfang, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                    if (lngAnfang2 > -1)
                    {
                        lngAnfang = lngAnfang2;
                    }
                    if ((lngAnfang == -1) | (lngEnde == -1))
                    {
                        ChangeFilmTitleAndRetry();
                        return false;
                    }
                    lngEnde = strZeile[i].IndexOf(strEnde, Convert.ToInt32(lngAnfang));
                    strFilmTitlesRef[i + intZeilenBereits] = MyHtml.TransferHtmlToString(
                        strZeile[i].Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length))
                    );

                    strAnfang = "<a href=\"/title/";
                    strEnde = "/\"";
                    lngAnfang = strZeile[i].IndexOf(strAnfang);
                    if ((lngAnfang == -1) | (lngEnde == -1))
                    {
                        ChangeFilmTitleAndRetry();
                        return false;
                    }
                    lngEnde = strZeile[i].IndexOf(strEnde, Convert.ToInt32(lngAnfang));
                    strFilmIDsRef[i + intZeilenBereits] = strZeile[i].Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length));

                }
            }
            return true;
        }
        private void FilmQueryComplete(Object sender, DownloadStringCompletedEventArgs e)
        {
            Status = FilmToChangeStatus.LoadingFilms;
            if (e != null)
            {
                if (e.Error == null)
                {
                    strQuelltext = e.Result;
                    loadFilm();
                }
            }
            boolFilmloaded = true;
        }

        public IMDBFilm[] getIMDBFilms()
        {
            return (IMDBFilms);
        }

        private void ChangeFilmTitleAndRetry()
        {
            TryCount++;
            if (FilmNameString.Contains("."))
            {
                FilmNameString = FilmNameString.Replace(".", " ");
            }
            else
            {
                FilmNameString = FilmNameString.Remove(FilmNameString.Length - 1, 1);
            }
            if (FilmNameString.Length > 1)
            {
                loadPageFilmSearch(1);    
            }
            else
            {
                Array.Resize(ref IMDBFilms, 1);
                IMDBFilms[0] = new IMDBFilm("Error - no Film found", "");
                boolFilmloaded = true;
                Status = FilmToChangeStatus.Error;
            }
        }
    }


    enum FilmToChangeStatus
    {
        nothing,
        FilmSearch,
        LoadingFilms,
        FilmsLoaded,
        TimeOut,
        Error
    }

    
}
