﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ThiesMediaProject.General;
using System.Threading;
using System.Net;
using ThiesGeneral.Web;
using System.IO;
using ThiesMediaProject.Properties;

namespace ThiesMediaProject.ToolForms.IMDBLoader
{
    public partial class IMDBLoaderForm : Form
    {
        public BindingList<IMDBLoaderFilm> ChangedFilms { get; set; }
        int SearchCount = 0;
        int ActiveSearches = 0;
        int ActiveFilmLoads = 0;
        int RefreshCounter = 0;
        bool Finished = false;
        DateTime StartingTime = DateTime.Now;
        WebClient[] MainWebClient = new WebClient[3];
        WebClient[] SubWebClient = new WebClient[3];


        public IMDBLoaderForm()
        {
            InitializeComponent();
            this.Size = Settings.Default.IMDBLoaderSize;
            for (int i = 0; i < 3; i++)
            {
                MainWebClient[i] = new WebClient();
                MainWebClient[i].DownloadStringCompleted += new DownloadStringCompletedEventHandler(IMDBLoaderForm_DownloadStringCompleted);

                SubWebClient[i] = new WebClient();
                SubWebClient[i].DownloadStringCompleted += new DownloadStringCompletedEventHandler(IMDBLoaderForm_SubDownloadStringCompleted);
            }
            this.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            this.Icon = Properties.Resources.tmp_icon;
        }

        private void IMDBLoaderForm_Load(object sender, EventArgs e)
        {
            iMDBLoaderFilmBindingSource.DataSource = ChangedFilms;
            iMDBLoaderFilmDataGridView.Refresh();
            StartSearch();
            timer1.Enabled = true;
        }

        private void StartSearch()
        {
            for (int i = 0; i < 3; i++)
            {
                if (SearchCount < ChangedFilms.Count)
                {     
                    // change special characters
                    ChangedFilms[SearchCount].Filmname = ChangedFilms[SearchCount].Filmname.Replace("&", "+");
                    Uri uriAdress = new Uri("http://www.imdb.de/find?s=tt&q=" + ChangedFilms[SearchCount].Filmname);
                    //Uri uriAdress = new Uri("http://www.imdb.com/find?s=tt&q=" + ChangedFilms[SearchCount].Filmname);
                    MainWebClient[i].DownloadStringAsync(uriAdress, ChangedFilms[SearchCount]);
                    ChangedFilms[SearchCount].LoadStatus = LoadingStatus.Film_Search;
                    ActiveSearches++;
                    SearchCount++;
                }
            }
        }

        private void StartFilmLoad()
        {
            foreach (IMDBLoaderFilm mainFilm in ChangedFilms)
            {
                mainFilm.Films_Loaded_Count = 0;
                if (mainFilm.IMDBFilms != null)
                {
                    foreach (IMDBFilm subFilm in mainFilm.IMDBFilms)
                    {
                        if (ActiveFilmLoads < 3)
                        {
                            if (!subFilm.FilmLoaded)
                            {
                                Uri uriAdress = new Uri("http://www.imdb.de/title/" + subFilm.FilmId + "/");
                                //Uri uriAdress = new Uri("http://www.imdb.com/title/" + subFilm.FilmId + "/");
                                SubWebClient[ActiveFilmLoads].DownloadStringAsync(uriAdress, subFilm);
                                mainFilm.LoadStatus = LoadingStatus.Loading_Films;
                                ActiveFilmLoads++;
                            }
                            else
                            {
                                mainFilm.Films_Loaded_Count++;
                            }
                        }
                        else
                        {
                            return;
                        }
                    }
                    if ((mainFilm.Films_Loaded_Count == mainFilm.IMDBFilms.Count) && (mainFilm.LoadStatus == LoadingStatus.Loading_Films))
                    {
                        mainFilm.LoadStatus = LoadingStatus.Films_Loaded;
                    }
                }
            }
        }

        void IMDBLoaderForm_DownloadStringCompleted(object sender, DownloadStringCompletedEventArgs e)
        {
            if (e.Error == null)
            {
                if (e.Result != "")
                {
                    string[] filmTitles = new string[1];
                    string[] filmIDs = new string[1];
                    IMDBLoaderFilm loaderFilm = (IMDBLoaderFilm)e.UserState;
                    if ((e.Result.IndexOf("<title>IMDb Titelsuche</title>") > -1) || (e.Result.IndexOf("<title>IMDb Title Search</title>") > -1))
                    {
                        if (!searchFilmsinIMDBForTitle(loaderFilm, (WebClient)sender, e.Result, ref filmTitles, ref filmIDs, loaderFilm.Filmname))
                        {
                            return;
                        }
                        loaderFilm.IMDBFilms = new BindingList<IMDBFilm>();
                        for (int i = 0; i < filmTitles.Count(); i++)
                        {
                            IMDBFilm film = new IMDBFilm();
                            film.FilmId = filmIDs[i];
                            film.FilmTitel = filmTitles[i];
                            loaderFilm.IMDBFilms.Add(film);
                        }
                        loaderFilm.Films_Found_Count = loaderFilm.IMDBFilms.Count;
                        loaderFilm.LoadStatus = LoadingStatus.Film_Search_Complete;
                    }
                    else
                    {
                        string strAnfang = "<link rel=\"canonical\" href=\"http://www.imdb.de/title/";
                        //string strAnfang = "<link rel=\"canonical\" href=\"http://www.imdb.com/title/";
                        string strEnde = "/\"";
                        long lngAnfang = e.Result.IndexOf(strAnfang);
                        long lngEnde = e.Result.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                        if (e.Result.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length)).Contains("/"))
                        {
                            strEnde = "/";
                            lngEnde = e.Result.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                        }
                        loaderFilm.IMDBFilms = new BindingList<IMDBFilm>();
                        IMDBFilm film = new IMDBFilm();
                        film.FilmTitel = loaderFilm.Filmname;
                        film.FilmId = MyHtml.TransferHtmlToString(
                            e.Result.Substring(
                                Convert.ToInt32(lngAnfang) + strAnfang.Length,
                                Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length)
                            )
                        );
                        loaderFilm.IMDBFilms.Add(film);
                        loaderFilm.Films_Found_Count = 1;
                        loaderFilm.LoadStatus = LoadingStatus.Film_Search_Complete;
                    }
                }
                else
                {
                    IMDBLoaderFilm loaderFilm = (IMDBLoaderFilm)e.UserState;
                    loaderFilm.LoadStatus = LoadingStatus.Error;
                }
                ActiveSearches--;
            }
            else
            {
                IMDBLoaderFilm loaderFilm = (IMDBLoaderFilm)e.UserState;
                Uri uriAdress = new Uri("http://www.imdb.de/find?s=tt&q=" + loaderFilm.Filmname);
                //Uri uriAdress = new Uri("http://www.imdb.com/find?s=tt&q=" + loaderFilm.Filmname);
                WebClient mainWebClient = (WebClient)sender;
                mainWebClient.DownloadStringAsync(uriAdress, loaderFilm);
            }
        }

        void IMDBLoaderForm_SubDownloadStringCompleted(object sender, DownloadStringCompletedEventArgs e)
        {
            try
            {
                string testResult = e.Result;
            }
            catch (Exception)
            {
                IMDBFilm currentFilm2 = (IMDBFilm)e.UserState;
                currentFilm2.FilmLoaded = true;
                ActiveFilmLoads--;
                return;
            }
            IMDBFilm currentFilm = (IMDBFilm)e.UserState;
            // Premiere Jahr
            string strAnfang = "<title>";
            string strEnde = "</title>";
            long lngAnfang = e.Result.IndexOf(strAnfang);
            long lngEnde = e.Result.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            currentFilm.FilmPremiere = MyHtml.TransferHtmlToString(
                    e.Result.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length))
                );
            if (currentFilm.FilmPremiere.Contains("/"))
            {
                currentFilm.FilmPremiere = currentFilm.FilmPremiere.Substring(0,
                    currentFilm.FilmPremiere.IndexOf("/"));
            }


            // Filmtitel
            
            if (currentFilm.FilmPremiere.Contains(strEnde))
            {
                strEnde = "(";
                lngAnfang = 0;
                lngEnde = currentFilm.FilmPremiere.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                if ((lngAnfang > -1) & (lngEnde > -1))
                {
                    currentFilm.FilmTitel = MyHtml.TransferHtmlToString(
                            currentFilm.FilmPremiere.Substring(Convert.ToInt32(lngAnfang), Convert.ToInt32(lngEnde - strEnde.Length))
                        );
                }
                else
                {
                    lngEnde = currentFilm.FilmPremiere.Length;
                    lngAnfang = 0;
                    if ((lngAnfang > -1) & (lngEnde < 100))
                    {
                        currentFilm.FilmTitel = MyHtml.TransferHtmlToString(
                                currentFilm.FilmPremiere.Substring(Convert.ToInt32(lngAnfang), Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length))
                            );
                    }
                }
            }
            

            strAnfang = "(";
            strEnde = ")";
            lngAnfang = currentFilm.FilmPremiere.IndexOf(strAnfang);
            lngEnde = currentFilm.FilmPremiere.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            if((lngAnfang>-1)&(lngEnde>-1))
            {
                currentFilm.FilmPremiere = MyHtml.TransferHtmlToString(
                        currentFilm.FilmPremiere.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length))
                    );
            }
            int intTest = 0;
            if (!int.TryParse(currentFilm.FilmPremiere,out intTest))
            {
                strEnde = ")</title>";
                
                lngEnde = e.Result.IndexOf(strEnde);
                lngAnfang = lngEnde -5;
                if ((lngAnfang > -1) & (lngEnde > -1))
                {
                    currentFilm.FilmPremiere = MyHtml.TransferHtmlToString(
                            e.Result.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length))
                        );
                }
            }



            // Genres
            strAnfang = "<h5>Genre:</h5>\n<div class=\"info-content\">\n";
            strEnde = "\n</div>";
            lngAnfang = e.Result.IndexOf(strAnfang);
            lngEnde = e.Result.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            if (lngAnfang > -1)
            {
                currentFilm.FilmGenre = MyHtml.TransferHtmlToString(
                        e.Result.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length))
                    );
            }

            // Regie                    
            strAnfang = "<h5>Regisseur:</h5>\n        <div class=\"info-content\">\n";
            strEnde = "\n</div>";
            lngAnfang = e.Result.IndexOf(strAnfang);
            lngEnde = e.Result.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            if (lngAnfang > -1)
            {
                currentFilm.FilmRegie = e.Result.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length));
                strAnfang = "';\">";
                strEnde = "</a>";
                lngAnfang = currentFilm.FilmRegie.IndexOf(strAnfang);
                lngEnde = currentFilm.FilmRegie.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                if (lngAnfang > -1)
                {
                    currentFilm.FilmRegie = MyHtml.TransferHtmlToString(
                            currentFilm.FilmRegie.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length))
                        );

                }
            }

            // FilmWertung
            strAnfang = "<div class=\"starbar-meta\">";
            strEnde = "</div>";
            lngAnfang = e.Result.IndexOf(strAnfang);
            lngEnde = e.Result.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            if (lngAnfang > -1)
            {
                currentFilm.FilmRating = e.Result.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length));
                strAnfang = "<b>";
                strEnde = "/";
                lngAnfang = currentFilm.FilmRating.IndexOf(strAnfang);
                lngEnde = currentFilm.FilmRating.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                if (lngAnfang > -1)
                {
                    currentFilm.FilmRating = MyHtml.TransferHtmlToString(
                            currentFilm.FilmRating.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length))
                        );

                }
            }

            //string strFilmDarsteller;            
            strAnfang = "(Hauptdarsteller)";
            strEnde = "</table>";

            lngAnfang = e.Result.IndexOf(strAnfang);
            lngEnde = e.Result.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            if (lngAnfang > -1)
            {
                currentFilm.FilmActors = e.Result.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length));
                string[] strZeile = currentFilm.FilmActors.Split(new string[1] { "</tr>" }, StringSplitOptions.None);
                currentFilm.FilmActors = "";
                for (int i = 0; i < strZeile.Count() - 1; i++)
                {
                    strAnfang = "';\">";
                    strEnde = "</a>";
                    lngAnfang = strZeile[i].IndexOf(strAnfang);
                    lngAnfang = strZeile[i].IndexOf(strAnfang, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                    lngEnde = strZeile[i].IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                    if (lngAnfang > -1)
                    {
                        currentFilm.FilmActors = currentFilm.FilmActors + "| " + MyHtml.TransferHtmlToString(
                                strZeile[i].Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length))
                            );
                    }
                }
            }
            
            //Bitmap Bild
            strAnfang = "id=\"primary-poster\"";
            strEnde = "</a>";

            lngAnfang = e.Result.IndexOf(strAnfang);
            lngEnde = e.Result.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            if (lngAnfang > -1)
            {
                string pictureUrl = e.Result.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length));
                strAnfang = "src=\"";
                strEnde = "\" />";

                lngAnfang = pictureUrl.IndexOf(strAnfang);
                lngEnde = pictureUrl.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                if (lngAnfang > -1)
                {
                    pictureUrl = pictureUrl.Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length));
                    Uri uriAdress = new Uri(pictureUrl);
                    WebClient wcWebclient = new WebClient();
                    Stream pcStream;
                    try
                    {
                        pcStream = wcWebclient.OpenRead(uriAdress);
                        currentFilm.FilmPicture = new Bitmap(pcStream);
                    }
                    catch (Exception)
                    {
                        
                    }
                    
                }
            }
            currentFilm.FilmLoaded = true;
            ActiveFilmLoads--;
            
        }

        public void AddFilm(Film filmToAdd)
        {
            if (ChangedFilms == null)
            {
                ChangedFilms = new BindingList<IMDBLoaderFilm>();
            }

            ChangedFilms.Add(new IMDBLoaderFilm(filmToAdd));
            
        }

        private bool searchFilmsinIMDBForTitle(IMDBLoaderFilm currentFilm, WebClient mainWebClient, string strQuelltext, ref string[] strFilmTitlesRef, ref string[] strFilmIDsRef, string strFilmTitlePar)
        {
            string strAnfang = "bereinstimmung)</b>";
            string strEnde = "bereinstimmung)</b>";
            long lngAnfang = strQuelltext.IndexOf(strAnfang);
            long lngEnde = strQuelltext.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            if (lngEnde == -1)
            {
                strEnde = "<script type=";
                lngEnde = strQuelltext.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            }

            if(lngAnfang == -1)
            {
                strAnfang = "Matches)</b>";
                strEnde = "Matches)</b>";
                lngAnfang = strQuelltext.IndexOf(strAnfang);
                lngEnde = strQuelltext.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                if (lngEnde == -1)
                {
                    strEnde = "<script type=";
                    lngEnde = strQuelltext.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                }
            }


            if ((lngAnfang == -1) | (lngEnde == -1))
            {
                ChangeFilmTitleAndRetry(mainWebClient,currentFilm);
                return false;
            }
            string strInhalt = strQuelltext.Substring(Convert.ToInt32(lngAnfang), Convert.ToInt32(lngEnde - lngAnfang));

            string[] strZeile = strInhalt.Split(new string[1] { "</tr>" }, StringSplitOptions.None);

            Array.Resize(ref strFilmTitlesRef, strZeile.Count() - 1);
            Array.Resize(ref strFilmIDsRef, strZeile.Count() - 1);
            for (int i = 0; i < strZeile.Count() - 1; i++)
            {
                strAnfang = "';\">";
                strEnde = "</a>";
                // Anfangszeichen 2 mal suchen, kommt oft 2 mal pro Film vor
                lngAnfang = strZeile[i].IndexOf(strAnfang);
                int lngAnfang2 = strZeile[i].IndexOf(strAnfang, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                if (lngAnfang2 > -1)
                {
                    lngAnfang = lngAnfang2;
                }
                if ((lngAnfang == -1) | (lngEnde == -1))
                {
                    ChangeFilmTitleAndRetry(mainWebClient, currentFilm);
                    return false;
                }
                lngEnde = strZeile[i].IndexOf(strEnde, Convert.ToInt32(lngAnfang));
                strFilmTitlesRef[i] = MyHtml.TransferHtmlToString(
                    strZeile[i].Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length))
                );

                strAnfang = "<a href=\"/title/";
                strEnde = "/\"";
                lngAnfang = strZeile[i].IndexOf(strAnfang);
                if ((lngAnfang == -1) | (lngEnde == -1))
                {
                    ChangeFilmTitleAndRetry(mainWebClient, currentFilm);
                    return false;
                }
                lngEnde = strZeile[i].IndexOf(strEnde, Convert.ToInt32(lngAnfang));
                strFilmIDsRef[i] = strZeile[i].Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length));
            }


            strAnfang = "Meistgesuchte Titel";
            strEnde = "bereinstimmung)</b>";
            lngAnfang = strQuelltext.IndexOf(strAnfang);
            lngEnde = strQuelltext.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            if (lngEnde == -1)
            {
                strEnde = "<script type=";
                lngEnde = strQuelltext.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
            }

            if (lngAnfang == -1)
            {
                strAnfang = "Popular Titles";
                strEnde = "Matches)</b>";
                lngAnfang = strQuelltext.IndexOf(strAnfang);
                lngEnde = strQuelltext.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                if (lngEnde == -1)
                {
                    strEnde = "<script type=";
                    lngEnde = strQuelltext.IndexOf(strEnde, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                }
            }

            if ((lngAnfang == -1) | (lngEnde == -1))
            {
                if (strFilmTitlesRef.Count() == 0)
                {
                    ChangeFilmTitleAndRetry(mainWebClient, currentFilm);
                    return false;
                }
            }
            else
            {
                strInhalt = strQuelltext.Substring(Convert.ToInt32(lngAnfang), Convert.ToInt32(lngEnde - lngAnfang));

                strZeile = strInhalt.Split(new string[1] { "</tr>" }, StringSplitOptions.None);

                int intZeilenBereits = strFilmTitlesRef.Count();
                Array.Resize(ref strFilmTitlesRef, intZeilenBereits + strZeile.Count() - 1);
                Array.Resize(ref strFilmIDsRef, intZeilenBereits + strZeile.Count() - 1);
                for (int i = 0; i < strZeile.Count() - 1; i++)
                {
                    strAnfang = "';\">";
                    strEnde = "</a>";
                    // Anfangszeichen 2 mal suchen, kommt oft 2 mal pro Film vor
                    lngAnfang = strZeile[i].IndexOf(strAnfang);
                    int lngAnfang2 = strZeile[i].IndexOf(strAnfang, Convert.ToInt32(lngAnfang) + strAnfang.Length);
                    if (lngAnfang2 > -1)
                    {
                        lngAnfang = lngAnfang2;
                    }
                    if ((lngAnfang == -1) | (lngEnde == -1))
                    {
                        ChangeFilmTitleAndRetry(mainWebClient, currentFilm);
                        return false;
                    }
                    lngEnde = strZeile[i].IndexOf(strEnde, Convert.ToInt32(lngAnfang));
                    strFilmTitlesRef[i + intZeilenBereits] = MyHtml.TransferHtmlToString(
                        strZeile[i].Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length))
                    );

                    strAnfang = "<a href=\"/title/";
                    strEnde = "/\"";
                    lngAnfang = strZeile[i].IndexOf(strAnfang);
                    if ((lngAnfang == -1) | (lngEnde == -1))
                    {
                        ChangeFilmTitleAndRetry(mainWebClient, currentFilm);
                        return false;
                    }
                    lngEnde = strZeile[i].IndexOf(strEnde, Convert.ToInt32(lngAnfang));
                    strFilmIDsRef[i + intZeilenBereits] = strZeile[i].Substring(Convert.ToInt32(lngAnfang) + strAnfang.Length, Convert.ToInt32(lngEnde - lngAnfang - strAnfang.Length));

                }
            }
            return true;
        }

        private void ChangeFilmTitleAndRetry(WebClient mainWebClient, IMDBLoaderFilm currentFilm)
        {
            currentFilm.Trys_Count++;
            if (currentFilm.Filmname.Contains("."))
            {
                currentFilm.Filmname = currentFilm.Filmname.Replace(".", " ");
            }
            else
            {
                currentFilm.Filmname = currentFilm.Filmname.Remove(currentFilm.Filmname.Length - 1, 1);
            }

            if (currentFilm.Filmname.Length <= 1)
            {
                currentFilm.LoadStatus = LoadingStatus.Error;                
            }
            else
            {
                Uri uriAdress = new Uri("http://www.imdb.de/find?s=tt&q=" + currentFilm.Filmname);
                //Uri uriAdress = new Uri("http://www.imdb.com/find?s=tt&q=" + currentFilm.Filmname);
                mainWebClient.DownloadStringAsync(uriAdress, currentFilm);
            }
        
        }

        private void iMDBLoaderFilmDataGridView_CellContentClick(object sender, DataGridViewCellEventArgs e)
        {

        }

        private void iMDBLoaderFilmDataGridView_CurrentCellChanged(object sender, EventArgs e)
        {
            if (iMDBLoaderFilmDataGridView.CurrentRow != null)
            {
                if (ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].IMDBFilms != null)
                {
                    iMDBFilmBindingSource.DataSource = ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].IMDBFilms;
                    iMDBFilmDataGridView.Refresh();
                    iMDBFilmDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);
                    iMDBFilmDataGridView.AutoResizeRows(DataGridViewAutoSizeRowsMode.AllCells);

                }                
            }
        }

        private void timer1_Tick(object sender, EventArgs e)
        {
            RefreshCounter++;
            if (RefreshCounter >= 0)
            {
                iMDBLoaderFilmDataGridView_CurrentCellChanged(sender, e);

                iMDBLoaderFilmDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);
                iMDBLoaderFilmDataGridView.Refresh();
                RefreshCounter = 0;
            }

            int loadedCount = 0;
            progressBar1.Maximum = ChangedFilms.Count;
            foreach (IMDBLoaderFilm item in ChangedFilms)
            {
                if (item.LoadStatus == LoadingStatus.Films_Loaded || item.LoadStatus == LoadingStatus.Worked)
                {
                    loadedCount++;
                }
            }
            progressBar1.Value = loadedCount;
            statusLabel.Text = string.Format("{0}/{1}", progressBar1.Value, progressBar1.Maximum);

            if ((loadedCount > 0) && (loadedCount < ChangedFilms.Count))
            {
                TimeSpan runningTime = DateTime.Now - StartingTime;
                TimeSpan timeToRun = new TimeSpan(runningTime.Ticks / loadedCount * ChangedFilms.Count);
                timeToGoLabel.Text = string.Format("{0}/{1}", runningTime.ToString(@"hh\:mm\:ss"), timeToRun.ToString(@"hh\:mm\:ss"));
            }

            if (loadedCount == ChangedFilms.Count && !Finished)
            {
                Finished = true;
                TimeSpan runningTime = DateTime.Now - StartingTime;
                timeToGoLabel.Text = string.Format("{0}/{1}", runningTime.ToString(@"hh\:mm\:ss"), runningTime.ToString(@"hh\:mm\:ss"));
            }
            

            if (ActiveSearches == 0)
            {
                StartSearch();
            }

            if (ActiveFilmLoads == 0)
            {
                StartFilmLoad();
            }

        }

        private void buttonNameAendern_Click(object sender, EventArgs e)
        {
            if (iMDBFilmDataGridView.CurrentRow != null)
            {
                InputBoxForm InpBox = new InputBoxForm();
                InpBox.Text = "Name ändern";
                InpBox.ValueString = ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].Filmname;
                InpBox.ShowDialog();
                if (InpBox.ValueString != ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].Filmname)
                {
                    ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].Filmname = InpBox.ValueString;
                    ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].LoadStatus = LoadingStatus.None;
                    ChangedFilms.Add(ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index]);
                    ChangedFilms.Remove(ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index]);
                    Finished = false;

                    SearchCount--;
                    if (SearchCount < 0)
                    {
                        SearchCount = 0;
                    }

                }
            }
        }

        private void buttonUebernehmen_Click(object sender, EventArgs e)
        {
            if (iMDBFilmDataGridView.CurrentRow != null)
            {
                ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].Actors =
                    ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].
                        IMDBFilms[iMDBFilmDataGridView.CurrentRow.Index].FilmActors;

                ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].IMDBID =
                    ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].
                        IMDBFilms[iMDBFilmDataGridView.CurrentRow.Index].FilmId;

                ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].Genre =
                    ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].
                        IMDBFilms[iMDBFilmDataGridView.CurrentRow.Index].FilmGenre;

                ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].SetMyFilmPicture(
                    ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].
                        IMDBFilms[iMDBFilmDataGridView.CurrentRow.Index].FilmPicture);

                try
                {
                    ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].YearOfPrime =
                    Convert.ToInt16(
                        ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].
                            IMDBFilms[iMDBFilmDataGridView.CurrentRow.Index].FilmPremiere);
                }
                catch (Exception)
                {
                    
                }

                ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].IMDBRating =
                    ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].
                        IMDBFilms[iMDBFilmDataGridView.CurrentRow.Index].FilmRating;

                ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].Regie =
                    ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].
                        IMDBFilms[iMDBFilmDataGridView.CurrentRow.Index].FilmRegie;

                ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].Filmname =
                    ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].
                        IMDBFilms[iMDBFilmDataGridView.CurrentRow.Index].FilmTitel;

                //Film filmToChange = Data.DataFilms.GetFilmById(ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].FilmID);
                Film filmToChange = Data.DataFilms.GetFilmByPath(ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].Path);

                IMDBLoaderFilm changedFilm = ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index];
                filmToChange.Actors = changedFilm.Actors;
                filmToChange.Filmname = changedFilm.Filmname;
                filmToChange.SetMyFilmPicture(changedFilm.FilmPicture);
                filmToChange.Genre = changedFilm.Genre;
                filmToChange.IMDBID = changedFilm.IMDBID;
                filmToChange.IMDBRating = changedFilm.IMDBRating;
                filmToChange.Regie = changedFilm.Regie;
                filmToChange.YearOfPrime = changedFilm.YearOfPrime;
                filmToChange.SaveXML();
                Data.Save();

                ChangedFilms[iMDBLoaderFilmDataGridView.CurrentRow.Index].LoadStatus = LoadingStatus.Worked;
                
            }
        }

        private void oKButton_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void IMDBLoaderForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            this.WindowState = FormWindowState.Normal;
            Settings.Default.IMDBLoaderSize = this.Size;
            Settings.Default.Save();
        }

        private void iMDBFilmDataGridView_CellDoubleClick(object sender, DataGridViewCellEventArgs e)
        {
            buttonUebernehmen_Click(sender, new EventArgs());
        }
    }
}
