﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;
using ThiesGeneral.FileFunctions;
using ThiesGeneral.Media.Video;
using ThiesMediaProject.Properties;
using ThiesMediaProject.General;
using System.IO;

namespace ThiesMediaProject.ToolForms
{
    public partial class MultiPlayForm : Form
    {
        string[] strPlayListTypes = new string[2] 
        {
            ".mpcpl Mediaplayer classic Playlist",
            ".asx Windows Media Playlist"
        };
        List<string> Films;
        Films FilmList = new Films(); 

        public string Folder { get; set; }
                                                   

        public MultiPlayForm()
        {
            InitializeComponent();
            this.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            this.Icon = Properties.Resources.tmp_icon;
        }

        private void FormMultiPlay_Load(object sender, EventArgs e)
        {
            comboBoxPlayListType.Items.AddRange(strPlayListTypes);
            comboBoxPlayListType.SelectedIndex = 0;
        }

        public void addFilms(string[] filmsPar, Films filmList, string folderPar)
        {
            FilmList = filmList;
            Films = new List<string>(filmsPar);
            listBoxFilms.Items.AddRange(filmsPar);
            Folder = folderPar;
        }



        private void buttonPlay_Click(object sender, EventArgs e)
        {
            if (listBoxFilms.SelectedIndex >= 0)
            {
                MyFile.StartFile(listBoxFilms.SelectedItem.ToString(), Settings.Default.DaemonToolsPath);
            }
        }

        private void buttonOk_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void buttonGeneratePlaylist_Click(object sender, EventArgs e)
        {
            switch (comboBoxPlayListType.SelectedIndex)
            {
                case 0:
                    MyFile.StartFile(VideoPlaylist.GenerateMPCPL(Films, Folder), Settings.Default.DaemonToolsPath);
                    break;
                case 1:
                    MyFile.StartFile(VideoPlaylist.GenerateASXPL(Films, Folder), Settings.Default.DaemonToolsPath);
                    break;
            }
        }        

        private void deleteButton_Click(object sender, EventArgs e)
        {
            if (listBoxFilms.SelectedIndex >= 0)
            {
                Films.RemoveAt(listBoxFilms.SelectedIndex);
                listBoxFilms.Items.Remove(listBoxFilms.SelectedItem);
                if (listBoxFilms.Items.Count > 0)
                {
                    listBoxFilms.SelectedIndex = 0;
                }
            }
            
        }

        private void upButton_Click(object sender, EventArgs e)
        {
            var myListbox = new ListBox();
            
            if (listBoxFilms.SelectedIndex > 0)
            {
                for (int a = 0; a < listBoxFilms.Items.Count; a++)
                {
                    if (a < listBoxFilms.Items.Count - 1)
                    {
                        if (listBoxFilms.Items[a + 1] == listBoxFilms.SelectedItem)
                        {
                            myListbox.Items.Add(listBoxFilms.SelectedItem);
                            myListbox.Items.Add(listBoxFilms.Items[a]);
                            a++;
                        }
                        else
                        {
                            myListbox.Items.Add(listBoxFilms.Items[a]);
                        }
                    }
                    else
                    {
                        myListbox.Items.Add(listBoxFilms.Items[a]);
                    }
                }
                for (int i = 0; i < listBoxFilms.Items.Count; i++)
                {
                    listBoxFilms.Items[i] = myListbox.Items[i];
                }
                listBoxFilms.SelectedIndex--;
            }
        }

        private void downButton_Click(object sender, EventArgs e)
        {
            var myListbox = new ListBox();

            if (listBoxFilms.SelectedItem != null)
            {
                for (int a = 0; a < listBoxFilms.Items.Count; a++)
                {
                    if (a < listBoxFilms.Items.Count - 1)
                    {
                        if (listBoxFilms.Items[a] == listBoxFilms.SelectedItem)
                        {
                            myListbox.Items.Add(listBoxFilms.Items[listBoxFilms.SelectedIndex+1]);
                            myListbox.Items.Add(listBoxFilms.SelectedItem);
                            a++;
                        }
                        else
                        {
                            myListbox.Items.Add(listBoxFilms.Items[a]);
                        }
                    }
                    else
                    {
                        myListbox.Items.Add(listBoxFilms.Items[a]);
                    }
                }
                for (int i = 0; i < listBoxFilms.Items.Count; i++)
                {
                    listBoxFilms.Items[i] = myListbox.Items[i];
                }
                listBoxFilms.SelectedIndex++;
            }
        }

        private void saveAsButton_Click(object sender, EventArgs e)
        {
            saveFileDialog1.Filter = ".mpcpl Mediaplayer classic Playlist|*.mpcpl|.asx Windows Media Playlist|*.asx";
            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                switch (comboBoxPlayListType.SelectedIndex)
                {
                    case 0:
                        MyFile.StartFile(VideoPlaylist.GenerateMPCPL(Films, Folder, saveFileDialog1.FileName), Settings.Default.DaemonToolsPath);
                        break;
                    case 1:
                        MyFile.StartFile(VideoPlaylist.GenerateASXPL(Films, Folder, saveFileDialog1.FileName), Settings.Default.DaemonToolsPath);
                        break;
                }
            }
        }

        private void saveFileDialog1_FileOk(object sender, CancelEventArgs e)
        {

        }

        private void playOnlyButton_Click(object sender, EventArgs e)
        {
            if (listBoxFilms.SelectedIndex >= 0)
            {
                FileInfo fI = new FileInfo(listBoxFilms.SelectedItem.ToString());
                Film myFilm = 
                    Data.DataFilms.GetFilmByPath(
                        fI.DirectoryName);
                if (myFilm != null)
                {
                    myFilm.OnlyPlayFilePath = listBoxFilms.SelectedItem.ToString();
                    myFilm.SaveXML();
                    MyFile.StartFile(listBoxFilms.SelectedItem.ToString(), Settings.Default.DaemonToolsPath);
                    this.Close();
                }
            }
        }

      
    }
}
