﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;
using ThiesGeneral.FileFunctions;
using ThiesGeneral.Media.Musik;
using ThiesMediaProject.Properties;

namespace ThiesMediaProject.ToolForms
{
    public partial class MusikPlayListForm : Form
    {
        M3U MusikPlaylist = new M3U();
        M3U RandomMusikPlaylist = new M3U();
        public new MusikForm ParentForm { get; set; }
        public string Folder { get; set; }
        bool Randomized = false;
        bool Repeat = false;
        Random rnd = new Random();
        int CurrentRandomItem = 0;


        public MusikPlayListForm()
        {
            InitializeComponent();
            this.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            this.Icon = Properties.Resources.tmp_icon;
        }

        private void FormMultiPlay_Load(object sender, EventArgs e)
        {

        }

        public void AddMusikFile(M3UItem item)
        {
            RandomMusikPlaylist.Add(item);
            MusikPlaylist.Add(item);
            m3UItemBindingSource.DataSource = MusikPlaylist;
            m3UItemDataGridView.Refresh();
        }

        public void AddMusikFile(M3U items)
        {            
            MusikPlaylist = items;
            m3UItemBindingSource.DataSource = MusikPlaylist;
            m3UItemDataGridView.Refresh();
            CreateRandomMusicPlaylist();
        }


        private void buttonPlay_Click(object sender, EventArgs e)
        {
            Play();
        }

        public void Play()
        {
            if (m3UItemDataGridView.CurrentRow != null)
            {
                ParentForm.PlayFile(
                    MusikPlaylist[m3UItemDataGridView.CurrentRow.Index].FilePath);
                if (Settings.Default.UseMusikPlayListForPlay)
                {
                    ParentForm.SearchForFile(
                        MusikPlaylist[m3UItemDataGridView.CurrentRow.Index].FilePath);
                }
            }
        }

        private void deleteButton_Click(object sender, EventArgs e)
        {
            if (m3UItemDataGridView.CurrentRow != null)
            {
                MusikPlaylist.RemoveAt(m3UItemDataGridView.CurrentRow.Index);
                m3UItemBindingSource.DataSource = MusikPlaylist;
                m3UItemDataGridView.Refresh();
            }
        }

        private void upButton_Click(object sender, EventArgs e)
        {
            var myItem = new M3UItem();
            
            if (m3UItemDataGridView.CurrentRow != null)
            {
                if (m3UItemDataGridView.CurrentRow.Index > 0)
                {
                    myItem = MusikPlaylist[m3UItemDataGridView.CurrentRow.Index - 1];
                    MusikPlaylist[m3UItemDataGridView.CurrentRow.Index - 1] =
                        MusikPlaylist[m3UItemDataGridView.CurrentRow.Index];
                    MusikPlaylist[m3UItemDataGridView.CurrentRow.Index] = myItem;
                    m3UItemBindingSource.DataSource = MusikPlaylist;
                    m3UItemDataGridView.Refresh();
                    m3UItemDataGridView.CurrentCell =
                        m3UItemDataGridView.Rows[m3UItemDataGridView.CurrentRow.Index - 1].
                            Cells[m3UItemDataGridView.CurrentCell.ColumnIndex];
                }
            }
        }

        private void downButton_Click(object sender, EventArgs e)
        {
            var myItem = new M3UItem();

            if (m3UItemDataGridView.CurrentRow != null)
            {
                if (m3UItemDataGridView.CurrentRow.Index != m3UItemDataGridView.Rows.Count - 1)
                {
                    myItem = MusikPlaylist[m3UItemDataGridView.CurrentRow.Index + 1];
                    MusikPlaylist[m3UItemDataGridView.CurrentRow.Index + 1] =
                        MusikPlaylist[m3UItemDataGridView.CurrentRow.Index];
                    MusikPlaylist[m3UItemDataGridView.CurrentRow.Index] = myItem;
                    m3UItemBindingSource.DataSource = MusikPlaylist;
                    m3UItemDataGridView.Refresh();
                    m3UItemDataGridView.CurrentCell =
                        m3UItemDataGridView.Rows[m3UItemDataGridView.CurrentRow.Index + 1].
                            Cells[m3UItemDataGridView.CurrentCell.ColumnIndex];
                }
            }
        }

        private void saveAsButton_Click(object sender, EventArgs e)
        {
            saveFileDialog1.Title = "Save playlist";
            saveFileDialog1.Filter = ".m3u Mediaplaylist|*.m3u";
            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                MusikPlaylist.SaveM3UFile(saveFileDialog1.FileName);
            }
        }

        private void saveFileDialog1_FileOk(object sender, CancelEventArgs e)
        {

        }

        public void PlayPrev()
        {
            if (m3UItemDataGridView.CurrentRow != null)
            {
                if (Randomized)
                {
                    if (CurrentRandomItem >= 1)
                    {
                        CurrentRandomItem--;
                        FindRandomItem();
                        Play();                        
                    }                    
                }
                else
                {
                    if (m3UItemDataGridView.CurrentRow.Index > 0)
                    {
                        m3UItemDataGridView.CurrentCell =
                                    m3UItemDataGridView.Rows[m3UItemDataGridView.CurrentRow.Index - 1].
                                        Cells[m3UItemDataGridView.CurrentCell.ColumnIndex];
                        Play();
                    }
                }
            }
        }

        private void prevButton_Click(object sender, EventArgs e)
        {
            PlayPrev();
        }

        public void PlayNext()
        {
            if (m3UItemDataGridView.CurrentRow != null)
            {

                if (Randomized)
                {
                    if (CurrentRandomItem < RandomMusikPlaylist.Count - 1)
                    {
                        CurrentRandomItem++;
                        FindRandomItem();
                        Play();
                    }
                    else if (Repeat)
                    {
                        CurrentRandomItem = 0;
                        FindRandomItem();
                        Play();
                    }
                }
                else
                {
                    if (m3UItemDataGridView.CurrentRow.Index != m3UItemDataGridView.Rows.Count - 1)
                    {
                        m3UItemDataGridView.CurrentCell =
                            m3UItemDataGridView.Rows[m3UItemDataGridView.CurrentRow.Index + 1].
                                Cells[m3UItemDataGridView.CurrentCell.ColumnIndex];
                        Play();
                    }
                    else if (Repeat)
                    {
                        m3UItemDataGridView.CurrentCell =
                            m3UItemDataGridView.Rows[0].
                                Cells[m3UItemDataGridView.CurrentCell.ColumnIndex];
                        Play();
                    }
                }
            }
        }

        private void nextButton_Click(object sender, EventArgs e)
        {
            PlayNext();
        }

        public void SetPosition(int myPosition)
        {
            m3UItemDataGridView.CurrentCell =
                        m3UItemDataGridView.Rows[myPosition].
                            Cells[m3UItemDataGridView.CurrentCell.ColumnIndex];
        }

        private void clearButton_Click(object sender, EventArgs e)
        {
            MusikPlaylist.Clear();
            RandomMusikPlaylist.Clear();
            m3UItemBindingSource.DataSource = MusikPlaylist;
            m3UItemDataGridView.Refresh();
        }

        private void loadButton_Click(object sender, EventArgs e)
        {
            if (loadPlayListOpenFileDialog.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                MusikPlaylist.LoadM3UFile(loadPlayListOpenFileDialog.FileName);
            }
            CreateRandomMusicPlaylist();
        }

        private void randomButton_Click(object sender, EventArgs e)
        {
            Randomized = !Randomized;
            switch (randomButton.FlatStyle)
            {
                case FlatStyle.Flat:
                    randomButton.FlatStyle = FlatStyle.System;
                    randomButton.BackColor = buttonPlay.BackColor;
                    break;
                case FlatStyle.Popup:
                    break;
                case FlatStyle.Standard:
                    randomButton.FlatStyle = FlatStyle.Flat;
                    randomButton.BackColor = Color.LightSteelBlue;
                    break;
                case FlatStyle.System:
                    randomButton.FlatStyle = FlatStyle.Flat;
                    randomButton.BackColor = Color.LightSteelBlue;
                    break;
                default:
                    break;
            }
            CreateRandomMusicPlaylist();
        }

        private void CreateRandomMusicPlaylist()
        {
            if (Randomized)
            {
                RandomMusikPlaylist.Clear();
                M3U tempMusicPlaylist = new M3U();
                foreach (M3UItem item in MusikPlaylist)
                {
                    tempMusicPlaylist.Add(item);
                }

                int maxCount = tempMusicPlaylist.Count;
                for (int i = 0; i < maxCount; i++)
                {                    
                    int newIndex = rnd.Next(0, tempMusicPlaylist.Count);
                    RandomMusikPlaylist.Add(tempMusicPlaylist[newIndex]);
                    tempMusicPlaylist.Remove(tempMusicPlaylist[newIndex]);
                }
                CurrentRandomItem = 0;
            }
        }

        private void FindRandomItem()
        {
            m3UItemDataGridView.CurrentCell =
                            m3UItemDataGridView.Rows[MusikPlaylist.IndexOf(RandomMusikPlaylist[CurrentRandomItem])].
                                Cells[m3UItemDataGridView.CurrentCell.ColumnIndex];
        }

        private void repeatButton_Click(object sender, EventArgs e)
        {
            Repeat = !Repeat;
            switch (repeatButton.FlatStyle)
            {
                case FlatStyle.Flat:
                    repeatButton.FlatStyle = FlatStyle.System;
                    repeatButton.BackColor = buttonPlay.BackColor;
                    break;
                case FlatStyle.Popup:
                    break;
                case FlatStyle.Standard:
                    repeatButton.FlatStyle = FlatStyle.Flat;
                    repeatButton.BackColor = Color.LightSteelBlue;
                    break;
                case FlatStyle.System:
                    repeatButton.FlatStyle = FlatStyle.Flat;
                    repeatButton.BackColor = Color.LightSteelBlue;
                    break;
                default:
                    break;
            }
        }

        private void m3UItemDataGridView_CellDoubleClick(object sender, DataGridViewCellEventArgs e)
        {
            Play();
        }
    }
}
