﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ThiesMediaProject.General;
using ThiesMediaProject.Properties;
using System.Threading;
using System.IO;
using ThiesMediaProject.MedInfo;

namespace ThiesMediaProject.ToolForms
{
    public partial class SeriesFilePropertyForm : Form
    {
        public Series MySeries { get; set; }

        public SeriesFilePropertyForm()
        {
            InitializeComponent();
            this.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            this.Icon = Properties.Resources.tmp_icon;
        }

        public SeriesFilePropertyForm(Series mySeries)
        {
            MySeries = mySeries;
            InitializeComponent();
            this.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            this.Icon = Properties.Resources.tmp_icon;
        }

        private void SeriesFilePropertyForm_Load(object sender, EventArgs e)
        {
            var mySf = new StatusForm("Propertyload");
            mySf.MaxValue = MySeries.SeriesEpisodes.Count;
            mySf.Show();
            seriesEpisodeBindingSource.DataSource = MySeries.SeriesEpisodes;
            seriesEpisodeDataGridView.Refresh();
            foreach (var seriesEpisode in MySeries.SeriesEpisodes)
            {
                mySf.Value++;
                try
                {
                    if (seriesEpisode.FilePath.ToLower().Contains(".ifo"))
                    {
                        if (new FileInfo(seriesEpisode.FilePath).Directory.GetFiles("*.vob",SearchOption.AllDirectories).Count() > 0)
                        {
                            TimeSpan myLength = new TimeSpan(0);
                            TimeSpan myLength3 = new TimeSpan(0);
                            foreach (FileInfo item in new FileInfo(seriesEpisode.FilePath).Directory.GetFiles("*.vob",SearchOption.AllDirectories))
                            {
                                axWindowsMediaPlayer1.URL = item.FullName;
                                axWindowsMediaPlayer1.Ctlcontrols.play();
                                DateTime startingDateTime = DateTime.Now;
                                while (axWindowsMediaPlayer1.playState != WMPLib.WMPPlayState.wmppsPlaying)
                                {
                                    Thread.Sleep(1);
                                    Application.DoEvents();
                                    if (DateTime.Now - startingDateTime > new TimeSpan(0, 0, 30))
                                    {
                                        throw new Exception("Can't read File: " + seriesEpisode.FilePath);
                                    }
                                }
                                axWindowsMediaPlayer1.Ctlcontrols.stop();
                                TimeSpan myLength2 = new TimeSpan(0);
                                string oldUrl = "";
                                for (int i = 0; i < axWindowsMediaPlayer1.currentPlaylist.count; i++)
			                    {
                                    if (axWindowsMediaPlayer1.currentPlaylist.get_Item(i).sourceURL.Substring(1,12) != oldUrl)
                                    {
                                        myLength2 = new TimeSpan(
                                        Convert.ToInt64(axWindowsMediaPlayer1.currentPlaylist.get_Item(i).duration * 10000000) + myLength2.Ticks);
                                        oldUrl = axWindowsMediaPlayer1.currentPlaylist.get_Item(i).sourceURL.Substring(1, 12);
                                    }
			                    }
                                // 02:25:30 - VTS_02_1 myLength2 = {01:12:46.6000000}
                                if (myLength2.Milliseconds > 0 && myLength2 > myLength)
                                {
                                    myLength = new TimeSpan(myLength2.Ticks);
                                }
                                else if (myLength2 > myLength3)
                                {
                                    myLength3 = new TimeSpan(myLength2.Ticks);
                                }
                                seriesEpisode.Width = axWindowsMediaPlayer1.currentMedia.imageSourceWidth;
                                seriesEpisode.Height = axWindowsMediaPlayer1.currentMedia.imageSourceHeight;
                            }
                            if (myLength == new TimeSpan(0))
                            {
                                myLength = new TimeSpan(myLength3.Ticks);
                            }
                            seriesEpisode.Length = myLength.ToString("hh':'mm':'ss");
                        }
                    }
                    else
                    {
                        MediaInfo MI = new MediaInfo();
                        MI.Open(seriesEpisode.FilePath);
                        seriesEpisode.VideoCodec = MI.Get(0, 0, "Video_Format_WithHint_List");
                        try
                        {
                            seriesEpisode.Width = Convert.ToInt32(MI.Get(StreamKind.Video, 0, "Width"));
                        }
                        catch (Exception) { }
                        try
                        {
                            seriesEpisode.Height = Convert.ToInt32(MI.Get(StreamKind.Video, 0, "Height"));
                        }
                        catch (Exception) { }
                        try
                        {
                            seriesEpisode.Length = Convert.ToDateTime(MI.Get(StreamKind.Video, 0, "Duration/String3")).TimeOfDay.ToString(@"hh\:mm\:ss");
                        }
                        catch (Exception) { }
                        try
                        {
                            seriesEpisode.VideoBitrate = Convert.ToInt32(MI.Get(StreamKind.Video, 0, "BitRate"));
                        }
                        catch (Exception) { }
                        try
                        {
                            seriesEpisode.AudioStreams = Convert.ToInt32(MI.Get(StreamKind.Audio, 0, "StreamCount"));
                        }
                        catch (Exception) { }

                        seriesEpisode.AudioLanguages = string.Empty;
                        seriesEpisode.AudioBitrate = string.Empty;
                        seriesEpisode.AudioCodec = string.Empty;
                        for (int i = 0; i < seriesEpisode.AudioStreams; i++)
                        {
                            seriesEpisode.AudioLanguages += MI.Get(StreamKind.Audio, i, "Language") + "|";
                            try
                            {
                                seriesEpisode.AudioBitrate += Convert.ToInt32(MI.Get(StreamKind.Audio, i, "BitRate")) + "|";
                            }
                            catch (Exception) { }
                            try
                            {
                                seriesEpisode.AudioChannels += Convert.ToInt32(MI.Get(StreamKind.Audio, i, "Channel(s)")) + "|";
                            }
                            catch (Exception) { }
                            seriesEpisode.AudioCodec += MI.Get(StreamKind.Audio, i, "Format") + "|";
                        }                                       
                                                
                    }
                }
                catch (Exception)
                {

                }

            }
            mySf.Close();
        }

        private void buttonOk_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void SeriesFilePropertyForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            MySeries.SaveAllXml();
        }
    }
}
