﻿/// Copyright © 2010-2011 Sebastian Thies
/// This program is distributed under the terms of the GNU General Public License
/// http://www.gnu.org/licenses/#GPL
/// email: sebastian.thies@arcor.de
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ThiesMediaProject.General;
using ThiesMediaProject.Properties;

namespace ThiesMediaProject.ToolForms
{
    public partial class SpecialPropertyChangerForm : Form
    {
        public BindingList<SpecialPropertyChanger> MProperties { get; set; }
        BindingList<SpecialPropertyChangerFunction> _Functions = new BindingList<SpecialPropertyChangerFunction>();

        public SpecialPropertyChangerForm()
        {
            InitializeComponent();
            this.Size = Settings.Default.SpecialPropertyFormSize;
            this.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            specialPropertyChangerBindingNavigator.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            bindingNavigatorPositionItem.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            this.Icon = Properties.Resources.tmp_icon;
        }

        private void SpecialPropertyChangerForm_Load(object sender, EventArgs e)
        {
            //MProperties = new BindingList<SpecialPropertyChanger>();
            //var SPC = new SpecialPropertyChanger();
            //SPC.ValueBeforeChange = "Test1";
            //MProperties.Add(SPC);
            //SPC = new SpecialPropertyChanger();
            //SPC.ValueBeforeChange = "Test2";
            //MProperties.Add(SPC);
            //SPC = new SpecialPropertyChanger();
            //SPC.ValueBeforeChange = "3Test";
            //MProperties.Add(SPC);
            //SPC = new SpecialPropertyChanger();
            //SPC.ValueBeforeChange = "4Test";
            //MProperties.Add(SPC);


            functionsComboBox.DataSource = Enum.GetValues(typeof(SpecialPropertyChangerFunction.AvailableFunctions));
            if (MProperties != null)
            {
                specialPropertyChangerBindingSource.DataSource = MProperties;    
            }
            specialPropertyChangerFunctionBindingSource.DataSource = _Functions;
            specialPropertyChangerDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);
            specialPropertyChangerFunctionDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);
        }

        private void addButton_Click(object sender, EventArgs e)
        {
            var myFunction = new SpecialPropertyChangerFunction();
            myFunction.TheFunction =
                (SpecialPropertyChangerFunction.AvailableFunctions)functionsComboBox.SelectedIndex;
            myFunction.Text1 = text1TextBox.Text;
            myFunction.Text2 = text2TextBox.Text;
            _Functions.Add(myFunction);
            specialPropertyChangerFunctionBindingSource.DataSource = _Functions;
            specialPropertyChangerFunctionDataGridView.Refresh();
            DoFunctions();
            specialPropertyChangerDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);
            specialPropertyChangerFunctionDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);
        }

        private void DoFunctions()
        {
            bool folowingJob = false;
            foreach (var item in _Functions)
            {
                if (folowingJob)
                {
                    foreach (var item2 in MProperties)
                    {
                        item2.ValueAfterChange =
                        item.RunFunction(item.TheFunction, item2.ValueAfterChange, item.Text1, item.Text2);
                    }
                }
                else
                {
                    foreach (var item2 in MProperties)
                    {
                        item2.ValueAfterChange =
                        item.RunFunction(item.TheFunction, item2.ValueBeforeChange, item.Text1, item.Text2);
                    }
                    folowingJob = true;
                }
                specialPropertyChangerBindingSource.DataSource = MProperties;
                specialPropertyChangerDataGridView.Refresh();
                specialPropertyChangerDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);
                specialPropertyChangerFunctionDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);
            }
            text1TextBox.Text = "";
            text2TextBox.Text = "";
        }

        private void deleteButton_Click(object sender, EventArgs e)
        {
            _Functions.RemoveAt(specialPropertyChangerFunctionDataGridView.CurrentRow.Index);
            specialPropertyChangerFunctionBindingSource.DataSource = _Functions;
            DoFunctions();
            specialPropertyChangerDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);
            specialPropertyChangerFunctionDataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.AllCells);
        }

        private void oKButton_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void SpecialPropertyChangerForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            this.WindowState = FormWindowState.Normal;
            Settings.Default.SpecialPropertyFormSize = this.Size;
        }
    }
}
