﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.IO;
using System.Windows.Forms;
using ThiesMediaProject.SettingForms;
using ThiesMediaProject.Properties;
using Microsoft.DirectX.AudioVideoPlayback;
using Gma.UserActivityMonitor;

namespace ThiesMediaProject.ToolForms
{
    public partial class VideoPlayerForm : Form
    {
        Video myVideo;
        bool myFullscreen;
        private bool mausDown;
        public static string[] fileTypes = {
            "*.mkv", 
            "*.avi",
            "*.mpg",
            "*.ogm",
            "*.mpeg",
            "*.ts",
            "*.m2ts",
            "video_ts.ifo",
            "*.wmv",
            "*.mp4"
        };
        public string FilePath { get; set; }
        public void GetFilePathByFolder(string folderPath)
        {
            foreach (string fileType in fileTypes)
            {
                foreach (string filePath in Directory.GetFiles(folderPath, fileType, SearchOption.AllDirectories))
                {
                    FilePath = filePath;
                    return;
                }
            }
            MessageBox.Show("File not found!", "File not found", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }

        Size videoSize;

        public VideoPlayerForm()
        {
            InitializeComponent();
            this.Font = new Font(this.Font.FontFamily, (float)Convert.ToDouble(Settings.Default.FormFontSize));
            this.Icon = Properties.Resources.gnome_mime_video;
        }

        private void HookManager_MouseDoubleClick(object sender, MouseEventArgs e)
        {
            
        }


        private void stopButton_Click(object sender, EventArgs e)
        {
            if (myVideo != null)
            {
                myVideo.Stop();
                myVideo = null;
            }
        }

        private void VideoPlayerForm_FormClosed(object sender, FormClosedEventArgs e)
        {
            if (myVideo != null)
            {
                playerTimer.Enabled = false;
                myVideo.Dispose();
            }
        }

        private void playButton_Click(object sender, EventArgs e)
        {
            Play();
        }

        private void Play()
        {
            if (FilePath != "")
            {
                try
                {
                    if (myVideo == null)
                    {
                        videoSize = new Size(videoPanel.Width, videoPanel.Height);
                        myVideo = new Video(FilePath);
                        myVideo.Owner = videoPanel;
                        myVideo.Size = videoSize;
                        videoPanel.Size = videoSize;
                    }
                    myVideo.Play();
                    lenthLabel.Text = new DateTime(Convert.ToInt64(10000000 * myVideo.Duration)).TimeOfDay.ToString("hh':'mm':'ss");
                }
                catch (Exception)
                {
                    myVideo = null;
                }
            }
        }

        private void pauseButton_Click(object sender, EventArgs e)
        {
            if (myVideo != null)
            {
                myVideo.Pause();
            }
        }

        private void playerTimer_Tick(object sender, EventArgs e)
        {
            if ((myVideo != null))
            {
                if ((myVideo.Playing))
                {
                    positionLabel.Text = new DateTime(Convert.ToInt64(10000000 * myVideo.CurrentPosition)).TimeOfDay.ToString("hh':'mm':'ss");
                    if (!mausDown)
                    {
                        playPositionTrackBar.Maximum = Convert.ToInt32(myVideo.Duration);
                        playPositionTrackBar.Value = Convert.ToInt32(myVideo.CurrentPosition);
                    }    
                }
            }
        }

        private void playPositionTrackBar_MouseDown(object sender, MouseEventArgs e)
        {
            mausDown = true;
        }

        private void playPositionTrackBar_MouseUp(object sender, MouseEventArgs e)
        {
            if ((myVideo != null))               
            {
                if ((myVideo.Playing))
                {
                    myVideo.CurrentPosition = Convert.ToDouble(playPositionTrackBar.Value);    
                }
            }
            mausDown = false;
        }

        private void fullscreenButton_Click(object sender, EventArgs e)
        {
            if ((myVideo != null))
            {
                myVideo.Fullscreen = true;
            }
        }

        private void videoPanel_MouseDoubleClick(object sender, MouseEventArgs e)
        {
            
        }

        

        private void playPositionTrackBar_Scroll(object sender, EventArgs e)
        {

        }

        private void ToggleFullscreen()
        {
            if (myVideo != null)
            {
                if (myFullscreen)
                {
                    //myVideo.Fullscreen = false;
                    videoPanel.Dock = DockStyle.None;
                    this.ShowInTaskbar = true;
                    this.WindowState = FormWindowState.Normal;
                    this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.Sizable;
                    myFullscreen = false;
                }
                else
                {
                        videoPanel.Dock = DockStyle.Fill;
                        videoPanel.BringToFront();
                        this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.None;
                        this.WindowState = FormWindowState.Maximized;
                        myFullscreen = true;
                }
            }

        }


        private void globalEventProvider1_MouseDoubleClick(object sender, MouseEventArgs e)
        {
            if (myFullscreen)
            {
                ToggleFullscreen();
            }
            else
            {
                int xBeginn = this.Location.X + videoPanel.Location.X;
                int xEnd = xBeginn + videoPanel.Width;

                int yBeginn = this.Location.Y + videoPanel.Location.Y;
                int yEnd = yBeginn + videoPanel.Height;


                if (
                    ((e.X >= xBeginn) && (e.X <= xEnd))
                    &&
                    ((e.Y >= yBeginn) && (e.Y <= yEnd))
                    )
                {
                    ToggleFullscreen();
                }
            }
        }

        private void VideoPlayerForm_Load(object sender, EventArgs e)
        {
            Play();
        }
        
    }
}
