﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Resources;
using System.Globalization;
using System.Windows.Forms;

namespace ThiesMediaProject
{
    static public class Translate
    {
        static CultureInfo Culture = CultureInfo.CurrentUICulture;


        /// <summary>
        /// change culture to a specific language
        /// </summary>
        /// <param name="cultureText">the culturetext de-DE for example</param>
        static public void SetNewCulture(string cultureText)
        {
            Culture = CultureInfo.CreateSpecificCulture(cultureText);
        }

        /// <summary>
        /// gets the translation of current culture
        /// </summary>
        /// <param name="inText">the text to translate</param>
        /// <returns>translated text</returns>
        static public string GetText(string inText)
        {
            ResourceManager rm = new
                ResourceManager("ThiesMediaProject.TMP_Language", typeof(MainForm).Assembly);
            if (rm.GetString(inText, Culture) != null)
            {
                return rm.GetString(inText, Culture);
            }
            else if (rm.GetString(ReplaceWrongChars(inText), Culture) != null)
            {
                return rm.GetString(ReplaceWrongChars(inText), Culture);
            }
            return inText;
        }

        /// <summary>
        /// replaces characters not allowed in names
        /// </summary>
        /// <param name="inText">the text to convert</param>
        /// <returns>converted string</returns>
        static private string ReplaceWrongChars(string inText)
        {
            string[] wrongChars = {
               " ",
               "\\",
               ":",
               "/",
               "&",
               "-"
           };

            foreach (string item in wrongChars)
            {
                inText = inText.Replace(item, "_");
            }
            return inText;
        }

        /// <summary>
        /// translates all controls on a form
        /// </summary>
        /// <param name="inForm">the form to translate</param>
        static public void TranslateForm(Form inForm)
        {
            inForm.Text = GetText(inForm.Text);
            foreach (Control item in inForm.Controls)
            {
                item.Text = GetText(item.Text);
                TranslateSubControls(item);
            }
        }

        static private void TranslateSubControls(Control inControl)
        {
            if (inControl.Controls != null)
            {
                if (inControl.Controls.Count > 0)
                {
                    foreach (Control item in inControl.Controls)
                    {
                        item.Text = GetText(item.Text);
                        TranslateSubControls(item);
                    }
                }
            }

            if (inControl.GetType() == new MenuStrip().GetType())
            {
                TranslateMenuStrip((MenuStrip)inControl);
            }

            if (inControl.GetType() == new DataGridView().GetType())
            {
                TranslateDataGridView((DataGridView)inControl);
            }
        }

        static private void TranslateDataGridView(DataGridView dataGridView)
        {
            foreach (DataGridViewColumn item in dataGridView.Columns)
            {
                item.HeaderText = GetText(item.HeaderText);
            }
        }


        static private void TranslateMenuStrip(MenuStrip menuStrip)
        {
            foreach (ToolStripDropDownItem item in menuStrip.Items)
            {
                item.Text = GetText(item.Text);
                TranslateToolStripMenuItem(item);
            }
        }

        static private void TranslateToolStripMenuItem(ToolStripDropDownItem menuStripItem)
        {
            for (int i = 0; i < menuStripItem.DropDownItems.Count; i++)
            {
                menuStripItem.DropDownItems[i].Text = GetText(menuStripItem.DropDownItems[i].Text);
                if (menuStripItem.DropDownItems[i].Text != "")
                {
                    TranslateToolStripMenuItem((ToolStripDropDownItem)menuStripItem.DropDownItems[i]);
                }
            }
        }

    }
}
